/* Copyright (c) 2001, 2011, Oracle and/or its affiliates. 
All rights reserved. */

/*
  |  SCC Viewer Technology - Include
  |
  |  Include:       SCCID.H
  |  Environment:   Portable
  |  Function:      Defines unique IDs for strings, dialogs, options, lists and maps in the Viewer Technology
  |
  */

/*
|  If you add an option for the viewer technology in here,
|  it should have a corresponding value added to sccop.h.
*/

#ifndef SCCID_H
#define SCCID_H

#ifdef WINDOWS
#ifndef SCC_PACK_SET
#define SCC_PACK_SET 1
#define SCC_PACKED_BY_SCCID_H 1
#pragma pack(push,8)
#endif /* SCC_PACK_SET */
#endif /* WINDOWS */

#ifdef __cplusplus
extern "C"
{
#endif

#define SCCIDTYPE_STRING        0x00010000
#define SCCIDTYPE_LIST          0x00020000
#define SCCIDTYPE_OPTION        0x00040000
#define SCCIDTYPE_DIALOG        0x00080000
#define SCCIDTYPE_ACTION        0x00100000
#define SCCIDTYPE_BITMAP        0x00200000

#define SCCID_INVALID           0xFFFFFFFF

/* String that contains hard coded options */


#define SCCID_SPREADSHEETDENAME    (SCCIDTYPE_STRING | 1)
#define SCCID_DATABASEDENAME       (SCCIDTYPE_STRING | 2)
#define SCCID_DOCUMENTDENAME       (SCCIDTYPE_STRING | 3)
#define SCCID_BITMAPDENAME         (SCCIDTYPE_STRING | 4)
#define SCCID_ARCHIVEDENAME        (SCCIDTYPE_STRING | 5)
#define SCCID_HEXDENAME            (SCCIDTYPE_STRING | 6)
#define SCCID_VECTORDENAME         (SCCIDTYPE_STRING | 7)
#define SCCID_MULTIMEDIADENAME     (SCCIDTYPE_STRING | 8)
#define SCCID_EMPTYDENAME          (SCCIDTYPE_STRING | 9)

#define SCCID_VWSTATE_OK           (SCCIDTYPE_STRING | 16)
#define SCCID_VWSTATE_ERROR        (SCCIDTYPE_STRING | 17)
#define SCCID_VWSTATE_EMPTY        (SCCIDTYPE_STRING | 18)
#define SCCID_VWSTATE_PROTECTED    (SCCIDTYPE_STRING | 19)
#define SCCID_VWSTATE_SORRY        (SCCIDTYPE_STRING | 20)
#define SCCID_VWSTATE_BAILOUT      (SCCIDTYPE_STRING | 21)
#define SCCID_VWSTATE_FATAL        (SCCIDTYPE_STRING | 22)

#define SCCID_VWMESSAGE_MEMORY           (SCCIDTYPE_STRING | 32)
#define SCCID_VWMESSAGE_STREAMBAIL       (SCCIDTYPE_STRING | 33)
#define SCCID_VWMESSAGE_FILEOPENFAILED   (SCCIDTYPE_STRING | 34)
#define SCCID_VWMESSAGE_MISSINGELEMENT   (SCCIDTYPE_STRING | 35)
#define SCCID_VWMESSAGE_BADFILE          (SCCIDTYPE_STRING | 36)
#define SCCID_VWMESSAGE_PROTECTEDFILE    (SCCIDTYPE_STRING | 37)
#define SCCID_VWMESSAGE_SUPFILEOPENFAILS (SCCIDTYPE_STRING | 38)
#define SCCID_VWMESSAGE_UNKNOWN          (SCCIDTYPE_STRING | 39)
#define SCCID_VWMESSAGE_EMPTYFILE        (SCCIDTYPE_STRING | 40)
#define SCCID_VWMESSAGE_EMPTYSECTION     (SCCIDTYPE_STRING | 41)
#define SCCID_VWMESSAGE_NOFILTER         (SCCIDTYPE_STRING | 42)
#define SCCID_VWMESSAGE_WRITEERROR       (SCCIDTYPE_STRING | 43)
#define SCCID_VWMESSAGE_FILECHANGED      (SCCIDTYPE_STRING | 44)
#define SCCID_VWMESSAGE_GPFAULT          (SCCIDTYPE_STRING | 45)
#define SCCID_VWMESSAGE_DIVIDEBYZERO     (SCCIDTYPE_STRING | 46)
#define SCCID_VWMESSAGE_NOSUPPORTEDFILE  (SCCIDTYPE_STRING | 47)
#define SCCID_VWMESSAGE_OTHEREXCEPTION   (SCCIDTYPE_STRING | 48)
#define SCCID_VWMESSAGE_NOENGINE         (SCCIDTYPE_STRING | 49)
#define SCCID_VWMESSAGE_UNKNOWNNOTVIEWED (SCCIDTYPE_STRING | 50)
#define SCCID_VWMESSAGE_FILTERTIMEOUT    (SCCIDTYPE_STRING | 51)
#define SCCID_VWMESSAGE_QVPTRIALEXPIRED  (SCCIDTYPE_STRING | 52)
#define SCCID_VWMESSAGE_CANCEL           (SCCIDTYPE_STRING | 53)
#define SCCID_VWMESSAGE_DRMFILE          (SCCIDTYPE_STRING | 54)
#define SCCID_VWMESSAGE_UNSUPPORTEDCOMPRESSION  (SCCIDTYPE_STRING | 55)
#define SCCID_VWMESSAGE_BADCREDENTIALS   (SCCIDTYPE_STRING | 56)

#define SCCID_VWCLIP_CAPTION             (SCCIDTYPE_STRING | 60)
#define SCCID_VWCLIP_NOMEMORY            (SCCIDTYPE_STRING | 61)
#define SCCID_VWCLIP_NOEMBEDDED          (SCCIDTYPE_STRING | 62)

#define SCCID_VWCLIP_FORMATBASE          (SCCIDTYPE_STRING | 70)
#define SCCID_VWCLIP_TEXT                (SCCID_VWCLIP_FORMATBASE)
#define SCCID_VWCLIP_RTF                 (SCCID_VWCLIP_FORMATBASE+1)
#define SCCID_VWCLIP_WINBITMAP           (SCCID_VWCLIP_FORMATBASE+7)
#define SCCID_VWCLIP_WINDIB              (SCCID_VWCLIP_FORMATBASE+8)
#define SCCID_VWCLIP_WINMETAFILE         (SCCID_VWCLIP_FORMATBASE+9)
#define SCCID_VWCLIP_WINPALETTE          (SCCID_VWCLIP_FORMATBASE+10)
#define SCCID_VWCLIP_MACPICT             (SCCID_VWCLIP_FORMATBASE+11)

#define SCCID_VWGRAF_EMBEDDEDGRAPHIC     (SCCIDTYPE_STRING | 90)
#define SCCID_VWGRAF_LINKEDGRAPHIC       (SCCIDTYPE_STRING | 91)

/* Used only in Win32, keys in Registry */

#define SCCID_REGNAME_COMPANY            (SCCIDTYPE_STRING | 100)
#define SCCID_REGNAME_PRODUCT            (SCCIDTYPE_STRING | 101)
#define SCCID_REGNAME_VERSION            (SCCIDTYPE_STRING | 102)

/* Used only in Win16, file, section & item in INI file */

#define SCCID_INI_FILE                   (SCCIDTYPE_STRING | 110)
#define SCCID_INI_SECTION                (SCCIDTYPE_STRING | 111)
#define SCCID_INI_ITEM                   (SCCIDTYPE_STRING | 112)

/* Name of the options file or registry entry */

#define SCCID_OPTIONS_FILE               (SCCIDTYPE_STRING | 115)
#define SCCID_OPTIONS_DEFAULT            (SCCIDTYPE_STRING | 116)
#define SCCID_CHARMAP_FILE               (SCCIDTYPE_STRING | 117)
#define SCCID_OPTIONS_REGISTRY           (SCCIDTYPE_STRING | 118)

/* Unix specific option to get the options file name */

#define SCCID_GETUNIXOPTIONSFILENAME     (SCCIDTYPE_STRING | 119)

/* Strings used in dialogs */

#define SCCID_PRINTABORTDLG_PAGE         (SCCIDTYPE_STRING | 120)
#define SCCID_PRINTOPTIONSDLG_FONT       (SCCIDTYPE_STRING | 121)
#define SCCID_FILTERLISTDLG_SELECTFILTER (SCCIDTYPE_STRING | 122)
#define SCCID_FILTERLISTDLG_FILTERLOAD   (SCCIDTYPE_STRING | 123)
#define SCCID_FILTERLISTDLG_FILTERINFO   (SCCIDTYPE_STRING | 124)
#define SCCID_FILTERLISTDLG_REBUILD      (SCCIDTYPE_STRING | 125)
#define SCCID_FILTERLISTDLG_FILEHEADER   (SCCIDTYPE_STRING | 126)
#define SCCID_FILTERLISTDLG_WRITEINFO    (SCCIDTYPE_STRING | 127)

/* Strings for font attributes */

#define SCCID_FONT_NORMAL                (SCCIDTYPE_STRING | 130)
#define SCCID_FONT_U                     (SCCID_FONT_NORMAL+1)
#define SCCID_FONT_I                     (SCCID_FONT_NORMAL+2)
#define SCCID_FONT_UI                    (SCCID_FONT_NORMAL+3)
#define SCCID_FONT_B                     (SCCID_FONT_NORMAL+4)
#define SCCID_FONT_BU                    (SCCID_FONT_NORMAL+5)
#define SCCID_FONT_BI                    (SCCID_FONT_NORMAL+6)
#define SCCID_FONT_BUI                   (SCCID_FONT_NORMAL+7)

/* Strings for window classes */

#define SCCID_WNDCLASS_VIEWER            (SCCIDTYPE_STRING | 140)
#define SCCID_WNDCLASS_DISPLAY           (SCCIDTYPE_STRING | 141)
#define SCCID_WNDCLASS_SECLIST           (SCCIDTYPE_STRING | 142)
#define SCCID_WNDCLASS_SCROLL             (SCCIDTYPE_STRING | 143)

/* Strings for filter and engine searches */

#define SCCID_FINDSPEC_FILTER            (SCCIDTYPE_STRING | 145)
#define SCCID_FINDSPEC_DISPLAY           (SCCIDTYPE_STRING | 146)
#define SCCID_FINDSPEC_EXPORT            (SCCIDTYPE_STRING | 147)
#define SCCID_FINDSPEC_COMPONENT         (SCCIDTYPE_STRING | 148)
#define SCCID_FINDSPEC_SCHEMADEF         (SCCIDTYPE_STRING | 149)

/* Strings for names of OLE2 and VWOLE2 DLLs */

#define SCCID_DLLNAME_OLE2               (SCCIDTYPE_STRING | 150)
#define SCCID_DLLNAME_SCCOLE             (SCCIDTYPE_STRING | 151)
#define SCCID_DLLNAME_SCCSD              (SCCIDTYPE_STRING | 152)
#define SCCID_DLLNAME_SCCXT              (SCCIDTYPE_STRING | 153)
#define SCCID_DLLNAME_SCCDU              (SCCIDTYPE_STRING | 154)
/*  Indexing related strings.  */
/*
    Despite deprecating ExInd2, leaving the ExInd string named with a '3' so
    current users don't have to change their code.
*/
#define SCCID_DLLNAME_SCCEXIND           (SCCIDTYPE_STRING | 155)
#define SCCID_DLLNAME_SCCEXIND3          SCCID_DLLNAME_SCCEXIND
#define SCCID_DLLNAME_SCCIND             (SCCIDTYPE_STRING | 156)
#define SCCID_DLLNAME_SCCCA              (SCCIDTYPE_STRING | 157)
#define SCCID_DLLNAME_SCCTA              (SCCIDTYPE_STRING | 158)

/* Strings for captions used in displaying embeddings in draft mode */
#define  SCCID_CAPTION_OLE1OBJECT        (SCCIDTYPE_STRING | 160)
#define  SCCID_CAPTION_OLE2OBJECT        (SCCIDTYPE_STRING | 161)
#define  SCCID_CAPTION_GRAPHICOBJECT     (SCCIDTYPE_STRING | 163)

/* Strings for names of days and months */

#define SCCID_FULLDAYNAME_1         (SCCIDTYPE_STRING | 200)
#define SCCID_FULLDAYNAME_2         (SCCIDTYPE_STRING | 201)
#define SCCID_FULLDAYNAME_3         (SCCIDTYPE_STRING | 202)
#define SCCID_FULLDAYNAME_4         (SCCIDTYPE_STRING | 203)
#define SCCID_FULLDAYNAME_5         (SCCIDTYPE_STRING | 204)
#define SCCID_FULLDAYNAME_6         (SCCIDTYPE_STRING | 205)
#define SCCID_FULLDAYNAME_7         (SCCIDTYPE_STRING | 206)

#define SCCID_ABBREVDAYNAME_1       (SCCIDTYPE_STRING | 207)
#define SCCID_ABBREVDAYNAME_2       (SCCIDTYPE_STRING | 208)
#define SCCID_ABBREVDAYNAME_3       (SCCIDTYPE_STRING | 209)
#define SCCID_ABBREVDAYNAME_4       (SCCIDTYPE_STRING | 210)
#define SCCID_ABBREVDAYNAME_5       (SCCIDTYPE_STRING | 211)
#define SCCID_ABBREVDAYNAME_6       (SCCIDTYPE_STRING | 212)
#define SCCID_ABBREVDAYNAME_7       (SCCIDTYPE_STRING | 213)

#define SCCID_FULLMONTHNAME_1       (SCCIDTYPE_STRING | 220)
#define SCCID_FULLMONTHNAME_2       (SCCIDTYPE_STRING | 221)
#define SCCID_FULLMONTHNAME_3       (SCCIDTYPE_STRING | 222)
#define SCCID_FULLMONTHNAME_4       (SCCIDTYPE_STRING | 223)
#define SCCID_FULLMONTHNAME_5       (SCCIDTYPE_STRING | 224)
#define SCCID_FULLMONTHNAME_6       (SCCIDTYPE_STRING | 225)
#define SCCID_FULLMONTHNAME_7       (SCCIDTYPE_STRING | 226)
#define SCCID_FULLMONTHNAME_8       (SCCIDTYPE_STRING | 227)
#define SCCID_FULLMONTHNAME_9       (SCCIDTYPE_STRING | 228)
#define SCCID_FULLMONTHNAME_10      (SCCIDTYPE_STRING | 229)
#define SCCID_FULLMONTHNAME_11      (SCCIDTYPE_STRING | 230)
#define SCCID_FULLMONTHNAME_12      (SCCIDTYPE_STRING | 231)
#define SCCID_FULLMONTHNAME_13      (SCCIDTYPE_STRING | 232)

#define SCCID_ABBREVMONTHNAME_1     (SCCIDTYPE_STRING | 240)
#define SCCID_ABBREVMONTHNAME_2     (SCCIDTYPE_STRING | 241)
#define SCCID_ABBREVMONTHNAME_3     (SCCIDTYPE_STRING | 242)
#define SCCID_ABBREVMONTHNAME_4     (SCCIDTYPE_STRING | 243)
#define SCCID_ABBREVMONTHNAME_5     (SCCIDTYPE_STRING | 244)
#define SCCID_ABBREVMONTHNAME_6     (SCCIDTYPE_STRING | 245)
#define SCCID_ABBREVMONTHNAME_7     (SCCIDTYPE_STRING | 246)
#define SCCID_ABBREVMONTHNAME_8     (SCCIDTYPE_STRING | 247)
#define SCCID_ABBREVMONTHNAME_9     (SCCIDTYPE_STRING | 248)
#define SCCID_ABBREVMONTHNAME_10    (SCCIDTYPE_STRING | 249)
#define SCCID_ABBREVMONTHNAME_11    (SCCIDTYPE_STRING | 250)
#define SCCID_ABBREVMONTHNAME_12    (SCCIDTYPE_STRING | 251)
#define SCCID_ABBREVMONTHNAME_13    (SCCIDTYPE_STRING | 252)

/* Error stings used in display engines */

#define SCCID_INVALIDDATE           (SCCIDTYPE_STRING | 260)
#define SCCID_INVALIDTIME           (SCCIDTYPE_STRING | 261)
#define SCCID_CELLERROR             (SCCIDTYPE_STRING | 262)
#define SCCID_TRUE                  (SCCIDTYPE_STRING | 263)
#define SCCID_FALSE                 (SCCIDTYPE_STRING | 264)
#define SCCID_ARCMSGNODIR           (SCCIDTYPE_STRING | 265)
#define SCCID_ARCMSGOVERWRITE       (SCCIDTYPE_STRING | 266)
#define SCCID_ARCMSGNOFILE          (SCCIDTYPE_STRING | 267)
#define SCCID_ARCMSGFILEENCRYPTED   (SCCIDTYPE_STRING | 268)
#define SCCID_ARCMSGUNKNOWNCOMP     (SCCIDTYPE_STRING | 269)
#define SCCID_ARCMSGUNSUPPORTEDCOMP (SCCIDTYPE_STRING | 270)
#define SCCID_ARCMSGNOSAVE          (SCCIDTYPE_STRING | 271)
#define SCCID_ARCMSGDATAERROR       (SCCIDTYPE_STRING | 272)
#define SCCID_ARCMSGNODECOMP        (SCCIDTYPE_STRING | 273)
#define SCCID_ARCMSGDISKFULL        (SCCIDTYPE_STRING | 274)
#define SCCID_ARCNAME               (SCCIDTYPE_STRING | 275)
#define SCCID_ARCSIZE               (SCCIDTYPE_STRING | 276)
#define SCCID_ARCMODIFIED           (SCCIDTYPE_STRING | 277)
#define SCCID_ARCSTATUSTITLE        (SCCIDTYPE_STRING | 278)
#define SCCID_ARCSAVEDLGTEXT        (SCCIDTYPE_STRING | 279)
#define SCCID_ARCSTOREDDIRS         (SCCIDTYPE_STRING | 280)
#define SCCID_ARCIGNORE             (SCCIDTYPE_STRING | 281)
#define SCCID_ARCRESTORE            (SCCIDTYPE_STRING | 282)

#define SCCID_ARCNONAME             (SCCIDTYPE_STRING | 283)
#define SCCID_ARCSIZEUNKNOWN        (SCCIDTYPE_STRING | 284)
#define SCCID_ARCMSGNAMEUSED        (SCCIDTYPE_STRING | 285)
#define SCCID_ARCCOMMENT            (SCCIDTYPE_STRING | 286)
#define SCCID_ARCTYPE               (SCCIDTYPE_STRING | 287)
#define SCCID_ARCUSER               (SCCIDTYPE_STRING | 288)
#define SCCID_ARCGROUP              (SCCIDTYPE_STRING | 289)
#define SCCID_ARCUSERID             (SCCIDTYPE_STRING | 290)
#define SCCID_ARCGROUPID            (SCCIDTYPE_STRING | 291)

#define SCCID_ARCDLG_BADNAMETITLE   (SCCIDTYPE_STRING | 292)
#define SCCID_ARCDLG_BADNAMETEXT1   (SCCIDTYPE_STRING | 293)
#define SCCID_ARCDLG_BADNAMETEXT2   (SCCIDTYPE_STRING | 294)
#define SCCID_ARCDLG_BADNAMEBOX     (SCCIDTYPE_STRING | 295)
#define SCCID_ARCDLG_BADNAMEOK      (SCCIDTYPE_STRING | 296)
#define SCCID_ARCDLG_BADNAMECANCEL  (SCCIDTYPE_STRING | 297)
#define SCCID_ARCDLG_BADNAMESKIP    (SCCIDTYPE_STRING | 298)
#define SCCID_ARCDLG_CANTWRITE      (SCCIDTYPE_STRING | 299)

#define SCCID_ARCCLASSID            (SCCIDTYPE_STRING | 300)
#define SCCID_YES					(SCCIDTYPE_STRING | 301)
#define SCCID_NO					(SCCIDTYPE_STRING | 302)
#define SCCID_ARCMSGNAMEUSED2       (SCCIDTYPE_STRING | 303)
#define SCCID_ARCEXTRACTING         (SCCIDTYPE_STRING | 304)
#define SCCID_ARCDLG_BADNAMEREPLACE (SCCIDTYPE_STRING | 305)
#define SCCID_ARCDLG_BADNAMEGEN     (SCCIDTYPE_STRING | 306)
#define SCCID_ARCDLG_BADNAMECREATE  (SCCIDTYPE_STRING | 307)

#define SCCID_ARCNODELOCATOR        (SCCIDTYPE_STRING | 308)
#define SCCID_DXL_NOTEID            (SCCIDTYPE_STRING | 309)
#define SCCID_DXL_NOTEUNIID         (SCCIDTYPE_STRING | 310)

#define SCCID_SCALE_HUNDREDS        (SCCIDTYPE_STRING | 311)
#define SCCID_SCALE_THOUSANDS       (SCCIDTYPE_STRING | 312)
#define SCCID_SCALE_MILLIONS        (SCCIDTYPE_STRING | 313)
#define SCCID_SCALE_BILLIONS        (SCCIDTYPE_STRING | 314)
#define SCCID_SCALE_TRILLIONS       (SCCIDTYPE_STRING | 315)
#define SCCID_SCALE_HUNDREDTHS      (SCCIDTYPE_STRING | 316)
#define SCCID_SCALE_THOUSANDTHS     (SCCIDTYPE_STRING | 317)
#define SCCID_SCALE_MILLIONTHS      (SCCIDTYPE_STRING | 318)
#define SCCID_SCALE_BILLIONTHS      (SCCIDTYPE_STRING | 319)
#define SCCID_SCALE_TRILLIONTHS     (SCCIDTYPE_STRING | 320)


/*Strings used in the BAD NAME dialog box*/

#define SCCID_ARCDLG_FILENAME		(SCCIDTYPE_STRING | 500)
#define SCCID_ARCDLG_BADNAMETEXT3   (SCCIDTYPE_STRING | 501)
#define SCCID_ARCDLG_BADNAMETEXT4   (SCCIDTYPE_STRING | 502)
#define SCCID_ARCDLG_YES            (SCCIDTYPE_STRING | 503)
#define SCCID_ARCDLG_NO             (SCCIDTYPE_STRING | 504)
#define SCCID_ARCDLG_RENAME         (SCCIDTYPE_STRING | 505)

/*
|  Special case for the names of files formats.
|  The SCCID for each FI ID can be generated by
|  ORing SCCIDTYPE_STRING with the FI ID.
|  For example the string ID for the text "Excel 5.0"
|  is (SCCIDTYPE_STRING | FI_EXCEL5)
|
|  For this reason the following range of String IDs
|  is reserved for FI use
|
|  SCCIDTYPE_STRING | 1000
|  through
|  SCCIDTYPE_STRING | 9999
|
*/

#define SCCID_BEGIN_FI_RESERVED  1000
#define SCCID_END_FI_RESERVED  9999

/*
|  The each of the following IDs serve a dual role of being unique ID of a list
|  and the ID to the sting that describes the list
*/

/*These are the real list IDs and correspond to the BIN file name for Win16 & Win32s*/
#define SCCID_FILTERLIST           (SCCIDTYPE_STRING | SCCIDTYPE_LIST | 10000)
#define SCCID_DELIST               (SCCIDTYPE_STRING | SCCIDTYPE_LIST | 10001)

/*These are the registry strings for the lists above, Reg entry ID = List ID+10 */
#define SCCID_FILTERLISTREG       (SCCIDTYPE_STRING | SCCIDTYPE_LIST | 10010)
#define SCCID_DELISTREG           (SCCIDTYPE_STRING | SCCIDTYPE_LIST | 10011)

/* Directory containing user specific files. For example filter lists on Unix. */
#define SCCID_USER_DIR            (SCCIDTYPE_STRING | 10020)

/* Used to set/get the name of the resource (LO) DLL to use */
#define SCCID_RESOURCELIBRARYID   (SCCIDTYPE_STRING | 10030)

/*
|  The each of the following IDs serve a dual role of being unique ID of an option
|  and the ID to the string that describes the option
*/

#define SCCID_DEFAULTDISPLAYFONT      (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10100)
#define SCCID_PRINTHEADER             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10101)
#define SCCID_DEFAULTPRINTMARGINS     (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10102)
#define SCCID_DEFAULTPRINTFONT        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10103)
#define SCCID_PRINTHEADERFONT         (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10104)
#define SCCID_FALLBACKFORMAT          (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10105)
#define SCCID_PRINTINFO               (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10106)
#define SCCID_PRINTJOBNAME            (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10107)
#define SCCID_WHATTOPRINT             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10108)
#define SCCID_PRINTSTARTPAGE          (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10109)
#define SCCID_PRINTENDPAGE            (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10110)
#define SCCID_PRINTCOLLATE            (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10111)
#define SCCID_PRINTCOPIES             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10112)
#define SCCID_HAVESELECTION           (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10113)
#define SCCID_USEDOCPAGESETTINGS      (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10114)

/*
|  Font options (scaling and aliasing)
*/
#define SCCID_FONTSCALINGFACTOR       (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10115)
#define SCCID_DISPLAYFONTALIAS        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10116)
#define SCCID_PRINTFONTALIAS              (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10117)
#define SCCID_ORIGFONTSCALINGFACTOR   (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10118)
#define SCCID_FONTFILTER				(SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10119)
/*
|  Document options
*/

#define SCCID_WPDISPLAYMODE        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10201)
#define SCCID_WPZOOM               (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10205)
#define SCCID_WPFITMODE            (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10206)
#define SCCID_WPWRAPTOWINDOW       (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10207)
#define SCCID_WPPRINTMODE          (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10208)
#define SCCID_WPDISABLEHYPERLINKS  (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10209)
#define SCCID_WPDISABLEPOSITIONALFRAMES (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10210)
#define SCCID_WPDISABLEEMAILHEADER (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10211)
/* depreciating SCCID_WPMIMEHEADEROUTPUT, but leaving it for backward compatibility */
#define SCCID_WPMIMEHEADEROUTPUT   (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10212)
#define SCCID_WPEMAILHEADEROUTPUT  (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10212)

/*
|  Document strings
*/

#define SCCID_WPDATECHAR              (SCCIDTYPE_STRING | 10202)
#define SCCID_WPTIMECHAR              (SCCIDTYPE_STRING | 10203)
#define SCCID_WPPAGENUMCHAR           (SCCIDTYPE_STRING | 10204)
#define SCCID_WPPAGE                  (SCCIDTYPE_STRING | 10205)
#define SCCID_PRINTHEADERPAGE         (SCCIDTYPE_STRING | 10206)
#define SCCID_WPEMAILOVERFLOW		  (SCCIDTYPE_STRING | 10207)

/*
|  Bitmap options
*/

#define SCCID_BMPROTATION             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10300)
#define SCCID_BMPPRINTASPECT          (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10310)
#define SCCID_BMPPRINTBORDER          (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10311)
#define SCCID_BMPDITHER               (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10312)
#define SCCID_BMPFITMODE              (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10313)
#define SCCID_BMPZOOM                 (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10314)
#define SCCID_BMPSHOWFULLSCREEN       (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10315)
#define SCCID_BMPZOOMEVENT            (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10316)
#define SCCID_BMPDITHERAVAILABLE      (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10317)

/*
|  Vector options
*/

#define SCCID_VECPRINTASPECT          (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10401)
#define SCCID_VECPRINTBORDER          (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10402)
#define SCCID_VECFITMODE              (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10403)
#define SCCID_VECZOOM                 (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10404)
#define SCCID_VECSHOWFULLSCREEN       (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10405)
#define SCCID_VECZOOMEVENT            (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10406)
#define SCCID_VECSHOWBACKGROUND       (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10407)
#define SCCID_VECPRINTBACKGROUND      (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10408)
/*
|   Quick View option. (may be extended to QVP) Set based on SCCID_QUICKVIEWDRAFT/DRAFTPRINT.
|   Both Draft and Draft Print have the same effect on MET.
|   Draft mode for presentations/charts/metafiles.
|   Implies no embeddings, no gradients, no textures.
*/
#define SCCID_VECDRAFTMODE            (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10409)

/*
|  Spreadsheet options
*/

#define SCCID_SSSHOWGRIDLINES         (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10501)
#define SCCID_SSPRINTGRIDLINES        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10502)
#define SCCID_SSPRINTHEADINGS         (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10503)
#define SCCID_SSCLIPBOARD             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10504)
#define SCCID_SSBADTYPE               (SCCIDTYPE_STRING | 10506)
#define SCCID_SSDRAFTMODE             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10507)
#define SCCID_SSPRINTFITTOPAGE        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10508)
#define SCCID_SSPRINTSCALEPERCENT     (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10509)
#define SCCID_SSPRINTSCALEXHIGH       (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10510)
#define SCCID_SSPRINTSCALEXWIDE       (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10511)
#define SCCID_SSPRINTDIRECTION        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10512)
#define SCCID_SSSHOWHEADINGS          (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10513)
#define SCCID_SS4DIGITDATES           (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10514)
#define SCCID_SSSHOWHIDDENCELLS       (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10515)
/*
|  Database options
*/

#define SCCID_DBSHOWGRIDLINES         (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10601)
#define SCCID_DBPRINTGRIDLINES        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10602)
#define SCCID_DBPRINTHEADINGS         (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10603)
#define SCCID_DBCLIPBOARD             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10604)
#define SCCID_DBFIELDNAMESTOCLIP      (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10605)
#define SCCID_DBDRAFTMODE             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10606)
#define SCCID_DBPRINTFITTOPAGE        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10607)

/*
|  Clipboard options
*/

#define SCCID_TOCLIPBOARD             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10701)
#define SCCID_DEFAULTCLIPBOARDFONT    (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10702)

/*
|  System options
*/

#define SCCID_DIALOGFLAGS             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10801)
#define SCCID_SYSTEMFLAGS             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10802)
#define SCCID_INTLFLAGS               (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10803)
#define SCCID_SCROLLFLAGS             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10804)
#define SCCID_OLEFLAGS                (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10805)
#define SCCID_FIFLAGS                 (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10806)
#define SCCID_TEMPDIR                 (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10807)
#define SCCID_NATIVEFILTERFLAG        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10808)
#define SCCID_TEMPFUNC                (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10809)
#define SCCID_DOCUMENTMEMORYMODE	  (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10810)

#define SCCID_RENDERING_PREFER_OIT    (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10821)


/* compression licensing options (to disable patented methods) */

#define SCCID_FILTERLZW				(SCCIDTYPE_OPTION | 11102)
#define SCCID_FILTERJPG				(SCCIDTYPE_OPTION | 11103)

/* Ignore the password verification in PST files */
#define SCCID_IGNORE_PASSWORD (SCCIDTYPE_OPTION | 11109)

/* Option to turn off pagebreaks... For example, on very large system dumps. Used by the text filter. */
#define SCCID_ASCIIFILTERPAGEOFF			(SCCIDTYPE_OPTION | 11108)

/* Excel option to disable putting out blank cells after last valid data cell */
#define SCCID_FILTERNOBLANK			(SCCIDTYPE_OPTION | 11104)

/* antialiasing options */
#define SCCID_ANTIALIAS             (SCCIDTYPE_OPTION | 11110)

/* Option to enable output of full TIFF/EXIF properties */
#define SCCID_FILTEREXIFFULL        (SCCIDTYPE_OPTION | 11106)

/* Option to communicate with the performance filter */
#define SCCID_FILTERRESERVED        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 11107)

/* Generic bit field for flags applicable to a wide range of products.  ISO formatting of Date/Times for example.  */
#define SCCID_FORMATFLAGS			(SCCIDTYPE_OPTION | 11120)

/*
|  Archive options
*/

#define SCCID_ARCSAVEEVENT            (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10901)
#define SCCID_ARCSORTORDER            (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10902)
#define SCCID_ARCORIGFORMAT           (SCCIDTYPE_STRING | 10903)
#define SCCID_ARCCHOOSEDIR            (SCCIDTYPE_STRING | 10904)
#define SCCID_ARCOUTPUTPATH           (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10905)
#define SCCID_ARCFLAGS                (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10906)
#define SCCID_ARCSAVETHIS             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10907)
#define SCCID_ARCVIEWTHIS             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10908)
#define SCCID_ARCFULLPATH             (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10909)
#define SCCID_ARCRENAME               (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 10910)


/*
|  International options
*/

#define SCCID_NUMBERFORMAT            (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 11001)
#define SCCID_DAYNAMES                (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 11002)
#define SCCID_MONTHNAMES              (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 11003)

#define SCCID_TIMEZONE              (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 11011)

/*
|  Bidirectional text options
*/

#define SCCID_REORDERMETHOD           (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 11051)


/*
|  Filter options
*/

#define SCCID_FILTERPERFORMANCE       (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 11101)
#define SCCID_ENABLEALLSUBOBJECTS     (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 11105)
#define SCCID_PARSEXMPMETADATA        (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 11106)
#define SCCID_PDF_FILTER_REORDER_BIDI (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 11111)

/*
|  Section default titles (created by chunker)
*/

#define SCCID_DLGDOCUMENT             (SCCIDTYPE_STRING | 12001)
#define SCCID_DLGSHEET                (SCCIDTYPE_STRING | 12002)
#define SCCID_DLGIMAGE                (SCCIDTYPE_STRING | 12003)
#define SCCID_DLGDATABASE             (SCCIDTYPE_STRING | 12004)
#define SCCID_DLGARCHIVE              (SCCIDTYPE_STRING | 12005)
#define SCCID_DLGCURRENT              (SCCIDTYPE_STRING | 12006)
#define SCCID_DLGSLIDE                (SCCIDTYPE_STRING | 12007)
#define SCCID_DLGCHART                (SCCIDTYPE_STRING | 12008)

#define SCCID_HARDOPTIONS            (SCCIDTYPE_STRING | 13000)

/*
|  Strings used by filters
*/
#define  SCCID_DXF_ISOMETRIC        (SCCIDTYPE_STRING | 13050)
#define  SCCID_DXF_PLAN             (SCCIDTYPE_STRING | 13051)
#define  SCCID_DXF_FRONT            (SCCIDTYPE_STRING | 13052)
#define  SCCID_DXF_RIGHT            (SCCIDTYPE_STRING | 13053)
#define  SCCID_DXF_DEFAULTVIEW      (SCCIDTYPE_STRING | 13054)
#define  SCCID_DXF_ACTIVEVIEW       (SCCIDTYPE_STRING | 13055)

#define  SCCID_TEXT_UUENCODE        (SCCIDTYPE_STRING | 13056)
#define  SCCID_TEXT_XXENCODE        (SCCIDTYPE_STRING | 13057)
#define  SCCID_TEXT_BASE64ENCODE    (SCCIDTYPE_STRING | 13058)

#define  SCCID_CCOD_GENERATOR       (SCCIDTYPE_STRING | 13059)

/*
|  Strings used by EXE filter
*/

#define  SCCID_EXE_OLDHEADER        (SCCIDTYPE_STRING | 13100)
#define  SCCID_EXE_TECHINFO         (SCCIDTYPE_STRING | 13101)
#define  SCCID_EXE_LOADHI           (SCCIDTYPE_STRING | 13102)
#define  SCCID_EXE_DLLFILE          (SCCIDTYPE_STRING | 13103)
#define  SCCID_EXE_WINEXE           (SCCIDTYPE_STRING | 13104)
#define  SCCID_EXE_LIBRARY          (SCCIDTYPE_STRING | 13105)
#define  SCCID_EXE_OPSYSOS2         (SCCIDTYPE_STRING | 13106)
#define  SCCID_EXE_OPSYSWIN         (SCCIDTYPE_STRING | 13107)
#define  SCCID_EXE_OPSYSDOS         (SCCIDTYPE_STRING | 13108)
#define  SCCID_EXE_OPSYSWIN386      (SCCIDTYPE_STRING | 13109)
#define  SCCID_EXE_UNKNOWN          (SCCIDTYPE_STRING | 13110)
#define  SCCID_EXE_SUPPORTLONG      (SCCIDTYPE_STRING | 13111)
#define  SCCID_EXE_PROTECTMODE      (SCCIDTYPE_STRING | 13112)
#define  SCCID_EXE_PROPFONT         (SCCIDTYPE_STRING | 13113)
#define  SCCID_EXE_FASTLOAD         (SCCIDTYPE_STRING | 13114)
#define  SCCID_EXE_BIT              (SCCIDTYPE_STRING | 13115)
#define  SCCID_EXE_OFFSET           (SCCIDTYPE_STRING | 13116)
#define  SCCID_EXE_LENGTH           (SCCIDTYPE_STRING | 13117)
#define  SCCID_EXE_ENTRIES          (SCCIDTYPE_STRING | 13119)
#define  SCCID_EXE_SEGMENTS         (SCCIDTYPE_STRING | 13120)
#define  SCCID_EXE_BYTES            (SCCIDTYPE_STRING | 13121)
#define  SCCID_EXE_SINGLEDATA       (SCCIDTYPE_STRING | 13122)
#define  SCCID_EXE_MULTIDATA        (SCCIDTYPE_STRING | 13123)
#define  SCCID_EXE_PROTMODE         (SCCIDTYPE_STRING | 13124)
#define  SCCID_EXE_NOTCOMPT         (SCCIDTYPE_STRING | 13125)
#define  SCCID_EXE_WINAPI           (SCCIDTYPE_STRING | 13126)
#define  SCCID_EXE_COMPT            (SCCIDTYPE_STRING | 13127)
#define  SCCID_EXE_SEGLOADER        (SCCIDTYPE_STRING | 13128)
#define  SCCID_EXE_LINKERR          (SCCIDTYPE_STRING | 13129)
#define  SCCID_EXE_EMSBANK          (SCCIDTYPE_STRING | 13130)
#define  SCCID_EXE_PREINIT          (SCCIDTYPE_STRING | 13131)
#define  SCCID_EXE_GLOBINIT         (SCCIDTYPE_STRING | 13132)
#define  SCCID_EXE_ISSET            (SCCIDTYPE_STRING | 13133)
#define  SCCID_EXE_SEGTABLE         (SCCIDTYPE_STRING | 13134)
#define  SCCID_EXE_NUM              (SCCIDTYPE_STRING | 13135)
#define  SCCID_EXE_TYPE             (SCCIDTYPE_STRING | 13136)
#define  SCCID_EXE_OFFSETCAP        (SCCIDTYPE_STRING | 13137)
#define  SCCID_EXE_LENGTHCAP        (SCCIDTYPE_STRING | 13138)
#define  SCCID_EXE_ALLOC            (SCCIDTYPE_STRING | 13139)
#define  SCCID_EXE_FLAGS            (SCCIDTYPE_STRING | 13140)
#define  SCCID_EXE_SMTYPE           (SCCIDTYPE_STRING | 13141)
#define  SCCID_EXE_DATA             (SCCIDTYPE_STRING | 13142)
#define  SCCID_EXE_CODE             (SCCIDTYPE_STRING | 13143)
#define  SCCID_EXE_READONLY         (SCCIDTYPE_STRING | 13144)
#define  SCCID_EXE_EXEONLY          (SCCIDTYPE_STRING | 13145)
#define  SCCID_EXE_READWRITE        (SCCIDTYPE_STRING | 13146)
#define  SCCID_EXE_EXEREAD          (SCCIDTYPE_STRING | 13147)
#define  SCCID_EXE_SHARED           (SCCIDTYPE_STRING | 13148)
#define  SCCID_EXE_NONSHARED        (SCCIDTYPE_STRING | 13149)
#define  SCCID_EXE_PRELOAD          (SCCIDTYPE_STRING | 13150)
#define  SCCID_EXE_LOADONCALL       (SCCIDTYPE_STRING | 13151)
#define  SCCID_EXE_EXPDOWN          (SCCIDTYPE_STRING | 13152)
#define  SCCID_EXE_NOEXPDOWN        (SCCIDTYPE_STRING | 13153)
#define  SCCID_EXE_CONFORM          (SCCIDTYPE_STRING | 13154)
#define  SCCID_EXE_NONCONFORM       (SCCIDTYPE_STRING | 13155)
#define  SCCID_EXE_NOIOPL           (SCCIDTYPE_STRING | 13156)
#define  SCCID_EXE_IOPL             (SCCIDTYPE_STRING | 13157)
#define  SCCID_EXE_286DPL           (SCCIDTYPE_STRING | 13158)
#define  SCCID_EXE_32BIT            (SCCIDTYPE_STRING | 13159)
#define  SCCID_EXE_HUGE             (SCCIDTYPE_STRING | 13160)
#define  SCCID_EXE_RELOCS           (SCCIDTYPE_STRING | 13161)
#define  SCCID_EXE_ITERATE          (SCCIDTYPE_STRING | 13162)
#define  SCCID_EXE_MOVEABLE         (SCCIDTYPE_STRING | 13163)
#define  SCCID_EXE_FIXED            (SCCIDTYPE_STRING | 13164)
#define  SCCID_EXE_DISCARD          (SCCIDTYPE_STRING | 13165)
#define  SCCID_EXE_NONDISCARD       (SCCIDTYPE_STRING | 13166)
#define  SCCID_EXE_SMSHARED         (SCCIDTYPE_STRING | 13167)
#define  SCCID_EXE_SMNONSHARED      (SCCIDTYPE_STRING | 13168)
#define  SCCID_EXE_RESEXPORT        (SCCIDTYPE_STRING | 13169)
#define  SCCID_EXE_NONRESEXPORT     (SCCIDTYPE_STRING | 13170)
#define  SCCID_EXE_ENTRYTABLE       (SCCIDTYPE_STRING | 13171)
#define  SCCID_EXE_NAME             (SCCIDTYPE_STRING | 13172)
#define  SCCID_EXE_IMPORTTABLE      (SCCIDTYPE_STRING | 13173)
#define  SCCID_EXE_WIN16EXE         (SCCIDTYPE_STRING | 13174)
#define  SCCID_EXE_WIN32EXE         (SCCIDTYPE_STRING | 13175)
#define  SCCID_EXE_IMOPTHEADER      (SCCIDTYPE_STRING | 13176)
#define  SCCID_EXE_INTEL860         (SCCIDTYPE_STRING | 13177)
#define  SCCID_EXE_INTEL386         (SCCIDTYPE_STRING | 13178)
#define  SCCID_EXE_MIPS             (SCCIDTYPE_STRING | 13179)
#define  SCCID_EXE_DECALPHA         (SCCIDTYPE_STRING | 13180)
#define  SCCID_EXE_RELOCSTRIPPED    (SCCIDTYPE_STRING | 13181)
#define  SCCID_EXE_EXEFILE          (SCCIDTYPE_STRING | 13182)
#define  SCCID_EXE_LINESTRIPPED     (SCCIDTYPE_STRING | 13183)
#define  SCCID_EXE_LOCSTRIPPED      (SCCIDTYPE_STRING | 13184)
#define  SCCID_EXE_16BITWORD        (SCCIDTYPE_STRING | 13185)
#define  SCCID_EXE_LOWBYTEREV       (SCCIDTYPE_STRING | 13186)
#define  SCCID_EXE_32BITWORD        (SCCIDTYPE_STRING | 13187)
#define  SCCID_EXE_DBGSTRIPPED      (SCCIDTYPE_STRING | 13188)
#define  SCCID_EXE_SYSFILE          (SCCIDTYPE_STRING | 13189)
#define  SCCID_EXE_FILEISDLL        (SCCIDTYPE_STRING | 13190)
#define  SCCID_EXE_HIBYTEREV        (SCCIDTYPE_STRING | 13191)
#define  SCCID_EXE_UNKSUBSYS        (SCCIDTYPE_STRING | 13192)
#define  SCCID_EXE_NOSUBSYSREQ      (SCCIDTYPE_STRING | 13193)
#define  SCCID_EXE_GUISUBSYS        (SCCIDTYPE_STRING | 13194)
#define  SCCID_EXE_WINSUBSYS        (SCCIDTYPE_STRING | 13195)
#define  SCCID_EXE_OS2SUBSYS        (SCCIDTYPE_STRING | 13196)
#define  SCCID_EXE_POSIXSUBSYS      (SCCIDTYPE_STRING | 13197)
#define  SCCID_EXE_DLLINITROUT      (SCCIDTYPE_STRING | 13198)
#define  SCCID_EXE_DLLTHRDTERM      (SCCIDTYPE_STRING | 13199)
#define  SCCID_EXE_DLLTHRDINIT      (SCCIDTYPE_STRING | 13200)
#define  SCCID_EXE_BREAKONLOAD      (SCCIDTYPE_STRING | 13201)
#define  SCCID_EXE_DEBUGONLOAD      (SCCIDTYPE_STRING | 13202)
#define  SCCID_EXE_EXPORTVADDR      (SCCIDTYPE_STRING | 13203)
#define  SCCID_EXE_EXPORTSIZE       (SCCIDTYPE_STRING | 13204)
#define  SCCID_EXE_IMPORTVADDR      (SCCIDTYPE_STRING | 13205)
#define  SCCID_EXE_IMPORTSIZE       (SCCIDTYPE_STRING | 13206)
#define  SCCID_EXE_RESOURCEDIR      (SCCIDTYPE_STRING | 13207)
#define  SCCID_EXE_VADDRESS         (SCCIDTYPE_STRING | 13208)
#define  SCCID_EXE_RESOURCESIZ      (SCCIDTYPE_STRING | 13209)
#define  SCCID_EXE_EXCEPTVADDR      (SCCIDTYPE_STRING | 13210)
#define  SCCID_EXE_EXCEPTSIZE       (SCCIDTYPE_STRING | 13211)
#define  SCCID_EXE_SECURVADDR       (SCCIDTYPE_STRING | 13212)
#define  SCCID_EXE_SECURSIZE        (SCCIDTYPE_STRING | 13213)
#define  SCCID_EXE_BASERELOC        (SCCIDTYPE_STRING | 13214)
#define  SCCID_EXE_BASESIZE         (SCCIDTYPE_STRING | 13215)
#define  SCCID_EXE_DEBUGVADDR       (SCCIDTYPE_STRING | 13216)
#define  SCCID_EXE_DEBUGSIZE        (SCCIDTYPE_STRING | 13217)
#define  SCCID_EXE_COPYVADDR        (SCCIDTYPE_STRING | 13218)
#define  SCCID_EXE_COPYSIZE         (SCCIDTYPE_STRING | 13219)
#define  SCCID_EXE_MIPSVADDR        (SCCIDTYPE_STRING | 13220)
#define  SCCID_EXE_MIPSSIZE         (SCCIDTYPE_STRING | 13221)
#define  SCCID_EXE_TLSVADDR         (SCCIDTYPE_STRING | 13222)
#define  SCCID_EXE_TLSSIZE          (SCCIDTYPE_STRING | 13223)
#define  SCCID_EXE_LOADVADDR        (SCCIDTYPE_STRING | 13224)
#define  SCCID_EXE_LOADSIZE         (SCCIDTYPE_STRING | 13225)
#define  SCCID_EXE_EDATA            (SCCIDTYPE_STRING | 13226)
#define  SCCID_EXE_IDATA            (SCCIDTYPE_STRING | 13227)
#define  SCCID_EXE_NOEXPFUNC        (SCCIDTYPE_STRING | 13228)
#define  SCCID_EXE_ORDINAL          (SCCIDTYPE_STRING | 13229)
#define  SCCID_EXE_EXTRYPT          (SCCIDTYPE_STRING | 13230)
#define  SCCID_EXE_FUNCNAME         (SCCIDTYPE_STRING | 13232)
#define  SCCID_EXE_CODESECT         (SCCIDTYPE_STRING | 13233)
#define  SCCID_EXE_IDATASECT        (SCCIDTYPE_STRING | 13234)
#define  SCCID_EXE_UNIDATASECT      (SCCIDTYPE_STRING | 13235)
#define  SCCID_EXE_COMMENTSECT      (SCCIDTYPE_STRING | 13236)
#define  SCCID_EXE_OVRLAYSECT       (SCCIDTYPE_STRING | 13237)
#define  SCCID_EXE_NOTPARTSECT      (SCCIDTYPE_STRING | 13238)
#define  SCCID_EXE_COMDATSECT       (SCCIDTYPE_STRING | 13239)
#define  SCCID_EXE_DISCARDSECT      (SCCIDTYPE_STRING | 13240)
#define  SCCID_EXE_NOCACHSECT       (SCCIDTYPE_STRING | 13241)
#define  SCCID_EXE_NOPAGESECT       (SCCIDTYPE_STRING | 13242)
#define  SCCID_EXE_SHARESECT        (SCCIDTYPE_STRING | 13243)
#define  SCCID_EXE_EXESECT          (SCCIDTYPE_STRING | 13244)
#define  SCCID_EXE_READSECT         (SCCIDTYPE_STRING | 13245)
#define  SCCID_EXE_WRITESECT        (SCCIDTYPE_STRING | 13246)
#define  SCCID_EXE_IA64             (SCCIDTYPE_STRING | 13247)

#define  SCCID_EXE_R10000           (SCCIDTYPE_STRING | 13248)
#define  SCCID_EXE_WCEMIPSV2        (SCCIDTYPE_STRING | 13249)
#define  SCCID_EXE_SH3              (SCCIDTYPE_STRING | 13250)
#define  SCCID_EXE_SH3DSP           (SCCIDTYPE_STRING | 13251)
#define  SCCID_EXE_SH3E             (SCCIDTYPE_STRING | 13252)
#define  SCCID_EXE_SH4              (SCCIDTYPE_STRING | 13253)
#define  SCCID_EXE_SH5              (SCCIDTYPE_STRING | 13254)
#define  SCCID_EXE_ARM              (SCCIDTYPE_STRING | 13255)
#define  SCCID_EXE_THUMB            (SCCIDTYPE_STRING | 13256)
#define  SCCID_EXE_AM33             (SCCIDTYPE_STRING | 13257)
#define  SCCID_EXE_POWERPC          (SCCIDTYPE_STRING | 13258)
#define  SCCID_EXE_POWERPCFP        (SCCIDTYPE_STRING | 13259)
#define  SCCID_EXE_MIPS16           (SCCIDTYPE_STRING | 13260)
#define  SCCID_EXE_ALPHA64          (SCCIDTYPE_STRING | 13261)
#define  SCCID_EXE_MIPSFPU          (SCCIDTYPE_STRING | 13262)
#define  SCCID_EXE_MIPSFPU16        (SCCIDTYPE_STRING | 13263)
#define  SCCID_EXE_TRICORE          (SCCIDTYPE_STRING | 13264)
#define  SCCID_EXE_CEF              (SCCIDTYPE_STRING | 13265)
#define  SCCID_EXE_EBC              (SCCIDTYPE_STRING | 13266)
#define  SCCID_EXE_AMD64            (SCCIDTYPE_STRING | 13267)
#define  SCCID_EXE_M32R             (SCCIDTYPE_STRING | 13268)
#define  SCCID_EXE_CEE              (SCCIDTYPE_STRING | 13269)
#define  SCCID_EXE_WIN64EXE         (SCCIDTYPE_STRING | 13270)
#define  SCCID_EXE_MIPS4000         (SCCIDTYPE_STRING | 13271)

#define  SCCID_EXEINIT_HEADERINFO        (SCCIDTYPE_STRING | 13500)
#define  SCCID_EXEINIT_SIGNATURE         (SCCIDTYPE_STRING | 13501)
#define  SCCID_EXEINIT_LASTPAGE          (SCCIDTYPE_STRING | 13502)
#define  SCCID_EXEINIT_TOTPAGES          (SCCIDTYPE_STRING | 13503)
#define  SCCID_EXEINIT_RELOCITEMS        (SCCIDTYPE_STRING | 13504)
#define  SCCID_EXEINIT_PARAINHEAD        (SCCIDTYPE_STRING | 13505)
#define  SCCID_EXEINIT_MINPARA           (SCCIDTYPE_STRING | 13506)
#define  SCCID_EXEINIT_MAXPARA           (SCCIDTYPE_STRING | 13507)
#define  SCCID_EXEINIT_INITSS            (SCCIDTYPE_STRING | 13508)
#define  SCCID_EXEINIT_INITSP            (SCCIDTYPE_STRING | 13509)
#define  SCCID_EXEINIT_COMPCHKSUM        (SCCIDTYPE_STRING | 13510)
#define  SCCID_EXEINIT_INITIP            (SCCIDTYPE_STRING | 13511)
#define  SCCID_EXEINIT_INITCODE          (SCCIDTYPE_STRING | 13512)
#define  SCCID_EXEINIT_RELOCTABLE        (SCCIDTYPE_STRING | 13513)
#define  SCCID_EXEINIT_OVERNUM           (SCCIDTYPE_STRING | 13514)
#define  SCCID_EXEINIT_RESERVED          (SCCIDTYPE_STRING | 13515)
#define  SCCID_EXEINIT_OFFSET2HDR        (SCCIDTYPE_STRING | 13516)
#define  SCCID_EXEINIT_MEMNEEDED         (SCCIDTYPE_STRING | 13517)
#define  SCCID_EXEINIT_GENINFO           (SCCIDTYPE_STRING | 13518)
#define  SCCID_EXEINIT_MODNAME           (SCCIDTYPE_STRING | 13519)
#define  SCCID_EXEINIT_DESCRIP           (SCCIDTYPE_STRING | 13520)
#define  SCCID_EXEINIT_OS                (SCCIDTYPE_STRING | 13521)
#define  SCCID_EXEINIT_LINKVER           (SCCIDTYPE_STRING | 13522)
#define  SCCID_EXEINIT_CHECKSUM          (SCCIDTYPE_STRING | 13523)
#define  SCCID_EXEINIT_ADS               (SCCIDTYPE_STRING | 13524)
#define  SCCID_EXEINIT_INITHS            (SCCIDTYPE_STRING | 13525)
#define  SCCID_EXEINIT_INITCSIP          (SCCIDTYPE_STRING | 13527)
#define  SCCID_EXEINIT_INITCSSP          (SCCIDTYPE_STRING | 13528)
#define  SCCID_EXEINIT_ADDNFO            (SCCIDTYPE_STRING | 13529)
#define  SCCID_EXEINIT_FLOADSTART        (SCCIDTYPE_STRING | 13530)
#define  SCCID_EXEINIT_FLOADLEN          (SCCIDTYPE_STRING | 13531)
#define  SCCID_EXEINIT_WINVER            (SCCIDTYPE_STRING | 13532)
#define  SCCID_EXEINIT_ENTRYTABLE        (SCCIDTYPE_STRING | 13533)
#define  SCCID_EXEINIT_SEGTABLE          (SCCIDTYPE_STRING | 13534)
#define  SCCID_EXEINIT_RESOURCETABLE     (SCCIDTYPE_STRING | 13535)
#define  SCCID_EXEINIT_RESTABLENAME      (SCCIDTYPE_STRING | 13536)
#define  SCCID_EXEINIT_MODULEREF         (SCCIDTYPE_STRING | 13537)
#define  SCCID_EXEINIT_IMPORTEDTABLE     (SCCIDTYPE_STRING | 13538)
#define  SCCID_EXEINIT_NONRESTABLE       (SCCIDTYPE_STRING | 13539)
#define  SCCID_EXEINIT_MOVEENPT          (SCCIDTYPE_STRING | 13540)
#define  SCCID_EXEINIT_ALIGN             (SCCIDTYPE_STRING | 13541)
#define  SCCID_EXEINIT_FLAGS             (SCCIDTYPE_STRING | 13542)
#define  SCCID_EXEINIT_IMAGEHEADER       (SCCIDTYPE_STRING | 13543)
#define  SCCID_EXEINIT_MACHINE           (SCCIDTYPE_STRING | 13544)
#define  SCCID_EXEINIT_NUMSECTION        (SCCIDTYPE_STRING | 13545)
#define  SCCID_EXEINIT_PSYMBOL           (SCCIDTYPE_STRING | 13546)
#define  SCCID_EXEINIT_NUMSYMBOL         (SCCIDTYPE_STRING | 13547)
#define  SCCID_EXEINIT_SIZOPHEAD         (SCCIDTYPE_STRING | 13548)
#define  SCCID_EXEINIT_MAGIC             (SCCIDTYPE_STRING | 13549)
#define  SCCID_EXEINIT_SIZECODE          (SCCIDTYPE_STRING | 13551)
#define  SCCID_EXEINIT_SIZINITDATA       (SCCIDTYPE_STRING | 13552)
#define  SCCID_EXEINIT_SIZUNITDATA       (SCCIDTYPE_STRING | 13553)
#define  SCCID_EXEINIT_ADDRENTRY         (SCCIDTYPE_STRING | 13554)
#define  SCCID_EXEINIT_BASECODE          (SCCIDTYPE_STRING | 13555)
#define  SCCID_EXEINIT_BASEDATA          (SCCIDTYPE_STRING | 13556)
#define  SCCID_EXEINIT_IMAGEBASE         (SCCIDTYPE_STRING | 13557)
#define  SCCID_EXEINIT_SECTALIGN         (SCCIDTYPE_STRING | 13558)
#define  SCCID_EXEINIT_FILEALIGN         (SCCIDTYPE_STRING | 13559)
#define  SCCID_EXEINIT_OSVER             (SCCIDTYPE_STRING | 13560)
#define  SCCID_EXEINIT_IMAGEVER          (SCCIDTYPE_STRING | 13561)
#define  SCCID_EXEINIT_SUBSYSVER         (SCCIDTYPE_STRING | 13562)
#define  SCCID_EXEINIT_RESERVED1         (SCCIDTYPE_STRING | 13563)
#define  SCCID_EXEINIT_SIZEIMAGE         (SCCIDTYPE_STRING | 13564)
#define  SCCID_EXEINIT_SIZEHEAD          (SCCIDTYPE_STRING | 13565)
#define  SCCID_EXEINIT_SUBSYS            (SCCIDTYPE_STRING | 13567)
#define  SCCID_EXEINIT_DLLCHAR           (SCCIDTYPE_STRING | 13568)
#define  SCCID_EXEINIT_SIZESTKR          (SCCIDTYPE_STRING | 13569)
#define  SCCID_EXEINIT_SIZESTKC          (SCCIDTYPE_STRING | 13570)
#define  SCCID_EXEINIT_SIZEHEAPR         (SCCIDTYPE_STRING | 13571)
#define  SCCID_EXEINIT_SIZEHEAPC         (SCCIDTYPE_STRING | 13572)
#define  SCCID_EXEINIT_LOADFLAG          (SCCIDTYPE_STRING | 13573)
#define  SCCID_EXEINIT_SIZEDDIR          (SCCIDTYPE_STRING | 13574)
#define  SCCID_EXEINIT_DATADIR           (SCCIDTYPE_STRING | 13575)
#define  SCCID_EXEINIT_SECTTABLE         (SCCIDTYPE_STRING | 13576)
#define  SCCID_EXEINIT_SECTNAME          (SCCIDTYPE_STRING | 13577)
#define  SCCID_EXEINIT_VIRTSIZE          (SCCIDTYPE_STRING | 13578)
#define  SCCID_EXEINIT_VIRTADDR          (SCCIDTYPE_STRING | 13579)
#define  SCCID_EXEINIT_SIZERAWDATA       (SCCIDTYPE_STRING | 13580)
#define  SCCID_EXEINIT_PRAWDATA          (SCCIDTYPE_STRING | 13581)
#define  SCCID_EXEINIT_PRELOC            (SCCIDTYPE_STRING | 13582)
#define  SCCID_EXEINIT_PNLINES           (SCCIDTYPE_STRING | 13583)
#define  SCCID_EXEINIT_NUMRELOC          (SCCIDTYPE_STRING | 13584)
#define  SCCID_EXEINIT_NUMLINES          (SCCIDTYPE_STRING | 13585)
#define  SCCID_EXEINIT_EXPTABLE          (SCCIDTYPE_STRING | 13586)
#define  SCCID_EXEINIT_NAME              (SCCIDTYPE_STRING | 13587)
#define  SCCID_EXEINIT_CHARACTER         (SCCIDTYPE_STRING | 13588)
#define  SCCID_EXEINIT_TIMEDATE          (SCCIDTYPE_STRING | 13589)
#define  SCCID_EXEINIT_VERSION           (SCCIDTYPE_STRING | 13590)
#define  SCCID_EXEINIT_BASE              (SCCIDTYPE_STRING | 13591)
#define  SCCID_EXEINIT_NUMFUNCT          (SCCIDTYPE_STRING | 13592)
#define  SCCID_EXEINIT_NUMNAMES          (SCCIDTYPE_STRING | 13593)
#define  SCCID_EXEINIT_IMPTABLE          (SCCIDTYPE_STRING | 13594)
#define  SCCID_EXEINIT_LINKVERS          (SCCIDTYPE_STRING | 13595)
#define  SCCID_EXEINIT_BLANK             (SCCIDTYPE_STRING | 13596)

/*
|  Strings used by VCAL filter
*/
#define SCCID_VCAL_RUN_TIME             (SCCIDTYPE_STRING | 13819)
#define SCCID_VCAL_SNOOZE_TIME          (SCCIDTYPE_STRING | 13820)
#define SCCID_VCAL_REPEAT_COUNT         (SCCIDTYPE_STRING | 13821)
#define SCCID_VCAL_AUDIO_CONTENT        (SCCIDTYPE_STRING | 13822)
#define SCCID_VCAL_NOTE                 (SCCIDTYPE_STRING | 13823)
#define SCCID_VCAL_ATTENDEE             (SCCIDTYPE_STRING | 13824)
#define SCCID_VCAL_ATTACHMENT			(SCCIDTYPE_STRING | 13825)
#define SCCID_VCAL_AUDIO_REMINDER		(SCCIDTYPE_STRING | 13826)
#define SCCID_VCAL_CLASSIFICATION		(SCCIDTYPE_STRING | 13827)
#define SCCID_VCAL_DTCREATED			(SCCIDTYPE_STRING | 13828)
#define SCCID_VCAL_DTCOMPLETED			(SCCIDTYPE_STRING | 13829)
#define SCCID_VCAL_DESCRIPTION			(SCCIDTYPE_STRING | 13830)
#define SCCID_VCAL_DISPLAY_REMINDER		(SCCIDTYPE_STRING | 13831)
#define SCCID_VCAL_DTDUE				(SCCIDTYPE_STRING | 13832)
#define SCCID_VCAL_DTEND				(SCCIDTYPE_STRING | 13833)
#define SCCID_VCAL_DTEXCEPTION			(SCCIDTYPE_STRING | 13834)
#define SCCID_VCAL_EXCEPTION_RULE		(SCCIDTYPE_STRING | 13835)
#define SCCID_VCAL_LAST_MODIFIED		(SCCIDTYPE_STRING | 13836)
#define SCCID_VCAL_LOCATION				(SCCIDTYPE_STRING | 13837)
#define SCCID_VCAL_MAIL_REMINDER		(SCCIDTYPE_STRING | 13838)
#define SCCID_VCAL_NUMBER_RECURRENCES	(SCCIDTYPE_STRING | 13839)
#define SCCID_VCAL_PROCEDURE_REMINDER	(SCCIDTYPE_STRING | 13840)
#define SCCID_VCAL_RELATED_TO			(SCCIDTYPE_STRING | 13841)
#define SCCID_VCAL_DTRECURRENCE			(SCCIDTYPE_STRING | 13842)
#define SCCID_VCAL_RECURRENCE_RULE		(SCCIDTYPE_STRING | 13843)
#define SCCID_VCAL_RESOURCES			(SCCIDTYPE_STRING | 13844)
#define SCCID_VCAL_SEQUENCE_NUMBER		(SCCIDTYPE_STRING | 13845)
#define SCCID_VCAL_DTSTART				(SCCIDTYPE_STRING | 13846)
#define SCCID_VCAL_TIME_TRANSPARENCY	(SCCIDTYPE_STRING | 13847)
#define SCCID_VCAL_EXPECT               (SCCIDTYPE_STRING | 13848)
#define SCCID_VCAL_RSVP                 (SCCIDTYPE_STRING | 13849)

/*
|  Strings used by VCARD filter
*/
#define SCCID_VCARD_URL                   (SCCIDTYPE_STRING | 13850)
#define SCCID_VCARD_CID                   (SCCIDTYPE_STRING | 13851)
#define SCCID_VCARD_ADDRESS               (SCCIDTYPE_STRING | 13852)
#define SCCID_VCARD_AGENT                 (SCCIDTYPE_STRING | 13853)
#define SCCID_VCARD_DISPLAY               (SCCIDTYPE_STRING | 13854)
#define SCCID_VCARD_BIRTHDATE             (SCCIDTYPE_STRING | 13855)
#define SCCID_VCARD_EMAIL                 (SCCIDTYPE_STRING | 13856)
#define SCCID_VCARD_FORMATTEDNAME         (SCCIDTYPE_STRING | 13857)
#define SCCID_VCARD_GEOPOS                (SCCIDTYPE_STRING | 13858)
#define SCCID_VCARD_PUBLICKEY             (SCCIDTYPE_STRING | 13859)
#define SCCID_VCARD_LOGO                  (SCCIDTYPE_STRING | 13860)
#define SCCID_VCARD_DELIVERYLABEL         (SCCIDTYPE_STRING | 13861)
#define SCCID_VCARD_MAILER                (SCCIDTYPE_STRING | 13862)
#define SCCID_VCARD_NAME                  (SCCIDTYPE_STRING | 13863)
#define SCCID_VCARD_COMMENT               (SCCIDTYPE_STRING | 13864)
#define SCCID_VCARD_ORGANIZATION          (SCCIDTYPE_STRING | 13865)
#define SCCID_VCARD_PHOTOGRAPH            (SCCIDTYPE_STRING | 13866)
#define SCCID_VCARD_LASTREV               (SCCIDTYPE_STRING | 13867)
#define SCCID_VCARD_ROLE                  (SCCIDTYPE_STRING | 13868)
#define SCCID_VCARD_SOUND                 (SCCIDTYPE_STRING | 13869)
#define SCCID_VCARD_TELENUMBER            (SCCIDTYPE_STRING | 13870)
#define SCCID_VCARD_TITLE                 (SCCIDTYPE_STRING | 13871)
#define SCCID_VCARD_TIMEZONE              (SCCIDTYPE_STRING | 13872)
#define SCCID_VCARD_UID                   (SCCIDTYPE_STRING | 13873)
#define SCCID_VCARD_UNIRESLOCATOR         (SCCIDTYPE_STRING | 13874)
#define SCCID_VCARD_VERSION               (SCCIDTYPE_STRING | 13875)
#define SCCID_VCARD_FAMILY                (SCCIDTYPE_STRING | 13876)
#define SCCID_VCARD_FIRST                 (SCCIDTYPE_STRING | 13877)
#define SCCID_VCARD_MIDDLE                (SCCIDTYPE_STRING | 13878)
#define SCCID_VCARD_PREFIX                (SCCIDTYPE_STRING | 13879)
#define SCCID_VCARD_SUFFIX                (SCCIDTYPE_STRING | 13880)
#define SCCID_VCARD_POADDRESS             (SCCIDTYPE_STRING | 13881)
#define SCCID_VCARD_EXTADDRESS            (SCCIDTYPE_STRING | 13882)
#define SCCID_VCARD_STREET                (SCCIDTYPE_STRING | 13883)
#define SCCID_VCARD_LOCALITY              (SCCIDTYPE_STRING | 13884)
#define SCCID_VCARD_REGION                (SCCIDTYPE_STRING | 13885)
#define SCCID_VCARD_POSTALCODE            (SCCIDTYPE_STRING | 13886)
#define SCCID_VCARD_COUNTRY               (SCCIDTYPE_STRING | 13887)
#define SCCID_VCARD_DOMESTIC              (SCCIDTYPE_STRING | 13888)
#define SCCID_VCARD_INTERNATIONAL         (SCCIDTYPE_STRING | 13889)
#define SCCID_VCARD_POSTAL                (SCCIDTYPE_STRING | 13890)
#define SCCID_VCARD_PARCEL                (SCCIDTYPE_STRING | 13891)
#define SCCID_VCARD_HOME                  (SCCIDTYPE_STRING | 13892)
#define SCCID_VCARD_WORK                  (SCCIDTYPE_STRING | 13893)
#define SCCID_VCARD_PREFERRED             (SCCIDTYPE_STRING | 13894)
#define SCCID_VCARD_VOICE                 (SCCIDTYPE_STRING | 13895)
#define SCCID_VCARD_FAX                   (SCCIDTYPE_STRING | 13896)
#define SCCID_VCARD_MESSAGE               (SCCIDTYPE_STRING | 13897)
#define SCCID_VCARD_CELL                  (SCCIDTYPE_STRING | 13898)
#define SCCID_VCARD_PAGER                 (SCCIDTYPE_STRING | 13899)
#define SCCID_VCARD_BBS                   (SCCIDTYPE_STRING | 13900)
#define SCCID_VCARD_MODEM                 (SCCIDTYPE_STRING | 13901)
#define SCCID_VCARD_CAR                   (SCCIDTYPE_STRING | 13902)
#define SCCID_VCARD_ISDN                  (SCCIDTYPE_STRING | 13903)
#define SCCID_VCARD_VIDEO                 (SCCIDTYPE_STRING | 13904)
#define SCCID_VCARD_AOL                   (SCCIDTYPE_STRING | 13905)
#define SCCID_VCARD_APPLELINK             (SCCIDTYPE_STRING | 13906)
#define SCCID_VCARD_ATTMAIL               (SCCIDTYPE_STRING | 13907)
#define SCCID_VCARD_CIS                   (SCCIDTYPE_STRING | 13908)
#define SCCID_VCARD_EWORLD                (SCCIDTYPE_STRING | 13909)
#define SCCID_VCARD_INTERNET              (SCCIDTYPE_STRING | 13910)
#define SCCID_VCARD_IBMMAIL               (SCCIDTYPE_STRING | 13911)
#define SCCID_VCARD_MCIMAIL               (SCCIDTYPE_STRING | 13912)
#define SCCID_VCARD_POWERSHARE            (SCCIDTYPE_STRING | 13913)
#define SCCID_VCARD_PRODIGY               (SCCIDTYPE_STRING | 13914)
#define SCCID_VCARD_TLX                   (SCCIDTYPE_STRING | 13915)
#define SCCID_VCARD_X400                  (SCCIDTYPE_STRING | 13916)
#define SCCID_VCARD_X509                  (SCCIDTYPE_STRING | 13917)
#define SCCID_VCARD_PGP                   (SCCIDTYPE_STRING | 13918)




/*
|  Strings used by MSG or any MAIL filter
*/
#define SCCID_MAIL_TO                     (SCCIDTYPE_STRING | 13930)
#define SCCID_MAIL_CC                     (SCCIDTYPE_STRING | 13931)
#define SCCID_MAIL_BCC                    (SCCIDTYPE_STRING | 13932)
#define SCCID_MAIL_SUBJECT                (SCCIDTYPE_STRING | 13933)
#define SCCID_MAIL_MSGFLAG                (SCCIDTYPE_STRING | 13934)
#define SCCID_MAIL_FLAGSTS                (SCCIDTYPE_STRING | 13935)
#define SCCID_MAIL_EXPIRES                (SCCIDTYPE_STRING | 13936)
#define SCCID_MAIL_CATEGORIES             (SCCIDTYPE_STRING | 13937)
#define SCCID_MAIL_IMPORTANCE             (SCCIDTYPE_STRING | 13938)
#define SCCID_MAIL_SENSITIVITY            (SCCIDTYPE_STRING | 13939)
#define SCCID_MAIL_LOCATION               (SCCIDTYPE_STRING | 13940)
#define SCCID_MAIL_FULLNAME               (SCCIDTYPE_STRING | 13941)
#define SCCID_MAIL_JOBTITLE               (SCCIDTYPE_STRING | 13942)
#define SCCID_MAIL_COMPANY                (SCCIDTYPE_STRING | 13943)
#define SCCID_MAIL_EMAIL                  (SCCIDTYPE_STRING | 13944)
#define SCCID_MAIL_WEBPAGE                (SCCIDTYPE_STRING | 13945)
#define SCCID_MAIL_BUSINESSPHONE        (SCCIDTYPE_STRING | 13946)
#define SCCID_MAIL_HOMEPHONE              (SCCIDTYPE_STRING | 13947)
#define SCCID_MAIL_FROM					  (SCCIDTYPE_STRING | 13948)
#define SCCID_MAIL_SENT                   (SCCIDTYPE_STRING | 13949)
#define SCCID_MAIL_RTFBODY                (SCCIDTYPE_STRING | 13950)
#define SCCID_MAIL_RECEIVED               (SCCIDTYPE_STRING | 13951)
#define SCCID_MAIL_SIZE                   (SCCIDTYPE_STRING | 13952)
#define SCCID_MAIL_LASTMODIFIED           (SCCIDTYPE_STRING | 13953)
#define SCCID_MAIL_NEWSGROUPS             (SCCIDTYPE_STRING | 13954)
#define SCCID_MAIL_SUBMITTIME             (SCCIDTYPE_STRING | 13955)
#define SCCID_MAIL_CCME                   (SCCIDTYPE_STRING | 13956)
#define SCCID_MAIL_ATTACHMENT             (SCCIDTYPE_STRING | 13957)
#define SCCID_MAIL_GENDER				  (SCCIDTYPE_STRING | 13958)
#define SCCID_MAIL_NICKNAME				  (SCCIDTYPE_STRING | 13959)
#define SCCID_MAIL_DEPARTMENT			  (SCCIDTYPE_STRING | 13960)
#define SCCID_MAIL_TITLE                  (SCCIDTYPE_STRING | 13961)
#define SCCID_MAIL_ON_BEHALF_OF         (SCCIDTYPE_STRING | 13962)
#define SCCID_MAIL_RECEIVEDDATE         (SCCIDTYPE_STRING | 13963)
#define SCCID_MAIL_HOMEADDRESS          (SCCIDTYPE_STRING | 13964)
#define SCCID_MAIL_BUSINESSADDRESS      (SCCIDTYPE_STRING | 13965)
#define SCCID_MAIL_OTHERADDRESS         (SCCIDTYPE_STRING | 13966)
#define SCCID_MAIL_IMADDRESS            (SCCIDTYPE_STRING | 13967)
#define SCCID_MAIL_DISPLAYAS            (SCCIDTYPE_STRING | 13968)
#define SCCID_MAIL_DISPLAYAS2           (SCCIDTYPE_STRING | 13969)
#define SCCID_MAIL_DISPLAYAS3           (SCCIDTYPE_STRING | 13970)
#define SCCID_MAIL_FILEAS               (SCCIDTYPE_STRING | 13971)
#define SCCID_MAIL_ASSISTANTPHONE       (SCCIDTYPE_STRING | 13972)
#define SCCID_MAIL_BUSINESSPHONE2       (SCCIDTYPE_STRING | 13974)
#define SCCID_MAIL_BUSINESSFAX          (SCCIDTYPE_STRING | 13975)
#define SCCID_MAIL_CALLBACKPHONE        (SCCIDTYPE_STRING | 13976)
#define SCCID_MAIL_CARPHONE             (SCCIDTYPE_STRING | 13977)
#define SCCID_MAIL_COMPANYPHONE         (SCCIDTYPE_STRING | 13978)
#define SCCID_MAIL_DATE					(SCCIDTYPE_STRING | 13979)
/*There are more SCCID_MAIL identifiers listed later (after SCCID_MAILFIELD). */


/*See further down in the file for the SCCID_MAILFIELD strings.  They would not fit in the range we have available here.*/

/*
|   These strings were created as field text, but of course they can be used for field definitions
*/
#define SCCID_MAILTEXT_NOSENDER           (SCCIDTYPE_STRING | 13980)
#define SCCID_MAILTEXT_NONE               (SCCIDTYPE_STRING | 13981)
#define SCCID_MAILTEXT_NOSUBJECT          (SCCIDTYPE_STRING | 13982)




/*
|  Strings used by MSProject filter
*/
#define SCCID_MSPROJECT_NAME                    (SCCIDTYPE_STRING | 14000)
#define SCCID_MSPROJECT_DURATION                (SCCIDTYPE_STRING | 14001)
#define SCCID_MSPROJECT_START                   (SCCIDTYPE_STRING | 14002)
#define SCCID_MSPROJECT_FINISH                  (SCCIDTYPE_STRING | 14003)
#define SCCID_MSPROJECT_UNIQUEIDPREDECESSORS    (SCCIDTYPE_STRING | 14004)
#define SCCID_MSPROJECT_WORK                    (SCCIDTYPE_STRING | 14005)
#define SCCID_MSPROJECT_COST                    (SCCIDTYPE_STRING | 14006)
#define SCCID_MSPROJECT_PRIORITY                (SCCIDTYPE_STRING | 14007)
#define SCCID_MSPROJECT_COMPLETE                (SCCIDTYPE_STRING | 14008)
#define SCCID_MSPROJECT_WORKCOMPLETE            (SCCIDTYPE_STRING | 14009)
#define SCCID_MSPROJECT_UNIQUEID                (SCCIDTYPE_STRING | 14010)
#define SCCID_MSPROJECT_TASKID                  (SCCIDTYPE_STRING | 14011)
#define SCCID_MSPROJECT_BASELINESTART           (SCCIDTYPE_STRING | 14012)
#define SCCID_MSPROJECT_ACTUALSTART             (SCCIDTYPE_STRING | 14013)
#define SCCID_MSPROJECT_STARTVARIANCE           (SCCIDTYPE_STRING | 14014)
#define SCCID_MSPROJECT_BASELINEFINISH          (SCCIDTYPE_STRING | 14015)
#define SCCID_MSPROJECT_ACTUALFINISH            (SCCIDTYPE_STRING | 14016)
#define SCCID_MSPROJECT_FINISHVARIANCE          (SCCIDTYPE_STRING | 14017)
#define SCCID_MSPROJECT_BASELINEDURATION        (SCCIDTYPE_STRING | 14018)
#define SCCID_MSPROJECT_ACTUALDURATION          (SCCIDTYPE_STRING | 14019)
#define SCCID_MSPROJECT_REMAININGDURATION       (SCCIDTYPE_STRING | 14020)
#define SCCID_MSPROJECT_DURATIONVARIANCE        (SCCIDTYPE_STRING | 14021)
#define SCCID_MSPROJECT_EARLYSTART              (SCCIDTYPE_STRING | 14022)
#define SCCID_MSPROJECT_EARLYFINISH             (SCCIDTYPE_STRING | 14023)
#define SCCID_MSPROJECT_LATESTART               (SCCIDTYPE_STRING | 14024)
#define SCCID_MSPROJECT_LATEFINISH              (SCCIDTYPE_STRING | 14025)
#define SCCID_MSPROJECT_FREESLACK               (SCCIDTYPE_STRING | 14026)
#define SCCID_MSPROJECT_TOTALSLACK              (SCCIDTYPE_STRING | 14027)
#define SCCID_MSPROJECT_LEVELINGDELAY           (SCCIDTYPE_STRING | 14028)
#define SCCID_MSPROJECT_BASELINEWORK            (SCCIDTYPE_STRING | 14029)
#define SCCID_MSPROJECT_ACTUALWORK              (SCCIDTYPE_STRING | 14030)
#define SCCID_MSPROJECT_REMAININGWORK           (SCCIDTYPE_STRING | 14031)
#define SCCID_MSPROJECT_OVERTIMEWORK            (SCCIDTYPE_STRING | 14032)
#define SCCID_MSPROJECT_ACTUALOVERTIMEWORK      (SCCIDTYPE_STRING | 14033)
#define SCCID_MSPROJECT_REMAININGOVERTIMEWORK   (SCCIDTYPE_STRING | 14034)
#define SCCID_MSPROJECT_REGULARWORK             (SCCIDTYPE_STRING | 14035)
#define SCCID_MSPROJECT_WORKVARIANCE            (SCCIDTYPE_STRING | 14036)
#define SCCID_MSPROJECT_FIXEDCOST               (SCCIDTYPE_STRING | 14037)
#define SCCID_MSPROJECT_BASELINECOST            (SCCIDTYPE_STRING | 14038)
#define SCCID_MSPROJECT_ACTUALCOST              (SCCIDTYPE_STRING | 14039)
#define SCCID_MSPROJECT_REMAININGCOST           (SCCIDTYPE_STRING | 14040)
#define SCCID_MSPROJECT_OVERTIMECOST            (SCCIDTYPE_STRING | 14041)
#define SCCID_MSPROJECT_ACTUALOVERTIMECOST      (SCCIDTYPE_STRING | 14042)
#define SCCID_MSPROJECT_REMAININGOVERTIMECOST   (SCCIDTYPE_STRING | 14043)
#define SCCID_MSPROJECT_FIXEDCOSTACCRUAL        (SCCIDTYPE_STRING | 14044)
#define SCCID_MSPROJECT_COSTVARIANCE            (SCCIDTYPE_STRING | 14045)
#define SCCID_MSPROJECT_COSTRATETABLE           (SCCIDTYPE_STRING | 14046)
#define SCCID_MSPROJECT_HYPERLINKHREF           (SCCIDTYPE_STRING | 14047)
#define SCCID_MSPROJECT_HYPERLINK               (SCCIDTYPE_STRING | 14048)
#define SCCID_MSPROJECT_HYPERLINKADDRESS        (SCCIDTYPE_STRING | 14049)
#define SCCID_MSPROJECT_HYPERLINKSUBADDRESS     (SCCIDTYPE_STRING | 14050)
#define SCCID_MSPROJECT_ASSIGNMENT              (SCCIDTYPE_STRING | 14051)
#define SCCID_MSPROJECT_ASSIGNMENTDELAY         (SCCIDTYPE_STRING | 14052)
#define SCCID_MSPROJECT_ASSIGNMENTUNITS         (SCCIDTYPE_STRING | 14053)
#define SCCID_MSPROJECT_CONSTRAINTTYPE          (SCCIDTYPE_STRING | 14054)
#define SCCID_MSPROJECT_CONSTRAINTDATE          (SCCIDTYPE_STRING | 14055)
#define SCCID_MSPROJECT_CONTACT                 (SCCIDTYPE_STRING | 14056)
#define SCCID_MSPROJECT_CRITICAL                (SCCIDTYPE_STRING | 14057)
#define SCCID_MSPROJECT_EFFORTDRIVEN            (SCCIDTYPE_STRING | 14058)
#define SCCID_MSPROJECT_HIDEBAR                 (SCCIDTYPE_STRING | 14059)
#define SCCID_MSPROJECT_LEVELASSIGNMENTS        (SCCIDTYPE_STRING | 14060)
#define SCCID_MSPROJECT_LEVELCANSPLIT           (SCCIDTYPE_STRING | 14061)
#define SCCID_MSPROJECT_LINKEDFIELD             (SCCIDTYPE_STRING | 14062)
#define SCCID_MSPROJECT_MARKED                  (SCCIDTYPE_STRING | 14063)
#define SCCID_MSPROJECT_MILESTONE               (SCCIDTYPE_STRING | 14064)
#define SCCID_MSPROJECT_OBJECTS                 (SCCIDTYPE_STRING | 14065)
#define SCCID_MSPROJECT_OUTLINELEVEL            (SCCIDTYPE_STRING | 14066)
#define SCCID_MSPROJECT_OUTLINENUMBER           (SCCIDTYPE_STRING | 14067)
#define SCCID_MSPROJECT_ROLLUP                  (SCCIDTYPE_STRING | 14068)
#define SCCID_MSPROJECT_STOP                    (SCCIDTYPE_STRING | 14069)
#define SCCID_MSPROJECT_RESUME                  (SCCIDTYPE_STRING | 14070)
#define SCCID_MSPROJECT_SUBPROJECTFILE          (SCCIDTYPE_STRING | 14071)
#define SCCID_MSPROJECT_SUBPROJECTREADONLY      (SCCIDTYPE_STRING | 14072)
#define SCCID_MSPROJECT_SUMMARY                 (SCCIDTYPE_STRING | 14073)
#define SCCID_MSPROJECT_UNIQUEISSUCCESSORS      (SCCIDTYPE_STRING | 14074)
#define SCCID_MSPROJECT_TYPE                    (SCCIDTYPE_STRING | 14075)
#define SCCID_MSPROJECT_WORKCONTOUR             (SCCIDTYPE_STRING | 14076)
#define SCCID_MSPROJECT_WBS                     (SCCIDTYPE_STRING | 14077)
#define SCCID_MSPROJECT_COST1                   (SCCIDTYPE_STRING | 14078)
#define SCCID_MSPROJECT_COST2                   (SCCIDTYPE_STRING | 14079)
#define SCCID_MSPROJECT_COST3                   (SCCIDTYPE_STRING | 14080)
#define SCCID_MSPROJECT_COST4                   (SCCIDTYPE_STRING | 14081)
#define SCCID_MSPROJECT_COST5                   (SCCIDTYPE_STRING | 14082)
#define SCCID_MSPROJECT_COST6                   (SCCIDTYPE_STRING | 14083)
#define SCCID_MSPROJECT_COST7                   (SCCIDTYPE_STRING | 14084)
#define SCCID_MSPROJECT_COST8                   (SCCIDTYPE_STRING | 14085)
#define SCCID_MSPROJECT_COST9                   (SCCIDTYPE_STRING | 14086)
#define SCCID_MSPROJECT_COST10                  (SCCIDTYPE_STRING | 14087)
#define SCCID_MSPROJECT_DATE1                   (SCCIDTYPE_STRING | 14088)
#define SCCID_MSPROJECT_DATE2                   (SCCIDTYPE_STRING | 14089)
#define SCCID_MSPROJECT_DATE3                   (SCCIDTYPE_STRING | 14090)
#define SCCID_MSPROJECT_DATE4                   (SCCIDTYPE_STRING | 14091)
#define SCCID_MSPROJECT_DATE5                   (SCCIDTYPE_STRING | 14092)
#define SCCID_MSPROJECT_DATE6                   (SCCIDTYPE_STRING | 14093)
#define SCCID_MSPROJECT_DATE7                   (SCCIDTYPE_STRING | 14094)
#define SCCID_MSPROJECT_DATE8                   (SCCIDTYPE_STRING | 14095)
#define SCCID_MSPROJECT_DATE9                   (SCCIDTYPE_STRING | 14096)
#define SCCID_MSPROJECT_DATE10                  (SCCIDTYPE_STRING | 14097)
#define SCCID_MSPROJECT_DURATION1               (SCCIDTYPE_STRING | 14098)
#define SCCID_MSPROJECT_DURATION2               (SCCIDTYPE_STRING | 14099)
#define SCCID_MSPROJECT_DURATION3               (SCCIDTYPE_STRING | 14100)
#define SCCID_MSPROJECT_DURATION4               (SCCIDTYPE_STRING | 14101)
#define SCCID_MSPROJECT_DURATION5               (SCCIDTYPE_STRING | 14102)
#define SCCID_MSPROJECT_DURATION6               (SCCIDTYPE_STRING | 14103)
#define SCCID_MSPROJECT_DURATION7               (SCCIDTYPE_STRING | 14104)
#define SCCID_MSPROJECT_DURATION8               (SCCIDTYPE_STRING | 14105)
#define SCCID_MSPROJECT_DURATION9               (SCCIDTYPE_STRING | 14106)
#define SCCID_MSPROJECT_DURATION10              (SCCIDTYPE_STRING | 14107)
#define SCCID_MSPROJECT_FINISH1                 (SCCIDTYPE_STRING | 14108)
#define SCCID_MSPROJECT_FINISH2                 (SCCIDTYPE_STRING | 14109)
#define SCCID_MSPROJECT_FINISH3                 (SCCIDTYPE_STRING | 14110)
#define SCCID_MSPROJECT_FINISH4                 (SCCIDTYPE_STRING | 14111)
#define SCCID_MSPROJECT_FINISH5                 (SCCIDTYPE_STRING | 14112)
#define SCCID_MSPROJECT_FINISH6                 (SCCIDTYPE_STRING | 14113)
#define SCCID_MSPROJECT_FINISH7                 (SCCIDTYPE_STRING | 14114)
#define SCCID_MSPROJECT_FINISH8                 (SCCIDTYPE_STRING | 14115)
#define SCCID_MSPROJECT_FINISH9                 (SCCIDTYPE_STRING | 14116)
#define SCCID_MSPROJECT_FINISH10                (SCCIDTYPE_STRING | 14117)
#define SCCID_MSPROJECT_FLAG1                   (SCCIDTYPE_STRING | 14118)
#define SCCID_MSPROJECT_FLAG2                   (SCCIDTYPE_STRING | 14119)
#define SCCID_MSPROJECT_FLAG3                   (SCCIDTYPE_STRING | 14120)
#define SCCID_MSPROJECT_FLAG4                   (SCCIDTYPE_STRING | 14121)
#define SCCID_MSPROJECT_FLAG5                   (SCCIDTYPE_STRING | 14122)
#define SCCID_MSPROJECT_FLAG6                   (SCCIDTYPE_STRING | 14123)
#define SCCID_MSPROJECT_FLAG7                   (SCCIDTYPE_STRING | 14124)
#define SCCID_MSPROJECT_FLAG8                   (SCCIDTYPE_STRING | 14125)
#define SCCID_MSPROJECT_FLAG9                   (SCCIDTYPE_STRING | 14126)
#define SCCID_MSPROJECT_FLAG10                  (SCCIDTYPE_STRING | 14127)
#define SCCID_MSPROJECT_FLAG11                  (SCCIDTYPE_STRING | 14128)
#define SCCID_MSPROJECT_FLAG12                  (SCCIDTYPE_STRING | 14129)
#define SCCID_MSPROJECT_FLAG13                  (SCCIDTYPE_STRING | 14130)
#define SCCID_MSPROJECT_FLAG14                  (SCCIDTYPE_STRING | 14131)
#define SCCID_MSPROJECT_FLAG15                  (SCCIDTYPE_STRING | 14132)
#define SCCID_MSPROJECT_FLAG16                  (SCCIDTYPE_STRING | 14133)
#define SCCID_MSPROJECT_FLAG17                  (SCCIDTYPE_STRING | 14134)
#define SCCID_MSPROJECT_FLAG18                  (SCCIDTYPE_STRING | 14135)
#define SCCID_MSPROJECT_FLAG19                  (SCCIDTYPE_STRING | 14136)
#define SCCID_MSPROJECT_FLAG20                  (SCCIDTYPE_STRING | 14137)
#define SCCID_MSPROJECT_NUMBER1                 (SCCIDTYPE_STRING | 14138)
#define SCCID_MSPROJECT_NUMBER2                 (SCCIDTYPE_STRING | 14139)
#define SCCID_MSPROJECT_NUMBER3                 (SCCIDTYPE_STRING | 14140)
#define SCCID_MSPROJECT_NUMBER4                 (SCCIDTYPE_STRING | 14141)
#define SCCID_MSPROJECT_NUMBER5                 (SCCIDTYPE_STRING | 14142)
#define SCCID_MSPROJECT_NUMBER6                 (SCCIDTYPE_STRING | 14143)
#define SCCID_MSPROJECT_NUMBER7                 (SCCIDTYPE_STRING | 14144)
#define SCCID_MSPROJECT_NUMBER8                 (SCCIDTYPE_STRING | 14145)
#define SCCID_MSPROJECT_NUMBER9                 (SCCIDTYPE_STRING | 14146)
#define SCCID_MSPROJECT_NUMBER10                (SCCIDTYPE_STRING | 14147)
#define SCCID_MSPROJECT_NUMBER11                (SCCIDTYPE_STRING | 14148)
#define SCCID_MSPROJECT_NUMBER12                (SCCIDTYPE_STRING | 14149)
#define SCCID_MSPROJECT_NUMBER13                (SCCIDTYPE_STRING | 14150)
#define SCCID_MSPROJECT_NUMBER14                (SCCIDTYPE_STRING | 14151)
#define SCCID_MSPROJECT_NUMBER15                (SCCIDTYPE_STRING | 14152)
#define SCCID_MSPROJECT_NUMBER16                (SCCIDTYPE_STRING | 14153)
#define SCCID_MSPROJECT_NUMBER17                (SCCIDTYPE_STRING | 14154)
#define SCCID_MSPROJECT_NUMBER18                (SCCIDTYPE_STRING | 14155)
#define SCCID_MSPROJECT_NUMBER19                (SCCIDTYPE_STRING | 14156)
#define SCCID_MSPROJECT_NUMBER20                (SCCIDTYPE_STRING | 14157)
#define SCCID_MSPROJECT_START1                  (SCCIDTYPE_STRING | 14158)
#define SCCID_MSPROJECT_START2                  (SCCIDTYPE_STRING | 14159)
#define SCCID_MSPROJECT_START3                  (SCCIDTYPE_STRING | 14160)
#define SCCID_MSPROJECT_START4                  (SCCIDTYPE_STRING | 14161)
#define SCCID_MSPROJECT_START5                  (SCCIDTYPE_STRING | 14162)
#define SCCID_MSPROJECT_START6                  (SCCIDTYPE_STRING | 14163)
#define SCCID_MSPROJECT_START7                  (SCCIDTYPE_STRING | 14164)
#define SCCID_MSPROJECT_START8                  (SCCIDTYPE_STRING | 14165)
#define SCCID_MSPROJECT_START9                  (SCCIDTYPE_STRING | 14166)
#define SCCID_MSPROJECT_START10                 (SCCIDTYPE_STRING | 14167)
#define SCCID_MSPROJECT_TEXT1                   (SCCIDTYPE_STRING | 14168)
#define SCCID_MSPROJECT_TEXT2                   (SCCIDTYPE_STRING | 14169)
#define SCCID_MSPROJECT_TEXT3                   (SCCIDTYPE_STRING | 14170)
#define SCCID_MSPROJECT_TEXT4                   (SCCIDTYPE_STRING | 14171)
#define SCCID_MSPROJECT_TEXT5                   (SCCIDTYPE_STRING | 14172)
#define SCCID_MSPROJECT_TEXT6                   (SCCIDTYPE_STRING | 14173)
#define SCCID_MSPROJECT_TEXT7                   (SCCIDTYPE_STRING | 14174)
#define SCCID_MSPROJECT_TEXT8                   (SCCIDTYPE_STRING | 14175)
#define SCCID_MSPROJECT_TEXT9                   (SCCIDTYPE_STRING | 14176)
#define SCCID_MSPROJECT_TEXT10                  (SCCIDTYPE_STRING | 14177)
#define SCCID_MSPROJECT_TEXT11                  (SCCIDTYPE_STRING | 14178)
#define SCCID_MSPROJECT_TEXT12                  (SCCIDTYPE_STRING | 14179)
#define SCCID_MSPROJECT_TEXT13                  (SCCIDTYPE_STRING | 14180)
#define SCCID_MSPROJECT_TEXT14                  (SCCIDTYPE_STRING | 14181)
#define SCCID_MSPROJECT_TEXT15                  (SCCIDTYPE_STRING | 14182)
#define SCCID_MSPROJECT_TEXT16                  (SCCIDTYPE_STRING | 14183)
#define SCCID_MSPROJECT_TEXT17                  (SCCIDTYPE_STRING | 14184)
#define SCCID_MSPROJECT_TEXT18                  (SCCIDTYPE_STRING | 14185)
#define SCCID_MSPROJECT_TEXT19                  (SCCIDTYPE_STRING | 14186)
#define SCCID_MSPROJECT_TEXT20                  (SCCIDTYPE_STRING | 14187)
#define SCCID_MSPROJECT_TEXT21                  (SCCIDTYPE_STRING | 14188)
#define SCCID_MSPROJECT_TEXT22                  (SCCIDTYPE_STRING | 14189)
#define SCCID_MSPROJECT_TEXT23                  (SCCIDTYPE_STRING | 14190)
#define SCCID_MSPROJECT_TEXT24                  (SCCIDTYPE_STRING | 14191)
#define SCCID_MSPROJECT_TEXT25                  (SCCIDTYPE_STRING | 14192)
#define SCCID_MSPROJECT_TEXT26                  (SCCIDTYPE_STRING | 14193)
#define SCCID_MSPROJECT_TEXT27                  (SCCIDTYPE_STRING | 14194)
#define SCCID_MSPROJECT_TEXT28                  (SCCIDTYPE_STRING | 14195)
#define SCCID_MSPROJECT_TEXT29                  (SCCIDTYPE_STRING | 14196)
#define SCCID_MSPROJECT_TEXT30                  (SCCIDTYPE_STRING | 14197)
#define SCCID_MSPROJECT_RESOURCENAME            (SCCIDTYPE_STRING | 14198)
#define SCCID_MSPROJECT_INITIALS                (SCCIDTYPE_STRING | 14199)
#define SCCID_MSPROJECT_GROUP                   (SCCIDTYPE_STRING | 14200)
#define SCCID_MSPROJECT_MAXUNITS                (SCCIDTYPE_STRING | 14201)
#define SCCID_MSPROJECT_STDRATE                 (SCCIDTYPE_STRING | 14202)
#define SCCID_MSPROJECT_OVTRATE                 (SCCIDTYPE_STRING | 14203)
#define SCCID_MSPROJECT_COSTPERUSE              (SCCIDTYPE_STRING | 14204)
#define SCCID_MSPROJECT_ACCRUEAT                (SCCIDTYPE_STRING | 14205)
#define SCCID_MSPROJECT_BASECALENDAR            (SCCIDTYPE_STRING | 14206)
#define SCCID_MSPROJECT_CODE                    (SCCIDTYPE_STRING | 14207)
#define SCCID_MSPROJECT_ID                      (SCCIDTYPE_STRING | 14208)
#define SCCID_MSPROJECT_EMAILADDRESS            (SCCIDTYPE_STRING | 14209)
#define SCCID_MSPROJECT_AVAILABLEFROM           (SCCIDTYPE_STRING | 14210)
#define SCCID_MSPROJECT_AVAILABLETO             (SCCIDTYPE_STRING | 14211)
#define SCCID_MSPROJECT_WORKGROUP               (SCCIDTYPE_STRING | 14212)
#define SCCID_MSPROJECT_CREATED                 (SCCIDTYPE_STRING | 14213)
#define SCCID_MSPROJECT_RESOURCEID              (SCCIDTYPE_STRING | 14214)
#define SCCID_MSPROJECT_RESOURCEGROUP           (SCCIDTYPE_STRING | 14215)
#define SCCID_MSPROJECT_CONFIRMED               (SCCIDTYPE_STRING | 14216)
#define SCCID_MSPROJECT_PEAK                    (SCCIDTYPE_STRING | 14217)
#define SCCID_MSPROJECT_RESOURCEINITIALS        (SCCIDTYPE_STRING | 14218)
#define SCCID_MSPROJECT_CANLEVEL                (SCCIDTYPE_STRING | 14219)
#define SCCID_MSPROJECT_UNIQUEIDSUCCESSORS      (SCCIDTYPE_STRING | 14220)
#define SCCID_MSPROJECT_PROJECTSHEETNAME        (SCCIDTYPE_STRING | 14221)
#define SCCID_MSPROJECT_TASKSHEETNAME           (SCCIDTYPE_STRING | 14222)
#define SCCID_MSPROJECT_RESOURCESHEETNAME       (SCCIDTYPE_STRING | 14223)
#define SCCID_MSPROJECT_ASSIGNMENTSHEETNAME     (SCCIDTYPE_STRING | 14224)
#define SCCID_MSPROJECT_NOTE                    (SCCIDTYPE_STRING | 14225)

#define SCCID_MSPROJECT_BASELINE1_BUDGETCOST     (SCCIDTYPE_STRING | 14256)
#define SCCID_MSPROJECT_BASELINE2_BUDGETCOST     (SCCIDTYPE_STRING | 14257)
#define SCCID_MSPROJECT_BASELINE3_BUDGETCOST     (SCCIDTYPE_STRING | 14258)
#define SCCID_MSPROJECT_BASELINE4_BUDGETCOST     (SCCIDTYPE_STRING | 14259)
#define SCCID_MSPROJECT_BASELINE5_BUDGETCOST     (SCCIDTYPE_STRING | 14260)
#define SCCID_MSPROJECT_BASELINE6_BUDGETCOST     (SCCIDTYPE_STRING | 14261)
#define SCCID_MSPROJECT_BASELINE7_BUDGETCOST     (SCCIDTYPE_STRING | 14262)
#define SCCID_MSPROJECT_BASELINE8_BUDGETCOST     (SCCIDTYPE_STRING | 14263)
#define SCCID_MSPROJECT_BASELINE9_BUDGETCOST     (SCCIDTYPE_STRING | 14264)
#define SCCID_MSPROJECT_BASELINE10_BUDGETCOST    (SCCIDTYPE_STRING | 14265)


#define SCCID_MSPROJECT_BASELINE1_BUDGETWORK     (SCCIDTYPE_STRING | 14266)
#define SCCID_MSPROJECT_BASELINE2_BUDGETWORK     (SCCIDTYPE_STRING | 14267)
#define SCCID_MSPROJECT_BASELINE3_BUDGETWORK     (SCCIDTYPE_STRING | 14268)
#define SCCID_MSPROJECT_BASELINE4_BUDGETWORK     (SCCIDTYPE_STRING | 14269)
#define SCCID_MSPROJECT_BASELINE5_BUDGETWORK     (SCCIDTYPE_STRING | 14270)
#define SCCID_MSPROJECT_BASELINE6_BUDGETWORK     (SCCIDTYPE_STRING | 14271)
#define SCCID_MSPROJECT_BASELINE7_BUDGETWORK     (SCCIDTYPE_STRING | 14272)
#define SCCID_MSPROJECT_BASELINE8_BUDGETWORK     (SCCIDTYPE_STRING | 14273)
#define SCCID_MSPROJECT_BASELINE9_BUDGETWORK     (SCCIDTYPE_STRING | 14274)
#define SCCID_MSPROJECT_BASELINE10_BUDGETWORK    (SCCIDTYPE_STRING | 14275)

#define SCCID_MSPROJECT_BUDGETCOST               (SCCIDTYPE_STRING | 14276)
#define SCCID_MSPROJECT_BUDGETWORK               (SCCIDTYPE_STRING | 14277)

#define SCCID_MSPROJECT_OUTLINECODE1             (SCCIDTYPE_STRING | 14278)
#define SCCID_MSPROJECT_OUTLINECODE2             (SCCIDTYPE_STRING | 14279)
#define SCCID_MSPROJECT_OUTLINECODE3             (SCCIDTYPE_STRING | 14280)
#define SCCID_MSPROJECT_OUTLINECODE4             (SCCIDTYPE_STRING | 14281)
#define SCCID_MSPROJECT_OUTLINECODE5             (SCCIDTYPE_STRING | 14282)
#define SCCID_MSPROJECT_OUTLINECODE6             (SCCIDTYPE_STRING | 14283)
#define SCCID_MSPROJECT_OUTLINECODE7             (SCCIDTYPE_STRING | 14284)
#define SCCID_MSPROJECT_OUTLINECODE8             (SCCIDTYPE_STRING | 14285)
#define SCCID_MSPROJECT_OUTLINECODE9             (SCCIDTYPE_STRING | 14286)
#define SCCID_MSPROJECT_OUTLINECODE10            (SCCIDTYPE_STRING | 14287)

#define SCCID_MSPROJECT_SCHEDULED_DURATION       (SCCIDTYPE_STRING | 14288)
#define SCCID_MSPROJECT_SCHEDULED_START          (SCCIDTYPE_STRING | 14289)
#define SCCID_MSPROJECT_SCHEDULED_FINISH         (SCCIDTYPE_STRING | 14290)
#define SCCID_MSPROJECT_ESTIMATED_DURATION       (SCCIDTYPE_STRING | 14291)
#define SCCID_MSPROJECT_ESTIMATED_START          (SCCIDTYPE_STRING | 14292)
#define SCCID_MSPROJECT_ESTIMATED_FINISH         (SCCIDTYPE_STRING | 14293)
#define SCCID_MSPROJECT_ACTIVE                   (SCCIDTYPE_STRING | 14294)
#define SCCID_MSPROJECT_IGNOREWARNING            (SCCIDTYPE_STRING | 14295)
#define SCCID_MSPROJECT_TASKMODE                 (SCCIDTYPE_STRING | 14296)

#define SCCID_MSPROJECT_BASELINEBUDGETCOST       (SCCIDTYPE_STRING | 14297)
#define SCCID_MSPROJECT_BASELINEBUDGETWORK       (SCCIDTYPE_STRING | 14298)
#define SCCID_MSPROJECT_TASKCALENDAR             (SCCIDTYPE_STRING | 14299)

#define SCCID_MSPROJECT_CONSTRAINTTYPE0         (SCCIDTYPE_STRING | 14300)
#define SCCID_MSPROJECT_CONSTRAINTTYPE1         (SCCIDTYPE_STRING | 14301)
#define SCCID_MSPROJECT_CONSTRAINTTYPE2         (SCCIDTYPE_STRING | 14302)
#define SCCID_MSPROJECT_CONSTRAINTTYPE3         (SCCIDTYPE_STRING | 14303)
#define SCCID_MSPROJECT_CONSTRAINTTYPE4         (SCCIDTYPE_STRING | 14304)
#define SCCID_MSPROJECT_CONSTRAINTTYPE5         (SCCIDTYPE_STRING | 14305)
#define SCCID_MSPROJECT_CONSTRAINTTYPE6         (SCCIDTYPE_STRING | 14306)
#define SCCID_MSPROJECT_CONSTRAINTTYPE7         (SCCIDTYPE_STRING | 14307)

#define SCCID_MSPROJECT_WORKGROUPTYPEA          (SCCIDTYPE_STRING | 14308)
#define SCCID_MSPROJECT_WORKGROUPTYPEB          (SCCIDTYPE_STRING | 14309)
#define SCCID_MSPROJECT_WORKGROUPTYPEC          (SCCIDTYPE_STRING | 14310)
#define SCCID_MSPROJECT_WORKGROUPTYPED          (SCCIDTYPE_STRING | 14311)
#define SCCID_MSPROJECT_WORKGROUPTYPEE          (SCCIDTYPE_STRING | 14312)

#define SCCID_MSPROJECT_PRIORITYTYPE0           (SCCIDTYPE_STRING | 14313)
#define SCCID_MSPROJECT_PRIORITYTYPE1           (SCCIDTYPE_STRING | 14314)
#define SCCID_MSPROJECT_PRIORITYTYPE2           (SCCIDTYPE_STRING | 14315)
#define SCCID_MSPROJECT_PRIORITYTYPE3           (SCCIDTYPE_STRING | 14316)
#define SCCID_MSPROJECT_PRIORITYTYPE4           (SCCIDTYPE_STRING | 14317)
#define SCCID_MSPROJECT_PRIORITYTYPE5           (SCCIDTYPE_STRING | 14318)
#define SCCID_MSPROJECT_PRIORITYTYPE6           (SCCIDTYPE_STRING | 14319)
#define SCCID_MSPROJECT_PRIORITYTYPE7           (SCCIDTYPE_STRING | 14320)
#define SCCID_MSPROJECT_PRIORITYTYPE8           (SCCIDTYPE_STRING | 14321)
#define SCCID_MSPROJECT_PRIORITYTYPE9           (SCCIDTYPE_STRING | 14322)


#define SCCID_MSPROJECT_TASKTYPE0               (SCCIDTYPE_STRING | 14323)
#define SCCID_MSPROJECT_TASKTYPE1               (SCCIDTYPE_STRING | 14324)
#define SCCID_MSPROJECT_TASKTYPE2               (SCCIDTYPE_STRING | 14325)

#define SCCID_MSPROJECT_ACCRUEATTYPE0           (SCCIDTYPE_STRING | 14326)
#define SCCID_MSPROJECT_ACCRUEATTYPE1           (SCCIDTYPE_STRING | 14327)
#define SCCID_MSPROJECT_ACCRUEATTYPE2           (SCCIDTYPE_STRING | 14328)


#define SCCID_MSPROJECT_WORKCONTOURTYPEA        (SCCIDTYPE_STRING | 14329)
#define SCCID_MSPROJECT_WORKCONTOURTYPEB        (SCCIDTYPE_STRING | 14330)
#define SCCID_MSPROJECT_WORKCONTOURTYPEC        (SCCIDTYPE_STRING | 14331)
#define SCCID_MSPROJECT_WORKCONTOURTYPED        (SCCIDTYPE_STRING | 14332)
#define SCCID_MSPROJECT_WORKCONTOURTYPEE        (SCCIDTYPE_STRING | 14333)
#define SCCID_MSPROJECT_WORKCONTOURTYPEF        (SCCIDTYPE_STRING | 14334)
#define SCCID_MSPROJECT_WORKCONTOURTYPEG        (SCCIDTYPE_STRING | 14335)
#define SCCID_MSPROJECT_WORKCONTOURTYPEH        (SCCIDTYPE_STRING | 14336)

#define SCCID_MSPROJECT_BASELINE1COST           (SCCIDTYPE_STRING | 14400)
#define SCCID_MSPROJECT_BASELINE2COST           (SCCIDTYPE_STRING | 14401)
#define SCCID_MSPROJECT_BASELINE3COST           (SCCIDTYPE_STRING | 14402)
#define SCCID_MSPROJECT_BASELINE4COST           (SCCIDTYPE_STRING | 14403)
#define SCCID_MSPROJECT_BASELINE5COST           (SCCIDTYPE_STRING | 14404)
#define SCCID_MSPROJECT_BASELINE6COST           (SCCIDTYPE_STRING | 14405)
#define SCCID_MSPROJECT_BASELINE7COST           (SCCIDTYPE_STRING | 14406)
#define SCCID_MSPROJECT_BASELINE8COST           (SCCIDTYPE_STRING | 14407)
#define SCCID_MSPROJECT_BASELINE9COST           (SCCIDTYPE_STRING | 14408)
#define SCCID_MSPROJECT_BASELINE10COST          (SCCIDTYPE_STRING | 14409)

#define SCCID_MSPROJECT_BASELINE1DURATION       (SCCIDTYPE_STRING | 14410)
#define SCCID_MSPROJECT_BASELINE2DURATION       (SCCIDTYPE_STRING | 14411)
#define SCCID_MSPROJECT_BASELINE3DURATION       (SCCIDTYPE_STRING | 14412)
#define SCCID_MSPROJECT_BASELINE4DURATION       (SCCIDTYPE_STRING | 14413)
#define SCCID_MSPROJECT_BASELINE5DURATION       (SCCIDTYPE_STRING | 14414)
#define SCCID_MSPROJECT_BASELINE6DURATION       (SCCIDTYPE_STRING | 14415)
#define SCCID_MSPROJECT_BASELINE7DURATION       (SCCIDTYPE_STRING | 14416)
#define SCCID_MSPROJECT_BASELINE8DURATION       (SCCIDTYPE_STRING | 14417)
#define SCCID_MSPROJECT_BASELINE9DURATION       (SCCIDTYPE_STRING | 14418)
#define SCCID_MSPROJECT_BASELINE10DURATION      (SCCIDTYPE_STRING | 14419)

#define SCCID_MSPROJECT_BASELINE1FINISH         (SCCIDTYPE_STRING | 14420)
#define SCCID_MSPROJECT_BASELINE2FINISH         (SCCIDTYPE_STRING | 14421)
#define SCCID_MSPROJECT_BASELINE3FINISH         (SCCIDTYPE_STRING | 14422)
#define SCCID_MSPROJECT_BASELINE4FINISH         (SCCIDTYPE_STRING | 14423)
#define SCCID_MSPROJECT_BASELINE5FINISH         (SCCIDTYPE_STRING | 14424)
#define SCCID_MSPROJECT_BASELINE6FINISH         (SCCIDTYPE_STRING | 14425)
#define SCCID_MSPROJECT_BASELINE7FINISH         (SCCIDTYPE_STRING | 14426)
#define SCCID_MSPROJECT_BASELINE8FINISH         (SCCIDTYPE_STRING | 14427)
#define SCCID_MSPROJECT_BASELINE9FINISH         (SCCIDTYPE_STRING | 14428)  
#define SCCID_MSPROJECT_BASELINE10FINISH        (SCCIDTYPE_STRING | 14429)

#define SCCID_MSPROJECT_BASELINE1START          (SCCIDTYPE_STRING | 14430)
#define SCCID_MSPROJECT_BASELINE2START          (SCCIDTYPE_STRING | 14431)
#define SCCID_MSPROJECT_BASELINE3START          (SCCIDTYPE_STRING | 14432)
#define SCCID_MSPROJECT_BASELINE4START          (SCCIDTYPE_STRING | 14433)
#define SCCID_MSPROJECT_BASELINE5START          (SCCIDTYPE_STRING | 14434)
#define SCCID_MSPROJECT_BASELINE6START          (SCCIDTYPE_STRING | 14435)
#define SCCID_MSPROJECT_BASELINE7START          (SCCIDTYPE_STRING | 14436)
#define SCCID_MSPROJECT_BASELINE8START          (SCCIDTYPE_STRING | 14437)
#define SCCID_MSPROJECT_BASELINE9START          (SCCIDTYPE_STRING | 14438)
#define SCCID_MSPROJECT_BASELINE10START         (SCCIDTYPE_STRING | 14439)

#define SCCID_MSPROJECT_BASELINE1WORK           (SCCIDTYPE_STRING | 14440)
#define SCCID_MSPROJECT_BASELINE2WORK           (SCCIDTYPE_STRING | 14441)
#define SCCID_MSPROJECT_BASELINE3WORK           (SCCIDTYPE_STRING | 14442)
#define SCCID_MSPROJECT_BASELINE4WORK           (SCCIDTYPE_STRING | 14443)
#define SCCID_MSPROJECT_BASELINE5WORK           (SCCIDTYPE_STRING | 14444)
#define SCCID_MSPROJECT_BASELINE6WORK           (SCCIDTYPE_STRING | 14445)
#define SCCID_MSPROJECT_BASELINE7WORK           (SCCIDTYPE_STRING | 14446)
#define SCCID_MSPROJECT_BASELINE8WORK           (SCCIDTYPE_STRING | 14447)
#define SCCID_MSPROJECT_BASELINE9WORK           (SCCIDTYPE_STRING | 14448)
#define SCCID_MSPROJECT_BASELINE10WORK          (SCCIDTYPE_STRING | 14449)

#define SCCID_MSPROJECT_ESTIMATED               (SCCIDTYPE_STRING | 14450)
#define SCCID_MSPROJECT_PHYSICALPERCOMPLETE     (SCCIDTYPE_STRING | 14451)
#define SCCID_MSPROJECT_DEADLINE                (SCCIDTYPE_STRING | 14452)
#define SCCID_MSPROJECT_RECURRING               (SCCIDTYPE_STRING | 14453)
#define SCCID_MSPROJECT_STARTSLACK              (SCCIDTYPE_STRING | 14454)
#define SCCID_MSPROJECT_FINISHSLACK             (SCCIDTYPE_STRING | 14455)
#define SCCID_MSPROJECT_EARNEDVALUEMETHOD       (SCCIDTYPE_STRING | 14456)
#define SCCID_MSPROJECT_BASELINE_DELIVERABLE_START (SCCIDTYPE_STRING | 14457)
#define SCCID_MSPROJECT_BASELINE_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14458)
#define SCCID_MSPROJECT_BASELINEFIXEDCOST       (SCCIDTYPE_STRING | 14459)

#define SCCID_MSPROJECT_BASELINE1_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14460)
#define SCCID_MSPROJECT_BASELINE2_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14462)
#define SCCID_MSPROJECT_BASELINE3_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14463)
#define SCCID_MSPROJECT_BASELINE4_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14464)
#define SCCID_MSPROJECT_BASELINE5_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14465)
#define SCCID_MSPROJECT_BASELINE6_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14466)
#define SCCID_MSPROJECT_BASELINE7_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14467)
#define SCCID_MSPROJECT_BASELINE8_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14468)
#define SCCID_MSPROJECT_BASELINE9_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14469)
#define SCCID_MSPROJECT_BASELINE10_DELIVERABLE_FINISH (SCCIDTYPE_STRING | 14470)

#define SCCID_MSPROJECT_BASELINE1_DELIVERABLE_START (SCCIDTYPE_STRING | 14471)
#define SCCID_MSPROJECT_BASELINE2_DELIVERABLE_START (SCCIDTYPE_STRING | 14472)
#define SCCID_MSPROJECT_BASELINE3_DELIVERABLE_START (SCCIDTYPE_STRING | 14473)
#define SCCID_MSPROJECT_BASELINE4_DELIVERABLE_START (SCCIDTYPE_STRING | 14474)
#define SCCID_MSPROJECT_BASELINE5_DELIVERABLE_START (SCCIDTYPE_STRING | 14475)
#define SCCID_MSPROJECT_BASELINE6_DELIVERABLE_START (SCCIDTYPE_STRING | 14476)
#define SCCID_MSPROJECT_BASELINE7_DELIVERABLE_START (SCCIDTYPE_STRING | 14477)
#define SCCID_MSPROJECT_BASELINE8_DELIVERABLE_START (SCCIDTYPE_STRING | 14478)
#define SCCID_MSPROJECT_BASELINE9_DELIVERABLE_START (SCCIDTYPE_STRING | 14479)
#define SCCID_MSPROJECT_BASELINE10_DELIVERABLE_START (SCCIDTYPE_STRING | 14480)

#define SCCID_MSPROJECT_GUID                        (SCCIDTYPE_STRING | 14481)
#define SCCID_MSPROJECT_MATERIALLABEL               (SCCIDTYPE_STRING | 14482)
#define SCCID_MSPROJECT_WINUSERACCT                 (SCCIDTYPE_STRING | 14483)
#define SCCID_MSPROJECT_COSTCENTER                  (SCCIDTYPE_STRING | 14484)
#define SCCID_MSPROJECT_PHONETICS                   (SCCIDTYPE_STRING | 14485)
#define SCCID_MSPROJECT_BUDGET                      (SCCIDTYPE_STRING | 14486)
#define SCCID_MSPROJECT_GENERIC                     (SCCIDTYPE_STRING | 14487)

#define SCCID_MSPROJECT_BOOKINGTYPE                 (SCCIDTYPE_STRING | 14488)
#define SCCID_MSPROJECT_BASELINEFIXEDCOSTACCRUAL    (SCCIDTYPE_STRING | 14489)
#define SCCID_MSPROJECT_PROJECT                     (SCCIDTYPE_STRING | 14490)
#define SCCID_MSPROJECT_PLACEHOLDER                 (SCCIDTYPE_STRING | 14491)
#define SCCID_MSPROJECT_OVERALLOCATED               (SCCIDTYPE_STRING | 14492)
#define SCCID_MSPROJECT_RESOURCETYPE                (SCCIDTYPE_STRING | 14493)
#define SCCID_MSPROJECT_CALENDARGUID                (SCCIDTYPE_STRING | 14494)
#define SCCID_MSPROJECT_TASKCALENDARGUID            (SCCIDTYPE_STRING | 14495)
#define SCCID_MSPROJECT_PRELEVELSTART               (SCCIDTYPE_STRING | 14496)
#define SCCID_MSPROJECT_PRELEVELFINISH              (SCCIDTYPE_STRING | 14497)

#define SCCID_MSPROJECT_BASELINE1_ESTIMATED_DURATION  (SCCIDTYPE_STRING | 14500)
#define SCCID_MSPROJECT_BASELINE2_ESTIMATED_DURATION  (SCCIDTYPE_STRING | 14501)
#define SCCID_MSPROJECT_BASELINE3_ESTIMATED_DURATION  (SCCIDTYPE_STRING | 14502)
#define SCCID_MSPROJECT_BASELINE4_ESTIMATED_DURATION  (SCCIDTYPE_STRING | 14503)
#define SCCID_MSPROJECT_BASELINE5_ESTIMATED_DURATION  (SCCIDTYPE_STRING | 14504)
#define SCCID_MSPROJECT_BASELINE6_ESTIMATED_DURATION  (SCCIDTYPE_STRING | 14505)
#define SCCID_MSPROJECT_BASELINE7_ESTIMATED_DURATION  (SCCIDTYPE_STRING | 14506)
#define SCCID_MSPROJECT_BASELINE8_ESTIMATED_DURATION  (SCCIDTYPE_STRING | 14507)
#define SCCID_MSPROJECT_BASELINE9_ESTIMATED_DURATION  (SCCIDTYPE_STRING | 14508)
#define SCCID_MSPROJECT_BASELINE10_ESTIMATED_DURATION (SCCIDTYPE_STRING | 14509)

#define SCCID_MSPROJECT_BASELINE1_ESTIMATED_START  (SCCIDTYPE_STRING | 14510)
#define SCCID_MSPROJECT_BASELINE2_ESTIMATED_START  (SCCIDTYPE_STRING | 14511)
#define SCCID_MSPROJECT_BASELINE3_ESTIMATED_START  (SCCIDTYPE_STRING | 14512)
#define SCCID_MSPROJECT_BASELINE4_ESTIMATED_START  (SCCIDTYPE_STRING | 14513)
#define SCCID_MSPROJECT_BASELINE5_ESTIMATED_START  (SCCIDTYPE_STRING | 14514)
#define SCCID_MSPROJECT_BASELINE6_ESTIMATED_START  (SCCIDTYPE_STRING | 14515)
#define SCCID_MSPROJECT_BASELINE7_ESTIMATED_START  (SCCIDTYPE_STRING | 14516)
#define SCCID_MSPROJECT_BASELINE8_ESTIMATED_START  (SCCIDTYPE_STRING | 14517)
#define SCCID_MSPROJECT_BASELINE9_ESTIMATED_START  (SCCIDTYPE_STRING | 14518)
#define SCCID_MSPROJECT_BASELINE10_ESTIMATED_START (SCCIDTYPE_STRING | 14519)

#define SCCID_MSPROJECT_BASELINE1_ESTIMATED_FINISH  (SCCIDTYPE_STRING | 14520)
#define SCCID_MSPROJECT_BASELINE2_ESTIMATED_FINISH  (SCCIDTYPE_STRING | 14521)
#define SCCID_MSPROJECT_BASELINE3_ESTIMATED_FINISH  (SCCIDTYPE_STRING | 14522)
#define SCCID_MSPROJECT_BASELINE4_ESTIMATED_FINISH  (SCCIDTYPE_STRING | 14523)
#define SCCID_MSPROJECT_BASELINE5_ESTIMATED_FINISH  (SCCIDTYPE_STRING | 14524)
#define SCCID_MSPROJECT_BASELINE6_ESTIMATED_FINISH  (SCCIDTYPE_STRING | 14525)
#define SCCID_MSPROJECT_BASELINE7_ESTIMATED_FINISH  (SCCIDTYPE_STRING | 14526)
#define SCCID_MSPROJECT_BASELINE8_ESTIMATED_FINISH  (SCCIDTYPE_STRING | 14527)
#define SCCID_MSPROJECT_BASELINE9_ESTIMATED_FINISH  (SCCIDTYPE_STRING | 14528)
#define SCCID_MSPROJECT_BASELINE10_ESTIMATED_FINISH (SCCIDTYPE_STRING | 14529)

#define SCCID_MSPROJECT_BASELINE1_FIXEDCOST         (SCCIDTYPE_STRING | 14530)
#define SCCID_MSPROJECT_BASELINE2_FIXEDCOST         (SCCIDTYPE_STRING | 14531)
#define SCCID_MSPROJECT_BASELINE3_FIXEDCOST         (SCCIDTYPE_STRING | 14532)
#define SCCID_MSPROJECT_BASELINE4_FIXEDCOST         (SCCIDTYPE_STRING | 14533)
#define SCCID_MSPROJECT_BASELINE5_FIXEDCOST         (SCCIDTYPE_STRING | 14534)
#define SCCID_MSPROJECT_BASELINE6_FIXEDCOST         (SCCIDTYPE_STRING | 14535)
#define SCCID_MSPROJECT_BASELINE7_FIXEDCOST         (SCCIDTYPE_STRING | 14536)
#define SCCID_MSPROJECT_BASELINE8_FIXEDCOST         (SCCIDTYPE_STRING | 14537)
#define SCCID_MSPROJECT_BASELINE9_FIXEDCOST         (SCCIDTYPE_STRING | 14538)
#define SCCID_MSPROJECT_BASELINE10_FIXEDCOST        (SCCIDTYPE_STRING | 14539)

#define SCCID_MSPROJECT_BASELINE1_FIXEDCOSTACCRUAL  (SCCIDTYPE_STRING | 14540)
#define SCCID_MSPROJECT_BASELINE2_FIXEDCOSTACCRUAL  (SCCIDTYPE_STRING | 14541)
#define SCCID_MSPROJECT_BASELINE3_FIXEDCOSTACCRUAL  (SCCIDTYPE_STRING | 14542)
#define SCCID_MSPROJECT_BASELINE4_FIXEDCOSTACCRUAL  (SCCIDTYPE_STRING | 14543)
#define SCCID_MSPROJECT_BASELINE5_FIXEDCOSTACCRUAL  (SCCIDTYPE_STRING | 14544)
#define SCCID_MSPROJECT_BASELINE6_FIXEDCOSTACCRUAL  (SCCIDTYPE_STRING | 14545)
#define SCCID_MSPROJECT_BASELINE7_FIXEDCOSTACCRUAL  (SCCIDTYPE_STRING | 14546)
#define SCCID_MSPROJECT_BASELINE8_FIXEDCOSTACCRUAL  (SCCIDTYPE_STRING | 14547)
#define SCCID_MSPROJECT_BASELINE9_FIXEDCOSTACCRUAL  (SCCIDTYPE_STRING | 14548)
#define SCCID_MSPROJECT_BASELINE10_FIXEDCOSTACCRUAL (SCCIDTYPE_STRING | 14549)


#define SCCID_PST_BUSINESSPHONE                 (SCCIDTYPE_STRING | 14343)

/* Strings used by the ID3 filter */
#define SCCID_ID3_AENC                          (SCCIDTYPE_STRING | 14700)
#define SCCID_ID3_APIC                          (SCCIDTYPE_STRING | 14701)
#define SCCID_ID3_ASPI                          (SCCIDTYPE_STRING | 14702)
#define SCCID_ID3_COMM                          (SCCIDTYPE_STRING | 14703)
#define SCCID_ID3_COMR                          (SCCIDTYPE_STRING | 14704)
#define SCCID_ID3_ENCR                          (SCCIDTYPE_STRING | 14705)
#define SCCID_ID3_EQUA                          (SCCIDTYPE_STRING | 14706)
#define SCCID_ID3_EQU2                          (SCCIDTYPE_STRING | 14707)
#define SCCID_ID3_ETCO                          (SCCIDTYPE_STRING | 14708)
#define SCCID_ID3_GEOB                          (SCCIDTYPE_STRING | 14709)
#define SCCID_ID3_GRID                          (SCCIDTYPE_STRING | 14710)
#define SCCID_ID3_IPLS                          (SCCIDTYPE_STRING | 14711)
#define SCCID_ID3_LINK                          (SCCIDTYPE_STRING | 14712)
#define SCCID_ID3_MCDI                          (SCCIDTYPE_STRING | 14713)
#define SCCID_ID3_MLLT                          (SCCIDTYPE_STRING | 14714)
#define SCCID_ID3_OWNE                          (SCCIDTYPE_STRING | 14715)
#define SCCID_ID3_PRIV                          (SCCIDTYPE_STRING | 14716)
#define SCCID_ID3_PCNT                          (SCCIDTYPE_STRING | 14717)
#define SCCID_ID3_POPM                          (SCCIDTYPE_STRING | 14718)
#define SCCID_ID3_POSS                          (SCCIDTYPE_STRING | 14719)
#define SCCID_ID3_RBUF                          (SCCIDTYPE_STRING | 14720)
#define SCCID_ID3_RVAD                          (SCCIDTYPE_STRING | 14721)
#define SCCID_ID3_RVA2                          (SCCIDTYPE_STRING | 14722)
#define SCCID_ID3_RVRB                          (SCCIDTYPE_STRING | 14723)
#define SCCID_ID3_SEEK                          (SCCIDTYPE_STRING | 14724)
#define SCCID_ID3_SIGN                          (SCCIDTYPE_STRING | 14725)
#define SCCID_ID3_SYLT                          (SCCIDTYPE_STRING | 14726)
#define SCCID_ID3_SYTC                          (SCCIDTYPE_STRING | 14727)
#define SCCID_ID3_TALB                          (SCCIDTYPE_STRING | 14728)
#define SCCID_ID3_TBPM                          (SCCIDTYPE_STRING | 14729)
#define SCCID_ID3_TCOM                          (SCCIDTYPE_STRING | 14730)
#define SCCID_ID3_TCON                          (SCCIDTYPE_STRING | 14731)
#define SCCID_ID3_TCOP                          (SCCIDTYPE_STRING | 14732)
#define SCCID_ID3_TDAT                          (SCCIDTYPE_STRING | 14733)
#define SCCID_ID3_TDLY                          (SCCIDTYPE_STRING | 14734)
#define SCCID_ID3_TENC                          (SCCIDTYPE_STRING | 14735)
#define SCCID_ID3_TEXT                          (SCCIDTYPE_STRING | 14736)
#define SCCID_ID3_TFLT                          (SCCIDTYPE_STRING | 14737)
#define SCCID_ID3_TIME                          (SCCIDTYPE_STRING | 14738)
#define SCCID_ID3_TIPL                          (SCCIDTYPE_STRING | 14739)
#define SCCID_ID3_TIT1                          (SCCIDTYPE_STRING | 14740)
#define SCCID_ID3_TIT2                          (SCCIDTYPE_STRING | 14741)
#define SCCID_ID3_TIT3                          (SCCIDTYPE_STRING | 14742)
#define SCCID_ID3_TKEY                          (SCCIDTYPE_STRING | 14743)
#define SCCID_ID3_TLAN                          (SCCIDTYPE_STRING | 14744)
#define SCCID_ID3_TLEN                          (SCCIDTYPE_STRING | 14745)
#define SCCID_ID3_TMCL                          (SCCIDTYPE_STRING | 14746)
#define SCCID_ID3_TMOO                          (SCCIDTYPE_STRING | 14747)
#define SCCID_ID3_TMED                          (SCCIDTYPE_STRING | 14748)
#define SCCID_ID3_TOAL                          (SCCIDTYPE_STRING | 14749)
#define SCCID_ID3_TOFN                          (SCCIDTYPE_STRING | 14750)
#define SCCID_ID3_TOLY                          (SCCIDTYPE_STRING | 14751)
#define SCCID_ID3_TOPE                          (SCCIDTYPE_STRING | 14752)
#define SCCID_ID3_TORY                          (SCCIDTYPE_STRING | 14753)
#define SCCID_ID3_TOWN                          (SCCIDTYPE_STRING | 14754)
#define SCCID_ID3_TPE1                          (SCCIDTYPE_STRING | 14755)
#define SCCID_ID3_TPE2                          (SCCIDTYPE_STRING | 14756)
#define SCCID_ID3_TPE3                          (SCCIDTYPE_STRING | 14757)
#define SCCID_ID3_TPE4                          (SCCIDTYPE_STRING | 14758)
#define SCCID_ID3_TPOS                          (SCCIDTYPE_STRING | 14759)
#define SCCID_ID3_TPRO                          (SCCIDTYPE_STRING | 14760)
#define SCCID_ID3_TPUB                          (SCCIDTYPE_STRING | 14761)
#define SCCID_ID3_TRCK                          (SCCIDTYPE_STRING | 14762)
#define SCCID_ID3_TRDA                          (SCCIDTYPE_STRING | 14763)
#define SCCID_ID3_TRSN                          (SCCIDTYPE_STRING | 14764)
#define SCCID_ID3_TRSO                          (SCCIDTYPE_STRING | 14765)
#define SCCID_ID3_TSIZ                          (SCCIDTYPE_STRING | 14766)
#define SCCID_ID3_TSRC                          (SCCIDTYPE_STRING | 14767)
#define SCCID_ID3_TSOA                          (SCCIDTYPE_STRING | 14768)
#define SCCID_ID3_TSOP                          (SCCIDTYPE_STRING | 14769)
#define SCCID_ID3_TSOT                          (SCCIDTYPE_STRING | 14770)
#define SCCID_ID3_TSSE                          (SCCIDTYPE_STRING | 14771)
#define SCCID_ID3_TSST                          (SCCIDTYPE_STRING | 14772)
#define SCCID_ID3_TYER                          (SCCIDTYPE_STRING | 14773)
#define SCCID_ID3_UFID                          (SCCIDTYPE_STRING | 14774)
#define SCCID_ID3_USER                          (SCCIDTYPE_STRING | 14775)
#define SCCID_ID3_USLT                          (SCCIDTYPE_STRING | 14776)
#define SCCID_ID3_WCOM                          (SCCIDTYPE_STRING | 14777)
#define SCCID_ID3_WCOP                          (SCCIDTYPE_STRING | 14778)
#define SCCID_ID3_WOAF                          (SCCIDTYPE_STRING | 14779)
#define SCCID_ID3_WOAR                          (SCCIDTYPE_STRING | 14780)
#define SCCID_ID3_WOAS                          (SCCIDTYPE_STRING | 14781)
#define SCCID_ID3_WORS                          (SCCIDTYPE_STRING | 14782)
#define SCCID_ID3_WPAY                          (SCCIDTYPE_STRING | 14783)
#define SCCID_ID3_WPUB                          (SCCIDTYPE_STRING | 14784)

/*
|  Multimedia document property string ids
*/
#define SCCID_MULTIMEDIA_ALBUM                  (SCCIDTYPE_STRING | 15000)
#define SCCID_MULTIMEDIA_ARRANGER               (SCCIDTYPE_STRING | 15001)
#define SCCID_MULTIMEDIA_ARTIST                 (SCCIDTYPE_STRING | 15002)
#define SCCID_MULTIMEDIA_AUTHOR                 (SCCIDTYPE_STRING | 15003)
#define SCCID_MULTIMEDIA_CHAPTER                (SCCIDTYPE_STRING | 15004)
#define SCCID_MULTIMEDIA_COMMENT                (SCCIDTYPE_STRING | 15005)
#define SCCID_MULTIMEDIA_COMPOSER               (SCCIDTYPE_STRING | 15006)
#define SCCID_MULTIMEDIA_COPYRIGHT              (SCCIDTYPE_STRING | 15007)
#define SCCID_MULTIMEDIA_CREATIONDATE           (SCCIDTYPE_STRING | 15008)
#define SCCID_MULTIMEDIA_DESCRIPTION            (SCCIDTYPE_STRING | 15009)
#define SCCID_MULTIMEDIA_DIRECTOR               (SCCIDTYPE_STRING | 15010)
#define SCCID_MULTIMEDIA_DISCLAIMER             (SCCIDTYPE_STRING | 15011)
#define SCCID_MULTIMEDIA_EDITDATEDESCRIPTION    (SCCIDTYPE_STRING | 15012)
#define SCCID_MULTIMEDIA_ENCODER                (SCCIDTYPE_STRING | 15013)
#define SCCID_MULTIMEDIA_FORMAT                 (SCCIDTYPE_STRING | 15014)
#define SCCID_MULTIMEDIA_GENRE                  (SCCIDTYPE_STRING | 15015)
#define SCCID_MULTIMEDIA_HOSTCOMPUTER           (SCCIDTYPE_STRING | 15016)
#define SCCID_MULTIMEDIA_INFO                   (SCCIDTYPE_STRING | 15017)
#define SCCID_MULTIMEDIA_ISRC                   (SCCIDTYPE_STRING | 15018)
#define SCCID_MULTIMEDIA_RECORDLABEL            (SCCIDTYPE_STRING | 15019)
#define SCCID_MULTIMEDIA_RECORDLABELURL         (SCCIDTYPE_STRING | 15020)
#define SCCID_MULTIMEDIA_FILECREATOR            (SCCIDTYPE_STRING | 15021)
#define SCCID_MULTIMEDIA_FILECREATORURL         (SCCIDTYPE_STRING | 15022)
#define SCCID_MULTIMEDIA_MODEL                  (SCCIDTYPE_STRING | 15023)
#define SCCID_MULTIMEDIA_TITLE                  (SCCIDTYPE_STRING | 15024)
#define SCCID_MULTIMEDIA_ORIGINALARTIST         (SCCIDTYPE_STRING | 15025)
#define SCCID_MULTIMEDIA_RECORDINGCOPYRIGHT     (SCCIDTYPE_STRING | 15026)
#define SCCID_MULTIMEDIA_PRODUCER               (SCCIDTYPE_STRING | 15027)
#define SCCID_MULTIMEDIA_PERFORMER              (SCCIDTYPE_STRING | 15028)
#define SCCID_MULTIMEDIA_PERFORMERURL           (SCCIDTYPE_STRING | 15029)
#define SCCID_MULTIMEDIA_PRODUCT                (SCCIDTYPE_STRING | 15030)
#define SCCID_MULTIMEDIA_HWSWREQS               (SCCIDTYPE_STRING | 15031)
#define SCCID_MULTIMEDIA_SUBTITLE               (SCCIDTYPE_STRING | 15032)
#define SCCID_MULTIMEDIA_SOURCECREDITS          (SCCIDTYPE_STRING | 15033)
#define SCCID_MULTIMEDIA_SONGWRITER             (SCCIDTYPE_STRING | 15034)
#define SCCID_MULTIMEDIA_SOFTWARE               (SCCIDTYPE_STRING | 15035)
#define SCCID_MULTIMEDIA_TRACK                  (SCCIDTYPE_STRING | 15036)
#define SCCID_MULTIMEDIA_WARNING                (SCCIDTYPE_STRING | 15037)
#define SCCID_MULTIMEDIA_WRITER                 (SCCIDTYPE_STRING | 15038)
#define SCCID_MULTIMEDIA_URL                    (SCCIDTYPE_STRING | 15039)
#define SCCID_MULTIMEDIA_WIDTH                  (SCCIDTYPE_STRING | 15040)
#define SCCID_MULTIMEDIA_HEIGHT                 (SCCIDTYPE_STRING | 15041)
#define SCCID_MULTIMEDIA_RATING                 (SCCIDTYPE_STRING | 15042)
#define SCCID_MULTIMEDIA_ENCODERDESCRIPTION     (SCCIDTYPE_STRING | 15043)
#define SCCID_MULTIMEDIA_KEYWORDS               (SCCIDTYPE_STRING | 15044)
#define SCCID_MULTIMEDIA_RELATED                (SCCIDTYPE_STRING | 15045)
#define SCCID_MULTIMEDIA_CREATIONTIME           (SCCIDTYPE_STRING | 15046)
#define SCCID_MULTIMEDIA_MANUFACTURER           (SCCIDTYPE_STRING | 15047)
#define SCCID_MULTIMEDIA_ARCHIVE                (SCCIDTYPE_STRING | 15048)
#define SCCID_MULTIMEDIA_COMMISSIONEDBY         (SCCIDTYPE_STRING | 15049)
#define SCCID_MULTIMEDIA_CROPPED                (SCCIDTYPE_STRING | 15050)
#define SCCID_MULTIMEDIA_DIMENSIONS             (SCCIDTYPE_STRING | 15051)
#define SCCID_MULTIMEDIA_RESOLUTION             (SCCIDTYPE_STRING | 15052)
#define SCCID_MULTIMEDIA_ENGINEER               (SCCIDTYPE_STRING | 15053)
#define SCCID_MULTIMEDIA_LIGHTNESS              (SCCIDTYPE_STRING | 15054)
#define SCCID_MULTIMEDIA_MEDIUM                 (SCCIDTYPE_STRING | 15055)
#define SCCID_MULTIMEDIA_PALETTE                (SCCIDTYPE_STRING | 15056)
#define SCCID_MULTIMEDIA_SUBJECT                (SCCIDTYPE_STRING | 15057)
#define SCCID_MULTIMEDIA_SHARPNESS              (SCCIDTYPE_STRING | 15058)
#define SCCID_MULTIMEDIA_SOURCEFORM             (SCCIDTYPE_STRING | 15059)
#define SCCID_MULTIMEDIA_TECHNICIAN             (SCCIDTYPE_STRING | 15060)
#define SCCID_MULTIMEDIA_NUMBEROFCHANNELS       (SCCIDTYPE_STRING | 15061)
#define SCCID_MULTIMEDIA_SAMPLINGRATE           (SCCIDTYPE_STRING | 15062)
#define SCCID_MULTIMEDIA_GROUPING               (SCCIDTYPE_STRING | 15063)
#define SCCID_MULTIMEDIA_CATEGORY               (SCCIDTYPE_STRING | 15064)
#define SCCID_MULTIMEDIA_LYRICS                 (SCCIDTYPE_STRING | 15065)
#define SCCID_MULTIMEDIA_TVNETWORK              (SCCIDTYPE_STRING | 15066)
#define SCCID_MULTIMEDIA_TVSHOW                 (SCCIDTYPE_STRING | 15067)
#define SCCID_MULTIMEDIA_EPISODE                (SCCIDTYPE_STRING | 15068)
#define SCCID_MULTIMEDIA_PURCHASEDATE           (SCCIDTYPE_STRING | 15069)

/*
|  Strings used by the Autocad acd2 filter.
*/
#define SCCID_ACD2_ZOOMEXTENTSVIEW              (SCCIDTYPE_STRING | 16000)

/*
|  Dialog IDs
*/

#define SCCID_PRINTABORTDIALOG        (SCCIDTYPE_DIALOG | 15001)
#define SCCID_PRINTOPTIONSDIALOG      (SCCIDTYPE_DIALOG | 15002)
#define SCCID_PRINTDIALOG             (SCCIDTYPE_DIALOG | 15003)
#define SCCID_SELECTFONTDIALOG        (SCCIDTYPE_DIALOG | 15004)
#define SCCID_DISPLAYOPTIONSDIALOG    (SCCIDTYPE_DIALOG | 15005)
#define SCCID_DISPLAYMOREDIALOG       (SCCIDTYPE_DIALOG | 15006)
#define SCCID_PRINTMOREDIALOG         (SCCIDTYPE_DIALOG | 15007)
#define SCCID_PRINTSETUPDIALOG        (SCCIDTYPE_DIALOG | 15008)
#define SCCID_SEARCHDIALOG            (SCCIDTYPE_DIALOG | 15009)
#define SCCID_CLIPBOARDOPTIONSDIALOG  (SCCIDTYPE_DIALOG | 15010)
#define SCCID_CLIPBOARDMOREDIALOG     (SCCIDTYPE_DIALOG | 15011)
#define SCCID_FILTERLISTDIALOG        (SCCIDTYPE_DIALOG | 15012)
#define SCCID_ARCSAVEALLDIALOG        (SCCIDTYPE_DIALOG | 15013)
#define SCCID_ARCSAVESELECTDIALOG     (SCCIDTYPE_DIALOG | 15014)
#define SCCID_PROGRESSDIALOG          (SCCIDTYPE_DIALOG | 15015)
#define SCCID_ARCBADNAMEDIALOG        (SCCIDTYPE_DIALOG | 15016)

/*
|   Action IDs
*/
#define SCCID_ACTIONCOPY              (SCCIDTYPE_ACTION | 15100)
#define SCCID_ACTIONPRINT             (SCCIDTYPE_ACTION | 15101)
#define SCCID_ACTIONFIXUPDEBUGITEMS   (SCCIDTYPE_ACTION | 15102)
#if defined(SCCDEBUG) && defined(WIN32)
#define SCCID_ACTIONDEBUGEVENT		  (SCCIDTYPE_ACTION | 15103)
#endif

/*
|   Unmappable character ID
*/
#define SCCID_UNMAPPABLECHAR          (SCCIDTYPE_OPTION | 15200)


#define SCCID_DEFAULTINPUTCHARSET     (SCCIDTYPE_STRING | SCCIDTYPE_OPTION | 15300)


/*
|   Menu item string base ID
*/
#define SCCID_MENUBASE                (SCCIDTYPE_STRING | 16000)

/*
|   HTML Export Strings
*/

/* property name strings */
#define SCCID_HX_DOCCOMMENT           (SCCIDTYPE_STRING | 17000)
#define SCCID_HX_KEYWORD              (SCCIDTYPE_STRING | 17001)
#define SCCID_HX_LASTSAVEDBY          (SCCIDTYPE_STRING | 17002)
#define SCCID_HX_PRIMARYAUTHOR        (SCCIDTYPE_STRING | 17003)
#define SCCID_HX_SUBJECT              (SCCIDTYPE_STRING | 17004)
#define SCCID_HX_TITLE                (SCCIDTYPE_STRING | 17005)
#define SCCID_HX_ABSTRACT             (SCCIDTYPE_STRING | 17006)
#define SCCID_HX_ACCOUNT              (SCCIDTYPE_STRING | 17007)
#define SCCID_HX_ADDRESS              (SCCIDTYPE_STRING | 17008)
#define SCCID_HX_ATTACHMENTS          (SCCIDTYPE_STRING | 17009)
#define SCCID_HX_AUTHORIZATION        (SCCIDTYPE_STRING | 17010)
#define SCCID_HX_BACKUPDATE           (SCCIDTYPE_STRING | 17011)
#define SCCID_HX_BILLTO               (SCCIDTYPE_STRING | 17012)
#define SCCID_HX_BLINDCOPY            (SCCIDTYPE_STRING | 17013)
#define SCCID_HX_CARBONCOPY           (SCCIDTYPE_STRING | 17014)
#define SCCID_HX_CATEGORY             (SCCIDTYPE_STRING | 17015)
#define SCCID_HX_CHECKEDBY            (SCCIDTYPE_STRING | 17016)
#define SCCID_HX_CLIENT               (SCCIDTYPE_STRING | 17017)
#define SCCID_HX_COMPLETEDDATE        (SCCIDTYPE_STRING | 17018)
#define SCCID_HX_COUNTCHARS           (SCCIDTYPE_STRING | 17019)
#define SCCID_HX_COUNTPAGES           (SCCIDTYPE_STRING | 17020)
#define SCCID_HX_COUNTWORDS           (SCCIDTYPE_STRING | 17021)
#define SCCID_HX_CREATIONDATE         (SCCIDTYPE_STRING | 17022)
#define SCCID_HX_DEPARTMENT           (SCCIDTYPE_STRING | 17023)
#define SCCID_HX_DESTINATION          (SCCIDTYPE_STRING | 17024)
#define SCCID_HX_DISPOSITION          (SCCIDTYPE_STRING | 17025)
#define SCCID_HX_DIVISION             (SCCIDTYPE_STRING | 17026)
#define SCCID_HX_EDITMINUTES          (SCCIDTYPE_STRING | 17027)
#define SCCID_HX_EDITOR               (SCCIDTYPE_STRING | 17028)
#define SCCID_HX_FORWARDTO            (SCCIDTYPE_STRING | 17029)
#define SCCID_HX_GROUP                (SCCIDTYPE_STRING | 17030)
#define SCCID_HX_LANGUAGE             (SCCIDTYPE_STRING | 17031)
#define SCCID_HX_LASTPRINTDATE        (SCCIDTYPE_STRING | 17032)
#define SCCID_HX_MAILSTOP             (SCCIDTYPE_STRING | 17033)
#define SCCID_HX_MATTER               (SCCIDTYPE_STRING | 17034)
#define SCCID_HX_OFFICE               (SCCIDTYPE_STRING | 17035)
#define SCCID_HX_OPERATOR             (SCCIDTYPE_STRING | 17036)
#define SCCID_HX_OWNER                (SCCIDTYPE_STRING | 17037)
#define SCCID_HX_PROJECT              (SCCIDTYPE_STRING | 17038)
#define SCCID_HX_PUBLISHER            (SCCIDTYPE_STRING | 17039)
#define SCCID_HX_PURPOSE              (SCCIDTYPE_STRING | 17040)
#define SCCID_HX_RECEIVEDFROM         (SCCIDTYPE_STRING | 17041)
#define SCCID_HX_RECORDEDBY           (SCCIDTYPE_STRING | 17042)
#define SCCID_HX_RECORDEDDATE         (SCCIDTYPE_STRING | 17043)
#define SCCID_HX_REFERENCE            (SCCIDTYPE_STRING | 17044)
#define SCCID_HX_REVISIONDATE         (SCCIDTYPE_STRING | 17045)
#define SCCID_HX_REVISIONNOTES        (SCCIDTYPE_STRING | 17046)
#define SCCID_HX_REVISIONNUMBER       (SCCIDTYPE_STRING | 17047)
#define SCCID_HX_SECONDARYAUTHOR      (SCCIDTYPE_STRING | 17048)
#define SCCID_HX_SECTION              (SCCIDTYPE_STRING | 17049)
#define SCCID_HX_SECURITY             (SCCIDTYPE_STRING | 17050)
#define SCCID_HX_SOURCE               (SCCIDTYPE_STRING | 17051)
#define SCCID_HX_STATUS               (SCCIDTYPE_STRING | 17052)
#define SCCID_HX_DOCTYPE              (SCCIDTYPE_STRING | 17053)
#define SCCID_HX_TYPIST               (SCCIDTYPE_STRING | 17054)
#define SCCID_HX_VERSIONDATE          (SCCIDTYPE_STRING | 17055)
#define SCCID_HX_VERSIONNOTES         (SCCIDTYPE_STRING | 17056)
#define SCCID_HX_VERSIONNUMBER        (SCCIDTYPE_STRING | 17057)
#define SCCID_HX_BASEFILELOCATION     (SCCIDTYPE_STRING | 17058)
#define SCCID_HX_MANAGER              (SCCIDTYPE_STRING | 17059)
#define SCCID_HX_COMPANY              (SCCIDTYPE_STRING | 17060)
#define SCCID_HX_EMPTYCELLS           (SCCIDTYPE_STRING | 17061)
#define SCCID_HX_CELLLABELSEPARATOR   (SCCIDTYPE_STRING | 17062)
#define SCCID_HX_PRESENTATIONFORMAT   (SCCIDTYPE_STRING | 17063)
#define SCCID_HX_COUNTPARAS           (SCCIDTYPE_STRING | 17064)
#define SCCID_HX_COUNTSLIDES          (SCCIDTYPE_STRING | 17065)
#define SCCID_HX_COUNTNOTES           (SCCIDTYPE_STRING | 17066)
#define SCCID_HX_COUNTSLIDESHIDDEN    (SCCIDTYPE_STRING | 17067)
#define SCCID_HX_COUNTMMCLIPS         (SCCIDTYPE_STRING | 17068)
#define SCCID_HX_SCALECROP            (SCCIDTYPE_STRING | 17069)
#define SCCID_HX_LINKSDIRTY           (SCCIDTYPE_STRING | 17070)
#define SCCID_HX_COUNTBYTES           (SCCIDTYPE_STRING | 17071)
#define SCCID_HX_COUNTLINES           (SCCIDTYPE_STRING | 17072)
#define SCCID_HX_LASTSAVEDATE         (SCCIDTYPE_STRING | 17073)
#define SCCID_HX_COUNTCHARSWITHSPACES (SCCIDTYPE_STRING | 17074)
#define SCCID_HX_HEADINGPAIRS         (SCCIDTYPE_STRING | 17075)
#define SCCID_HX_TITLEOFPARTS         (SCCIDTYPE_STRING | 17076)
#define SCCID_HX_DOCNUMBER            (SCCIDTYPE_STRING | 17077)
#define SCCID_HX_SSFORMULA            (SCCIDTYPE_STRING | 17078)
#define SCCID_HX_APPVERSION           (SCCIDTYPE_STRING | 17079)
#define SCCID_HX_XMPNAMESPACE         (SCCIDTYPE_STRING | 17080)
#define SCCID_HX_DOCTEMPLATE          (SCCIDTYPE_STRING | 17081)

/* Template Error file general strings */
#define SCCID_HX_MSG_TITLE            (SCCIDTYPE_STRING | 17100)
#define SCCID_HX_MSG_STARTERR         (SCCIDTYPE_STRING | 17101)
#define SCCID_HX_MSG_ERROR            (SCCIDTYPE_STRING | 17102)
#define SCCID_HX_MSG_CHECKBELOW       (SCCIDTYPE_STRING | 17103)
#define SCCID_HX_MSG_ANCHOR           (SCCIDTYPE_STRING | 17104)
#define SCCID_HX_MSG_SEEABOVE         (SCCIDTYPE_STRING | 17105)

/* PP97 default text strings */
#define SCCID_PP97_FIRST_SLIDE        (SCCIDTYPE_STRING | 17200)
#define SCCID_PP97_TITLE              (SCCIDTYPE_STRING | 17201)
#define SCCID_PP97_SUBTITLE           (SCCIDTYPE_STRING | 17202)
#define SCCID_PP97_CLIPART            (SCCIDTYPE_STRING | 17203)
#define SCCID_PP97_OBJECT             (SCCIDTYPE_STRING | 17204)
#define SCCID_PP97_CHART              (SCCIDTYPE_STRING | 17205)
#define SCCID_PP97_TABLE              (SCCIDTYPE_STRING | 17206)
#define SCCID_PP97_ORGCHART           (SCCIDTYPE_STRING | 17207)
#define SCCID_PP97_MEDIACLIP          (SCCIDTYPE_STRING | 17208)
#define SCCID_PP97_TEXT               (SCCIDTYPE_STRING | 17209)

/* Yahoo! IM default text strings */
#define SCCID_YIM_UKNCONT             (SCCIDTYPE_STRING | 17250)
#define SCCID_YIM_CHATDATE            (SCCIDTYPE_STRING | 17251)
#define SCCID_YIM_CHATWITH            (SCCIDTYPE_STRING | 17252)
#define SCCID_YIM_YOURPRO             (SCCIDTYPE_STRING | 17253)
#define SCCID_YIM_YMESS               (SCCIDTYPE_STRING | 17254)
#define SCCID_YIM_JOINCONF            (SCCIDTYPE_STRING | 17255)
#define SCCID_YIM_LEFTCONF            (SCCIDTYPE_STRING | 17256)

/* Error messages */
#define SCCID_ERR_OK                                (SCCIDTYPE_STRING | 17300)
#define SCCID_ERR_UNKNOWN                           (SCCIDTYPE_STRING | 17301)
#define SCCID_ERR_BADPARAM                          (SCCIDTYPE_STRING | 17302)
#define SCCID_ERR_ABORT                             (SCCIDTYPE_STRING | 17303)
#define SCCID_ERR_CANCEL                            (SCCIDTYPE_STRING | 17304)
#define SCCID_ERR_NOINIT                            (SCCIDTYPE_STRING | 17305)
#define SCCID_ERR_MACINITFAILED                     (SCCIDTYPE_STRING | 17306)
#define SCCID_ERR_MESSAGEHANDLED                    (SCCIDTYPE_STRING | 17307)
#define SCCID_ERR_NOITEM                            (SCCIDTYPE_STRING | 17308)
#define SCCID_ERR_NONEFOUND                         (SCCIDTYPE_STRING | 17309)
#define SCCID_ERR_MORE                              (SCCIDTYPE_STRING | 17310)
#define SCCID_ERR_NOTHANDLED                        (SCCIDTYPE_STRING | 17311)
#define SCCID_ERR_SYSTEM                            (SCCIDTYPE_STRING | 17312)
#define SCCID_ERR_PROCCREATE                        (SCCIDTYPE_STRING | 17313)
#define SCCID_ERR_PROCDESTROY                       (SCCIDTYPE_STRING | 17314)
#define SCCID_ERR_PROCTIMEOUT                       (SCCIDTYPE_STRING | 17315)
#define SCCID_ERR_ASSERTIONFAILED                   (SCCIDTYPE_STRING | 17316)
#define SCCID_ERR_DEBUGERROR                        (SCCIDTYPE_STRING | 17317)
#define SCCID_ERR_NOCHANGE                          (SCCIDTYPE_STRING | 17318)
#define SCCID_ERR_DISPLAYOPENFAILED                 (SCCIDTYPE_STRING | 17319)
#define SCCID_ERR_ALLOCFAILED                       (SCCIDTYPE_STRING | 17320)
#define SCCID_ERR_OUTOFMEMORY                       (SCCIDTYPE_STRING | 17321)
#define SCCID_ERR_INSUFFICIENTBUFFER                (SCCIDTYPE_STRING | 17322)
#define SCCID_ERR_MEMORYLEAK                        (SCCIDTYPE_STRING | 17323)
#define SCCID_ERR_MEMTABLEFULL                      (SCCIDTYPE_STRING | 17324)
#define SCCID_ERR_INVALIDHANDLE                     (SCCIDTYPE_STRING | 17325)
#define SCCID_ERR_NULLHANDLE                        (SCCIDTYPE_STRING | 17326)
#define SCCID_ERR_LOCKEDHANDLE                      (SCCIDTYPE_STRING | 17327)
#define SCCID_ERR_UNLOCKEDHANDLE                    (SCCIDTYPE_STRING | 17328)
#define SCCID_ERR_NOFILE                            (SCCIDTYPE_STRING | 17329)
#define SCCID_ERR_FILEOPENFAILED                    (SCCIDTYPE_STRING | 17330)
#define SCCID_ERR_SUPFILEOPENFAILED                 (SCCIDTYPE_STRING | 17331)
#define SCCID_ERR_BADFILE                           (SCCIDTYPE_STRING | 17332)
#define SCCID_ERR_EMPTYFILE                         (SCCIDTYPE_STRING | 17333)
#define SCCID_ERR_PROTECTEDFILE                     (SCCIDTYPE_STRING | 17334)
#define SCCID_ERR_FILECREATE                        (SCCIDTYPE_STRING | 17335)
#define SCCID_ERR_FILECHANGED                       (SCCIDTYPE_STRING | 17336)
#define SCCID_ERR_FILEWRITEFAILED                   (SCCIDTYPE_STRING | 17337)
#define SCCID_ERR_EOF                               (SCCIDTYPE_STRING | 17338)
#define SCCID_ERR_INVALIDFILEHANDLE                 (SCCIDTYPE_STRING | 17339)
#define SCCID_ERR_OPENINPUTFAILED                   (SCCIDTYPE_STRING | 17340)
#define SCCID_ERR_FILECOPYFAILED                    (SCCIDTYPE_STRING | 17341)
#define SCCID_ERR_FILENOTAVAILABLE                  (SCCIDTYPE_STRING | 17342)
#define SCCID_ERR_RECORDDELETED                     (SCCIDTYPE_STRING | 17343)
#define SCCID_ERR_INVALIDPATH                       (SCCIDTYPE_STRING | 17344)
#define SCCID_ERR_INVALIDSPEC                       (SCCIDTYPE_STRING | 17345)
#define SCCID_ERR_BADINFOID                         (SCCIDTYPE_STRING | 17346)
#define SCCID_ERR_SEEKOUTOFRANGE                    (SCCIDTYPE_STRING | 17347)
#define SCCID_ERR_INVALIDID                         (SCCIDTYPE_STRING | 17348)
#define SCCID_ERR_UNSUPPORTEDFORMAT                 (SCCIDTYPE_STRING | 17349)
#define SCCID_ERR_NOFILTER                          (SCCIDTYPE_STRING | 17350)
#define SCCID_ERR_FILTERLOADFAILED                  (SCCIDTYPE_STRING | 17351)
#define SCCID_ERR_FILTERALLOCFAILED                 (SCCIDTYPE_STRING | 17352)
#define SCCID_ERR_FILTERTIMEOUT                     (SCCIDTYPE_STRING | 17353)
#define SCCID_ERR_FILTEREXCEPTACCESS                (SCCIDTYPE_STRING | 17354)
#define SCCID_ERR_FILTEREXCEPTZERO                  (SCCIDTYPE_STRING | 17355)
#define SCCID_ERR_FILTEREXCEPTOTHER                 (SCCIDTYPE_STRING | 17356)
#define SCCID_ERR_FILTERSCRAMBLEERROR               (SCCIDTYPE_STRING | 17357)
#define SCCID_ERR_FILTERTILEMAXEXCEEDED             (SCCIDTYPE_STRING | 17358)
#define SCCID_ERR_NODISPLAYENGINE                   (SCCIDTYPE_STRING | 17359)
#define SCCID_ERR_DISPLAYINITFAILED                 (SCCIDTYPE_STRING | 17360)
#define SCCID_ERR_CHUNKERINITFAILED                 (SCCIDTYPE_STRING | 17361)
#define SCCID_ERR_DATANOTAVAILABLE                  (SCCIDTYPE_STRING | 17362)
#define SCCID_ERR_VIEWERBAIL                        (SCCIDTYPE_STRING | 17363)
#define SCCID_ERR_CHARMAPFAILED                     (SCCIDTYPE_STRING | 17364)
#define SCCID_ERR_LASTPAGE                          (SCCIDTYPE_STRING | 17365)
#define SCCID_ERR_NOPAGE                            (SCCIDTYPE_STRING | 17366)
#define SCCID_ERR_OTHERPRINTING                     (SCCIDTYPE_STRING | 17367)
#define SCCID_ERR_FEATURENOTAVAIL                   (SCCIDTYPE_STRING | 17368)
#define SCCID_ERR_RAWTEXTDISABLED                   (SCCIDTYPE_STRING | 17369)
#define SCCID_ERR_DATAREMOTEERROR                   (SCCIDTYPE_STRING | 17370)
#define SCCID_ERR_EXCEPTION                         (SCCIDTYPE_STRING | 17371)
#define SCCID_ERR_EXCEPT_ACCESSVIOLATION            (SCCIDTYPE_STRING | 17372)
#define SCCID_ERR_EXCEPT_BREAKPOINT                 (SCCIDTYPE_STRING | 17373)
#define SCCID_ERR_EXCEPT_DATATYPEMISALIGNMENT       (SCCIDTYPE_STRING | 17374)
#define SCCID_ERR_EXCEPT_SINGLESTEP                 (SCCIDTYPE_STRING | 17375)
#define SCCID_ERR_EXCEPT_ARRAYBOUNDSEXCEEDED        (SCCIDTYPE_STRING | 17376)
#define SCCID_ERR_EXCEPT_FPDENORMALOPERAND          (SCCIDTYPE_STRING | 17377)
#define SCCID_ERR_EXCEPT_FPDIVIDEBYZERO             (SCCIDTYPE_STRING | 17378)
#define SCCID_ERR_EXCEPT_FPINEXACTRESULT            (SCCIDTYPE_STRING | 17379)
#define SCCID_ERR_EXCEPT_FPINVALIDOPERATION         (SCCIDTYPE_STRING | 17380)
#define SCCID_ERR_EXCEPT_FPOVERFLOW                 (SCCIDTYPE_STRING | 17381)
#define SCCID_ERR_EXCEPT_FPSTACKCHECK               (SCCIDTYPE_STRING | 17382)
#define SCCID_ERR_EXCEPT_FPUNDERFLOW                (SCCIDTYPE_STRING | 17383)
#define SCCID_ERR_EXCEPT_INTDIVIDEBYZERO            (SCCIDTYPE_STRING | 17384)
#define SCCID_ERR_EXCEPT_INTOVERFLOW                (SCCIDTYPE_STRING | 17385)
#define SCCID_ERR_EXCEPT_PRIVINSTRUCTION            (SCCIDTYPE_STRING | 17386)
#define SCCID_ERR_EXCEPT_NONCONTINUABLE             (SCCIDTYPE_STRING | 17387)
#define SCCID_ERR_EXCEPT_UNKNOWN                    (SCCIDTYPE_STRING | 17388)
#define SCCID_ERR_TESTNOTAVAILABLE                  (SCCIDTYPE_STRING | 17389)
#define SCCID_ERR_TESTTIMEOUT                       (SCCIDTYPE_STRING | 17390)
#define SCCID_ERR_CREATEBINFAILED                   (SCCIDTYPE_STRING | 17391)
#define SCCID_ERR_OPENBINFAILED                     (SCCIDTYPE_STRING | 17392)
#define SCCID_ERR_WRITEBINFAILED                    (SCCIDTYPE_STRING | 17393)
#define SCCID_ERR_READBINFAILED                     (SCCIDTYPE_STRING | 17394)
#define SCCID_ERR_OPENDUMPFAILED                    (SCCIDTYPE_STRING | 17395)
#define SCCID_ERR_COMPAREFAILED                     (SCCIDTYPE_STRING | 17396)
#define SCCID_ERR_CHUNKERRUNMISMATCH                (SCCIDTYPE_STRING | 17397)
#define SCCID_ERR_CHUNKERSIZEMISMATCH               (SCCIDTYPE_STRING | 17398)
#define SCCID_ERR_CHUNKERFAILED                     (SCCIDTYPE_STRING | 17399)
#define SCCID_ERR_CHUNKEROVERRUN                    (SCCIDTYPE_STRING | 17400)
#define SCCID_ERR_COMPRESSIONFAILED                 (SCCIDTYPE_STRING | 17401)
#define SCCID_ERR_STREAMBAIL                        (SCCIDTYPE_STRING | 17402)
#define SCCID_ERR_MISSINGELEMENT                    (SCCIDTYPE_STRING | 17403)
#define SCCID_ERR_TESTCOMPLETE                      (SCCIDTYPE_STRING | 17404)
#define SCCID_ERR_TESTMODESWITCH                    (SCCIDTYPE_STRING | 17405)
#define SCCID_ERR_BASELINEFILENOTFOUND              (SCCIDTYPE_STRING | 17406)
#define SCCID_ERR_COMPAREFILENOTFOUND               (SCCIDTYPE_STRING | 17407)
#define SCCID_ERR_TECHNOTAVAILABLE                  (SCCIDTYPE_STRING | 17408)
#define SCCID_ERR_TESTFILESEMPTY                    (SCCIDTYPE_STRING | 17409)
#define SCCID_ERR_INVALIDRESPONSE                   (SCCIDTYPE_STRING | 17410)

#define SCCID_ERR_COMMTIMEOUT                       (SCCIDTYPE_STRING | 17411)
#define SCCID_ERR_COMMUNKNOWN                       (SCCIDTYPE_STRING | 17412)
#define SCCID_ERR_CONNECTIONREFUSED                 (SCCIDTYPE_STRING | 17413)
#define SCCID_ERR_COMMFAULT                         (SCCIDTYPE_STRING | 17414)
#define SCCID_ERR_CONNECTIONDOWN                    (SCCIDTYPE_STRING | 17415)
#define SCCID_ERR_CONNECTIONUNREACHABLE             (SCCIDTYPE_STRING | 17416)
#define SCCID_ERR_DISCONNECTED                      (SCCIDTYPE_STRING | 17417)
#define SCCID_ERR_SYNCHRONIZE                       (SCCIDTYPE_STRING | 17418)

#define SCCID_ERR_HX_GENERAL                        (SCCIDTYPE_STRING | 17419)
#define SCCID_ERR_HX_TREE                           (SCCIDTYPE_STRING | 17420)
#define SCCID_ERR_HX_INVALIDVAL                     (SCCIDTYPE_STRING | 17421)
#define SCCID_ERR_HX_NONE                           (SCCIDTYPE_STRING | 17422)
#define SCCID_ERR_HX_ENDMACRO                       (SCCIDTYPE_STRING | 17423)
#define SCCID_ERR_HX_START                          (SCCIDTYPE_STRING | 17424)
#define SCCID_ERR_HX_EQ                             (SCCIDTYPE_STRING | 17425)
#define SCCID_ERR_HX_END                            (SCCIDTYPE_STRING | 17426)
#define SCCID_ERR_HX_ACTION                         (SCCIDTYPE_STRING | 17427)
#define SCCID_ERR_HX_SECTION                        (SCCIDTYPE_STRING | 17428)
#define SCCID_ERR_HX_ELEMENT                        (SCCIDTYPE_STRING | 17429)
#define SCCID_ERR_HX_LINK                           (SCCIDTYPE_STRING | 17430)
#define SCCID_ERR_HX_TAG                            (SCCIDTYPE_STRING | 17431)
#define SCCID_ERR_HX_TEMPLATE                       (SCCIDTYPE_STRING | 17432)
#define SCCID_ERR_HX_TYPE                           (SCCIDTYPE_STRING | 17433)
#define SCCID_ERR_HX_TYPENAME                       (SCCIDTYPE_STRING | 17434)
#define SCCID_ERR_HX_DEFINE                         (SCCIDTYPE_STRING | 17435)
#define SCCID_ERR_HX_DOCUMENT                       (SCCIDTYPE_STRING | 17436)
#define SCCID_ERR_HX_GENLINK                        (SCCIDTYPE_STRING | 17437)
#define SCCID_ERR_HX_INSERT                         (SCCIDTYPE_STRING | 17438)
#define SCCID_ERR_HX_REPEAT                         (SCCIDTYPE_STRING | 17439)
#define SCCID_ERR_HX_ALLOC                          (SCCIDTYPE_STRING | 17440)
#define SCCID_ERR_HX_INVALIDCMD                     (SCCIDTYPE_STRING | 17441)
#define SCCID_ERR_HX_INVALIDERRNUM                  (SCCIDTYPE_STRING | 17442)
#define SCCID_ERR_HX_HANDLEELEM                     (SCCIDTYPE_STRING | 17443)
#define SCCID_ERR_HX_ASISOUTTEXT                    (SCCIDTYPE_STRING | 17444)
#define SCCID_ERR_HX_OUTTEXT                        (SCCIDTYPE_STRING | 17445)
#define SCCID_ERR_HX_NOTEMPLATE                     (SCCIDTYPE_STRING | 17446)
#define SCCID_ERR_HX_OUTFILEFAIL                    (SCCIDTYPE_STRING | 17447)
#define SCCID_ERR_HX_NOENDREPEAT                    (SCCIDTYPE_STRING | 17448)
#define SCCID_ERR_HX_NOENDIF                        (SCCIDTYPE_STRING | 17449)
#define SCCID_ERR_HX_NOENDIGNORE                    (SCCIDTYPE_STRING | 17450)
#define SCCID_ERR_HX_NONREPEAT                      (SCCIDTYPE_STRING | 17451)
#define SCCID_ERR_HX_REPEATENDONINDEX               (SCCIDTYPE_STRING | 17452)
#define SCCID_ERR_HX_IFENDONINDEX                   (SCCIDTYPE_STRING | 17453)
#define SCCID_ERR_HX_INSERTENDONINDEX               (SCCIDTYPE_STRING | 17454)
#define SCCID_ERR_HX_NOELEMENT                      (SCCIDTYPE_STRING | 17455)
#define SCCID_ERR_HX_NOSTARTTAG                     (SCCIDTYPE_STRING | 17456)
#define SCCID_ERR_HX_INVALIDTYPE                    (SCCIDTYPE_STRING | 17457)
#define SCCID_ERR_HX_NOVALUE                        (SCCIDTYPE_STRING | 17458)
#define SCCID_ERR_HX_NOCONDITION                    (SCCIDTYPE_STRING | 17459)
#define SCCID_ERR_HX_INVALIDLINKPARAM               (SCCIDTYPE_STRING | 17460)
#define SCCID_ERR_HX_NOLINKPARAM                    (SCCIDTYPE_STRING | 17461)
#define SCCID_ERR_HX_BADCOUNTORVALUE                (SCCIDTYPE_STRING | 17462)
#define SCCID_ERR_HX_INVALIDELSE                    (SCCIDTYPE_STRING | 17463)
#define SCCID_ERR_HX_INVALIDCOND                    (SCCIDTYPE_STRING | 17464)
#define SCCID_ERR_HX_TEMPLATECREATE                 (SCCIDTYPE_STRING | 17465)
#define SCCID_ERR_HX_MAXELEMSPASSED                 (SCCIDTYPE_STRING | 17466)
#define SCCID_ERR_HX_NOTYPE                         (SCCIDTYPE_STRING | 17467)
#define SCCID_ERR_HX_CUSTOMELEMENT                  (SCCIDTYPE_STRING | 17468)
#define SCCID_ERR_HX_INVALIDELSEIF                  (SCCIDTYPE_STRING | 17469)
#define SCCID_ERR_HX_CSSPRAGMA                      (SCCIDTYPE_STRING | 17470)
#define SCCID_ERR_HX_ANCHOR                         (SCCIDTYPE_STRING | 17471)
#define SCCID_ERR_HX_LABEL                          (SCCIDTYPE_STRING | 17472)
#define SCCID_ERR_HX_DECKSIZEEXCEEDED               (SCCIDTYPE_STRING | 17473)
#define SCCID_ERR_HX_UNSUPPORTEDMACRO               (SCCIDTYPE_STRING | 17474)
#define SCCID_ERR_HX_NONBREAKINGREPEAT              (SCCIDTYPE_STRING | 17475)
#define SCCID_ERR_HX_NONBREAKINGTEMPLATE            (SCCIDTYPE_STRING | 17476)
#define SCCID_ERR_HX_INVALIDATTRIBUTE               (SCCIDTYPE_STRING | 17477)
#define SCCID_ERR_HX_INVALIDATTRIBVALUE             (SCCIDTYPE_STRING | 17478)
#define SCCID_ERR_HX_MALFORMEDUNIT                  (SCCIDTYPE_STRING | 17479)
#define SCCID_ERR_HX_TEXTBUFFERTOOSMALL             (SCCIDTYPE_STRING | 17480)
#define SCCID_ERR_HX_BUFFERTOOSMALLFORGRAPHICS      (SCCIDTYPE_STRING | 17481)
#define SCCID_ERR_HX_INTERNALEXPORTFILTER           (SCCIDTYPE_STRING | 17482)
#define SCCID_ERR_HX_TEMPLATEPARSE                  (SCCIDTYPE_STRING | 17483)
#define SCCID_ERR_HX_OUTPUTFILE                     (SCCIDTYPE_STRING | 17484)
#define SCCID_ERR_HX_INTERNALELEMENT				(SCCIDTYPE_STRING | 17485)
#define SCCID_ERR_HX_INTERNALPROCESS				(SCCIDTYPE_STRING | 17486)
#define SCCID_ERR_HX_INTERNALPREVIEW				(SCCIDTYPE_STRING | 17487)
#define SCCID_ERR_HX_INTERNALEXMU					(SCCIDTYPE_STRING | 17488)
#define SCCID_ERR_HX_INTERNALEXLM					(SCCIDTYPE_STRING | 17489)
#define SCCID_ERR_HX_INTERNALPARA                   (SCCIDTYPE_STRING | 17490)
#define SCCID_ERR_HX_INTERNALSTYLE                  (SCCIDTYPE_STRING | 17491)
#define SCCID_ERR_HX_INTERNALTABLE                  (SCCIDTYPE_STRING | 17492)
#define SCCID_ERR_HX_INTERNALTAGS                   (SCCIDTYPE_STRING | 17493)
#define SCCID_ERR_HX_INTERNALGRAPHICS               (SCCIDTYPE_STRING | 17494)

#define SCCID_ERR_IX_STARTPAGE						(SCCIDTYPE_STRING | 17496)
#define SCCID_ERR_COMPRESSION_DISABLED				(SCCIDTYPE_STRING | 17497)
#define SCCID_ERR_IX_ENDPAGE						(SCCIDTYPE_STRING | 17498)

#define SCCID_ERR_CHARMAPBIN_NOFILE                 (SCCIDTYPE_STRING | 17499)

#define SCCID_ERR_ANNOLOAD							(SCCIDTYPE_STRING | 17500)
#define SCCID_ERR_ANNOFUNCTION						(SCCIDTYPE_STRING | 17501)
#define SCCID_ERR_NODATATORENDER          (SCCIDTYPE_STRING | 17502)
#define SCCID_VWMESSAGE_NODATATORENDER         SCCID_ERR_NODATATORENDER

#define SCCID_ERR_HX_INTERNALTAGID                  (SCCIDTYPE_STRING | 17503)
#define SCCID_ERR_HX_INTERNALLOCATIONID             (SCCIDTYPE_STRING | 17504)
#define SCCID_ERR_HX_INTERNALSSCELL                 (SCCIDTYPE_STRING | 17505)
#define SCCID_ERR_HX_INTERNALEMPTYSHEET             (SCCIDTYPE_STRING | 17506)
#define SCCID_ERR_HX_INTERNALDOCUMENT				(SCCIDTYPE_STRING | 17507)

#define SCCID_ERR_OSGD_NOFONTS				        (SCCIDTYPE_STRING | 17508)
#define SCCID_ERR_BADFILENAME						(SCCIDTYPE_STRING | 17509)
#define SCCID_ERR_INVALIDFONTDIR					(SCCIDTYPE_STRING | 17510)

#define SCCID_ERR_HX_SECTNODATA                     (SCCIDTYPE_STRING | 17511)

#define SCCID_ERR_GPFAULT                           (SCCIDTYPE_STRING | 17512)
#define SCCID_ERR_DIVIDEBYZERO                      (SCCIDTYPE_STRING | 17513)
#define SCCID_ERR_OTHEREXCEPTION                    (SCCIDTYPE_STRING | 17514)
#define SCCID_ERR_NOHTMLEXPORTFILTER                (SCCIDTYPE_STRING | 17515)
#define SCCID_ERR_NOGRAPHICEXPORTFILTER             (SCCIDTYPE_STRING | 17516)
#define SCCID_ERR_STACK_BUFFER_OVERRUN              (SCCIDTYPE_STRING | 17517)

#define SCCID_ERR_OUTPUTSOLUTION_LOADFAILED         (SCCIDTYPE_STRING | 17518)
#define SCCID_ERR_DRMFILE                           (SCCIDTYPE_STRING | 17519)

#define SCCID_ERR_IX_WATERMARKWILLNOTFITTARGET      (SCCIDTYPE_STRING | 17520)
#define SCCID_ERR_IX_WATERMARKTYPENOTSUPPORTED      (SCCIDTYPE_STRING | 17521)
#define SCCID_ERR_EXTERNALURLREFERENCE              (SCCIDTYPE_STRING | 17522)

#define SCCID_ERR_CHUNKERFAILURE                    (SCCIDTYPE_STRING | 17523)

#define SCCID_ERR_OCRMISSING                        (SCCIDTYPE_STRING | 17524)
#define SCCID_ERR_OCR_UNKNOWNERR                    (SCCIDTYPE_STRING | 17525)
#define SCCID_ERR_OCR_LICENCEFAIL                   (SCCIDTYPE_STRING | 17526)
#define SCCID_ERR_OCR_INVALIDTECH                   (SCCIDTYPE_STRING | 17527)
#define SCCID_ERR_OCR_INVALIDQUAL                   (SCCIDTYPE_STRING | 17528)
#define SCCID_ERR_OCR_LOADFAILED                    (SCCIDTYPE_STRING | 17529)
#define SCCID_ERR_OCR_INPUTFAILURE                  (SCCIDTYPE_STRING | 17530)
#define SCCID_ERR_OCR_FILETOOBIG                    (SCCIDTYPE_STRING | 17531)

#define SCCID_ERR_LINKTOFILE                        (SCCIDTYPE_STRING | 17532)
#define SCCID_ERR_UNSUPPORTEDCOMPRESSION            (SCCIDTYPE_STRING | 17533)
#define SCCID_ERR_NOTARCHIVEFILE                    (SCCIDTYPE_STRING | 17534)
#define SCCID_ERR_NOTSUPPORTEDARCHIVEFILE           (SCCIDTYPE_STRING | 17535)
#define SCCID_ERR_INVALIDHDOC                       (SCCIDTYPE_STRING | 17536)
#define SCCID_ERR_BADCREDENTIAL                     (SCCIDTYPE_STRING | 17537)
#define SCCID_ERR_FILESIZE                          (SCCIDTYPE_STRING | 17538)
#define SCCID_ERR_OUTPUT_SOL_MISSING                (SCCIDTYPE_STRING | 17539)

#define SCCID_ERR_INSUFFICIENTPRINTABLEPAGEHEIGHT   (SCCIDTYPE_STRING | 17540)
#define SCCID_ERR_INSUFFICIENTPRINTABLEPAGEWIDTH    (SCCIDTYPE_STRING | 17541)

#define SCCID_ERR_FILTERGENERAL                     (SCCIDTYPE_STRING | 17542)
#define SCCID_ERR_FILEIDFAILED                      (SCCIDTYPE_STRING | 17543)
#define SCCID_ERR_EMPTYSECTION                      (SCCIDTYPE_STRING | 17544)
#define SCCID_ERR_DISPLAYALLOCFAILED                (SCCIDTYPE_STRING | 17545)
#define SCCID_ERR_UNKNOWNNOTVIEWED                  (SCCIDTYPE_STRING | 17546)
#define SCCID_ERR_NOPRINTER                         (SCCIDTYPE_STRING | 17547)
#define SCCID_ERR_PRINTERINITFAILED                 (SCCIDTYPE_STRING | 17548)
#define SCCID_ERR_PRINTINGFAILED                    (SCCIDTYPE_STRING | 17549)
#define SCCID_ERR_BADPRINTERDC                      (SCCIDTYPE_STRING | 17550)
#define SCCID_ERR_NOPRINTDEVICE                     (SCCIDTYPE_STRING | 17551)
#define SCCID_ERR_NOPRINTDIALOG                     (SCCIDTYPE_STRING | 17552)
#define SCCID_ERR_PRINTERSTARTDOCFAILED             (SCCIDTYPE_STRING | 17553)
#define SCCID_ERR_LOBADID                           (SCCIDTYPE_STRING | 17554)
#define SCCID_ERR_LONOSTRING                        (SCCIDTYPE_STRING | 17555)
#define SCCID_ERR_LOLIBLINKFAIL                     (SCCIDTYPE_STRING | 17556)
#define SCCID_ERR_LOINITLINKFAIL                    (SCCIDTYPE_STRING | 17557)
#define SCCID_ERR_LOGETSTRINGLINKFAIL               (SCCIDTYPE_STRING | 17558)
#define SCCID_ERR_LODEINITLINKFAIL                  (SCCIDTYPE_STRING | 17559)
#define SCCID_ERR_LONOCREATE                        (SCCIDTYPE_STRING | 17560)
#define SCCID_ERR_LODODIALOG                        (SCCIDTYPE_STRING | 17561)
#define SCCID_ERR_LODOACTION                        (SCCIDTYPE_STRING | 17562)
#define SCCID_ERR_NULLPOINTER                       (SCCIDTYPE_STRING | 17563)
#define SCCID_ERR_NODERELEASED                      (SCCIDTYPE_STRING | 17564)
#define SCCID_ERR_NODEATTACHED                      (SCCIDTYPE_STRING | 17565)
#define SCCID_ERR_NODENOTATTACHED                   (SCCIDTYPE_STRING | 17566)
#define SCCID_ERR_ALLCHILDRENATTACHED               (SCCIDTYPE_STRING | 17567)
#define SCCID_ERR_NODEATTRIBUTESDONE                (SCCIDTYPE_STRING | 17568)
#define SCCID_ERR_DUPLICATEID                       (SCCIDTYPE_STRING | 17569)
#define SCCID_ERR_IDASSIGNED                        (SCCIDTYPE_STRING | 17570)
#define SCCID_ERR_NODEATTRIBUTESNOTDONE             (SCCIDTYPE_STRING | 17571)
#define SCCID_ERR_DIFFERENTTREE                     (SCCIDTYPE_STRING | 17572)
#define SCCID_ERR_OLESTORAGENOTSUPPORTED            (SCCIDTYPE_STRING | 17573)

/* subdoc property name strings */
#define SCCID_HX_SUBDOC_AUTHOR                      (SCCIDTYPE_STRING | 17600)
#define SCCID_HX_SUBDOC_CREATEDATE                  (SCCIDTYPE_STRING | 17601)   
#define SCCID_HX_SUBDOC_LASTSAVEDATE                (SCCIDTYPE_STRING | 17602)
#define SCCID_HX_SUBDOC_TITLE                       (SCCIDTYPE_STRING | 17603)
#define SCCID_HX_SUBDOC_NOTES                       (SCCIDTYPE_STRING | 17604)
#define SCCID_HX_SUBDOC_AUTHORSHORT                 (SCCIDTYPE_STRING | 17605)

/*
|  Transformation Server reserves the range of id's from 18000 to 18999.
|	Do not attempt to store these options into any OIT, OIVT or EX options store.
*/
#define SCCID_TS_STARTID				 (SCCIDTYPE_OPTION | 18000)
#define SCCID_TS_MAXID					 (SCCIDTYPE_OPTION | 18999)

/*
| HTML Converter reserves the range of id's from 19000 to 19999.
| Do not attempt to store these options into any OIT, OIVT or EX options store.
*/
/* message */
#define SCCID_HC_MSG_LOGLEVEL                       (SCCIDTYPE_STRING | 19000)
#define SCCID_HC_MSG_FATAL                          (SCCIDTYPE_STRING | 19001)
#define SCCID_HC_MSG_WARNING                        (SCCIDTYPE_STRING | 19002)
#define SCCID_HC_MSG_OUTPUTFILES                    (SCCIDTYPE_STRING | 19003)
#define SCCID_HC_MSG_START                          (SCCIDTYPE_STRING | 19004)
#define SCCID_HC_MSG_END                            (SCCIDTYPE_STRING | 19005)
#define SCCID_HC_MSG_OUTPUTFILE                     (SCCIDTYPE_STRING | 19006)
#define SCCID_HC_MSG_DEFAULT                        (SCCIDTYPE_STRING | 19007)
#define SCCID_HC_MSG_SUMMARY                        (SCCIDTYPE_STRING | 19008)
#define SCCID_HC_MSG_FATALERROR                     (SCCIDTYPE_STRING | 19009)

/*
|  PST filter strings.
*/
#define SCCID_PST_SUBJECT							(SCCIDTYPE_STRING | 20000)
#define SCCID_PST_OWNER								(SCCIDTYPE_STRING | 20001)
#define SCCID_PST_RECIPIENT							(SCCIDTYPE_STRING | 20002)
#define SCCID_PST_ATTENDEES							(SCCIDTYPE_STRING | 20003)
#define SCCID_PST_NONE								(SCCIDTYPE_STRING | 20004)
#define SCCID_PST_COMPANY_NAME						(SCCIDTYPE_STRING | 20005)
#define SCCID_PST_MINUTES							(SCCIDTYPE_STRING | 20006)
#define SCCID_PST_HOURS								(SCCIDTYPE_STRING | 20007)
#define SCCID_PST_NOT_STARTED						(SCCIDTYPE_STRING | 20008)
#define SCCID_PST_IN_PROGRESS						(SCCIDTYPE_STRING | 20009)
#define SCCID_PST_COMPLETED							(SCCIDTYPE_STRING | 20010)
#define SCCID_PST_WAITING							(SCCIDTYPE_STRING | 20011)
#define SCCID_PST_DEFERRED							(SCCIDTYPE_STRING | 20012)
#define SCCID_PST_PERCENT_COMPLETE					(SCCIDTYPE_STRING | 20013)
#define SCCID_PST_TOTAL_WORK						(SCCIDTYPE_STRING | 20014)
#define SCCID_PST_LOW								(SCCIDTYPE_STRING | 20015)
#define SCCID_PST_HIGH								(SCCIDTYPE_STRING | 20016)
#define SCCID_PST_AM								(SCCIDTYPE_STRING | 20017)
#define SCCID_PST_PM								(SCCIDTYPE_STRING | 20018)
#define SCCID_PST_START_DATE						(SCCIDTYPE_STRING | 20019)
#define SCCID_PST_DUE_DATE							(SCCIDTYPE_STRING | 20020)
#define SCCID_PST_BILLING							(SCCIDTYPE_STRING | 20021)
#define SCCID_PST_CONTACTS							(SCCIDTYPE_STRING | 20022)
#define SCCID_PST_ENTRY_TYPE						(SCCIDTYPE_STRING | 20023)
#define SCCID_PST_SENDER							(SCCIDTYPE_STRING | 20024)
#define SCCID_PST_COMPANY                           (SCCIDTYPE_STRING | 20025)
#define SCCID_PST_CATEGORIES                        (SCCIDTYPE_STRING | 20026)
#define SCCID_PST_MILEAGE                           (SCCIDTYPE_STRING | 20027)
#define SCCID_PST_STATUS                            (SCCIDTYPE_STRING | 20028)
#define SCCID_PST_DAYS                              (SCCIDTYPE_STRING | 20029)
#define SCCID_PST_WEEKS                             (SCCIDTYPE_STRING | 20030)
#define SCCID_PST_NAME                              (SCCIDTYPE_STRING | 20031)
#define SCCID_PST_ENTRYID                           (SCCIDTYPE_STRING | 20032)

#define SCCID_MSG_PRIVATE                           (SCCIDTYPE_STRING | 20050)
#define SCCID_MSG_PERSONAL                          (SCCIDTYPE_STRING | 20051)
#define SCCID_MSG_CONFIDENTIAL                      (SCCIDTYPE_STRING | 20052)

/*These MAILFIELD strings belong with the other SCCID_MAIL strings, but they would not fit in the range specified for
 |them.  Therfore I've put them here with a comment to see below by the SCCID_MAIL strings.
 |
*/
#define SCCID_MAILFIELD_DISPLAY_TO								(SCCIDTYPE_STRING | 20101)
#define SCCID_MAILFIELD_SUBJECT									(SCCIDTYPE_STRING | 20102)
#define SCCID_MAILFIELD_DISPLAY_CC								(SCCIDTYPE_STRING | 20103)
#define SCCID_MAILFIELD_DISPLAY_BCC								(SCCIDTYPE_STRING | 20104)
#define SCCID_MAILFIELD_IMPORTANCE								(SCCIDTYPE_STRING | 20105)
#define SCCID_MAILFIELD_SENSITIVITY								(SCCIDTYPE_STRING | 20106)
#define SCCID_MAILFIELD_FLAGSTS									(SCCIDTYPE_STRING | 20107)
#define SCCID_MAILFIELD_ALTERNATE_RECIPIENT_ALLOWED				(SCCIDTYPE_STRING | 20108)
#define SCCID_MAILFIELD_PRIORITY								(SCCIDTYPE_STRING | 20109)
#define SCCID_MAILFIELD_CLIENT_SUBMIT_TIME						(SCCIDTYPE_STRING | 20110)
#define SCCID_MAILFIELD_CREATION_TIME							(SCCIDTYPE_STRING | 20111)
#define SCCID_MAILFIELD_LAST_MODIFICATION_TIME					(SCCIDTYPE_STRING | 20112)
#define SCCID_MAILFIELD_PROVIDER_SUBMIT_TIME					(SCCIDTYPE_STRING | 20113)
#define SCCID_MAILFIELD_CONVERSATION_INDEX						(SCCIDTYPE_STRING | 20114)
#define SCCID_MAILFIELD_CONVERSATION_TOPIC						(SCCIDTYPE_STRING | 20115)
#define SCCID_MAILFIELD_MESSAGE_CC_ME							(SCCIDTYPE_STRING | 20116)
#define SCCID_MAILFIELD_MESSAGE_DELIVERY_TIME					(SCCIDTYPE_STRING | 20117)
#define SCCID_MAILFIELD_MSGFLAG									(SCCIDTYPE_STRING | 20118)
#define SCCID_MAILFIELD_MESSAGE_SIZE							(SCCIDTYPE_STRING | 20119)
#define SCCID_MAILFIELD_MESSAGE_SUBMISSION_ID					(SCCIDTYPE_STRING | 20120)
#define SCCID_MAILFIELD_MESSAGE_CLASS							(SCCIDTYPE_STRING | 20121)
#define SCCID_MAILFIELD_ORIGINATOR_DELIVERY_REPORT_REQUESTED	(SCCIDTYPE_STRING | 20122)
#define SCCID_MAILFIELD_READ_RECEIPT_REQUESTED					(SCCIDTYPE_STRING | 20123)
#define SCCID_MAILFIELD_RCVD_REPRESENTING_ADDRTYPE				(SCCIDTYPE_STRING | 20124)
#define SCCID_MAILFIELD_RCVD_REPRESENTING_EMAIL_ADDRESS			(SCCIDTYPE_STRING | 20125)
#define SCCID_MAILFIELD_RCVD_REPRESENTING_ENTRYID				(SCCIDTYPE_STRING | 20126)
#define SCCID_MAILFIELD_RCVD_REPRESENTING_NAME					(SCCIDTYPE_STRING | 20127)
#define SCCID_MAILFIELD_RCVD_REPRESENTING_SEARCH_KEY			(SCCIDTYPE_STRING | 20128)
#define SCCID_MAILFIELD_RECEIVED_BY_ADDRTYPE					(SCCIDTYPE_STRING | 20129)
#define SCCID_MAILFIELD_RECEIVED_BY_EMAIL_ADDRESS				(SCCIDTYPE_STRING | 20130)
#define SCCID_MAILFIELD_RECEIVED_BY_ENTRYID						(SCCIDTYPE_STRING | 20131)
#define SCCID_MAILFIELD_RECEIVED_BY_NAME						(SCCIDTYPE_STRING | 20132)
#define SCCID_MAILFIELD_RECEIVED_BY_SEARCH_KEY					(SCCIDTYPE_STRING | 20133)
#define SCCID_MAILFIELD_RTF_IN_SYNC								(SCCIDTYPE_STRING | 20134)
#define SCCID_MAILFIELD_RTF_SYNC_BODY_COUNT						(SCCIDTYPE_STRING | 20135)
#define SCCID_MAILFIELD_RTF_SYNC_BODY_CRC						(SCCIDTYPE_STRING | 20136)
#define SCCID_MAILFIELD_RTF_SYNC_BODY_TAG						(SCCIDTYPE_STRING | 20137)
#define SCCID_MAILFIELD_RTF_SYNC_PREFIX_COUNT					(SCCIDTYPE_STRING | 20138)
#define SCCID_MAILFIELD_RTF_SYNC_TRAILING_COUNT					(SCCIDTYPE_STRING | 20139)
#define SCCID_MAILFIELD_SEARCH_KEY								(SCCIDTYPE_STRING | 20140)
#define SCCID_MAILFIELD_SENDER_ADDRTYPE							(SCCIDTYPE_STRING | 20141)
#define SCCID_MAILFIELD_SENDER_EMAIL_ADDRESS					(SCCIDTYPE_STRING | 20142)
#define SCCID_MAILFIELD_SENDER_ENTRYID							(SCCIDTYPE_STRING | 20143)
#define SCCID_MAILFIELD_SENDER_NAME								(SCCIDTYPE_STRING | 20144)
#define SCCID_MAILFIELD_SENDER_SEARCH_KEY						(SCCIDTYPE_STRING | 20145)
#define SCCID_MAILFIELD_SENT_REPRESENTING_ADDRTYPE				(SCCIDTYPE_STRING | 20146)
#define SCCID_MAILFIELD_SENT_REPRESENTING_EMAIL_ADDRESS			(SCCIDTYPE_STRING | 20147)
#define SCCID_MAILFIELD_SENT_REPRESENTING_ENTRYID				(SCCIDTYPE_STRING | 20148)
#define SCCID_MAILFIELD_SENT_REPRESENTING_NAME					(SCCIDTYPE_STRING | 20149)
#define SCCID_MAILFIELD_SENT_REPRESENTING_SEARCH_KEY			(SCCIDTYPE_STRING | 20150)
#define SCCID_MAILFIELD_TRANSPORT_MESSAGE_HEADERS				(SCCIDTYPE_STRING | 20151)
#define SCCID_MAILFIELD_AUTO_FORWARDED							(SCCIDTYPE_STRING | 20152)
#define SCCID_MAILFIELD_DEFERRED_DELIVERY_TIME					(SCCIDTYPE_STRING | 20153)
#define SCCID_MAILFIELD_EXPIRY_TIME								(SCCIDTYPE_STRING | 20154)
#define SCCID_MAILFIELD_LATEST_DELIVERY_TIME					(SCCIDTYPE_STRING | 20155)
#define SCCID_MAILFIELD_RECIPIENT_REASSIGNMENT_PROHIBITED		(SCCIDTYPE_STRING | 20156)
#define SCCID_MAILFIELD_REPLY_TIME								(SCCIDTYPE_STRING | 20157)
#define SCCID_MAILFIELD_REPORT_TAG								(SCCIDTYPE_STRING | 20158)
#define SCCID_MAILFIELD_RESPONSE_REQUESTED						(SCCIDTYPE_STRING | 20159)
#define SCCID_MAILFIELD_REPLY_REQUESTED							(SCCIDTYPE_STRING | 20160)
#define SCCID_MAILFIELD_DELETE_AFTER_SUBMIT						(SCCIDTYPE_STRING | 20161)
#define SCCID_MAILFIELD_MESSAGE_LOCALE_ID						(SCCIDTYPE_STRING | 20162)
#define SCCID_MAILFIELD_CREATOR_NAME							(SCCIDTYPE_STRING | 20163)
#define SCCID_MAILFIELD_CREATOR_ENTRYID							(SCCIDTYPE_STRING | 20164)
#define SCCID_MAILFIELD_LAST_MODIFIER_NAME						(SCCIDTYPE_STRING | 20165)
#define SCCID_MAILFIELD_LAST_MODIFIER_ENTRYID					(SCCIDTYPE_STRING | 20166)
#define SCCID_MAILFIELD_INTERNET_ARTICLE_NUMBER 				(SCCIDTYPE_STRING | 20167)
#define SCCID_MAILFIELD_NT_SECURITY_DESCRIPTOR					(SCCIDTYPE_STRING | 20168)
#define SCCID_MAILFIELD_TRUST_SENDER							(SCCIDTYPE_STRING | 20169)
#define SCCID_MAILFIELD_INTERNET_MESSAGE_ID 					(SCCIDTYPE_STRING | 20170)
#define SCCID_MAILFIELD_ATTR_HIDDEN								(SCCIDTYPE_STRING | 20171)
#define SCCID_MAILFIELD_ATTR_SYSTEM								(SCCIDTYPE_STRING | 20172)
#define SCCID_MAILFIELD_ATTR_READONLY							(SCCIDTYPE_STRING | 20173)
#define SCCID_MAILFIELD_INTERNET_CPID							(SCCIDTYPE_STRING | 20174)
#define SCCID_MAILFIELD_MESSAGE_CODEPAGE						(SCCIDTYPE_STRING | 20175)
#define SCCID_MAILFIELD_SENDER_FLAGS							(SCCIDTYPE_STRING | 20176)
#define SCCID_MAILFIELD_SENT_REPRESENTING_FLAGS					(SCCIDTYPE_STRING | 20177)
#define SCCID_MAILFIELD_RCVD_BY_FLAGS							(SCCIDTYPE_STRING | 20178)
#define SCCID_MAILFIELD_RCVD_REPRESENTING_FLAGS					(SCCIDTYPE_STRING | 20179)
#define SCCID_MAILFIELD_INET_MAIL_OVERRIDE_FORMAT				(SCCIDTYPE_STRING | 20180)
#define SCCID_MAILFIELD_MSG_EDITOR_FORMAT						(SCCIDTYPE_STRING | 20181)
#define SCCID_MAILFIELD_PROFILE_CONNECT_FLAGS					(SCCIDTYPE_STRING | 20182)
#define SCCID_MAILFIELD_PROOF_OF_DELIVERY_REQUESTED				(SCCIDTYPE_STRING | 20183)
#define SCCID_MAILFIELD_PROOF_OF_SUBMISSION_REQUESTED           (SCCIDTYPE_STRING | 20184)
#define SCCID_MAILFIELD_IN_REPLY_TO_ID							(SCCIDTYPE_STRING | 20185)


#define SCCID_MAIL_HOMEPHONE2                                   (SCCIDTYPE_STRING | 20200)
#define SCCID_MAIL_HOMEFAX                                      (SCCIDTYPE_STRING | 20201)
#define SCCID_MAIL_ISDN                                         (SCCIDTYPE_STRING | 20202)
#define SCCID_MAIL_MOBILEPHONE                                  (SCCIDTYPE_STRING | 20203)
#define SCCID_MAIL_OTHERPHONE                                   (SCCIDTYPE_STRING | 20204)
#define SCCID_MAIL_OTHERFAX                                     (SCCIDTYPE_STRING | 20205)
#define SCCID_MAIL_PAGERPHONE                                   (SCCIDTYPE_STRING | 20206)
#define SCCID_MAIL_PRIMARYPHONE                                 (SCCIDTYPE_STRING | 20207)
#define SCCID_MAIL_RADIOPHONE                                   (SCCIDTYPE_STRING | 20208)
#define SCCID_MAIL_TELEXPHONE                                   (SCCIDTYPE_STRING | 20209)
#define SCCID_MAIL_TTYTTDPHONE                                  (SCCIDTYPE_STRING | 20210)
#define SCCID_MAIL_REMINDERTOPIC                                (SCCIDTYPE_STRING | 20211)
#define SCCID_MAIL_EMAIL2                                       (SCCIDTYPE_STRING | 20212)
#define SCCID_MAIL_EMAIL3                                       (SCCIDTYPE_STRING | 20213)
#define SCCID_MAIL_BUSINESSSTREET                               (SCCIDTYPE_STRING | 20214)
#define SCCID_MAIL_BUSINESSPOBOX                                (SCCIDTYPE_STRING | 20215)
#define SCCID_MAIL_BUSINESSCITY                                 (SCCIDTYPE_STRING | 20216)
#define SCCID_MAIL_BUSINESSSTATE                                (SCCIDTYPE_STRING | 20217)
#define SCCID_MAIL_BUSINESSPOSTALCODE                           (SCCIDTYPE_STRING | 20218)
#define SCCID_MAIL_BUSINESSCOUNTRY                              (SCCIDTYPE_STRING | 20219)
#define SCCID_MAIL_HOMESTREET                                   (SCCIDTYPE_STRING | 20220)
#define SCCID_MAIL_HOMEPOBOX                                    (SCCIDTYPE_STRING | 20221)
#define SCCID_MAIL_HOMECITY                                     (SCCIDTYPE_STRING | 20222)
#define SCCID_MAIL_HOMESTATE                                    (SCCIDTYPE_STRING | 20223)
#define SCCID_MAIL_HOMEPOSTALCODE                               (SCCIDTYPE_STRING | 20224)
#define SCCID_MAIL_HOMECOUNTRY                                  (SCCIDTYPE_STRING | 20225)
#define SCCID_MAIL_OTHERSTREET                                  (SCCIDTYPE_STRING | 20226)
#define SCCID_MAIL_OTHERPOBOX                                   (SCCIDTYPE_STRING | 20227)
#define SCCID_MAIL_OTHERCITY                                    (SCCIDTYPE_STRING | 20228)
#define SCCID_MAIL_OTHERSTATE                                   (SCCIDTYPE_STRING | 20229)
#define SCCID_MAIL_OTHERPOSTALCODE                              (SCCIDTYPE_STRING | 20230)
#define SCCID_MAIL_OTHERCOUNTRY                                 (SCCIDTYPE_STRING | 20231)
#define SCCID_MAIL_PERSONALHOMEPAGE                             (SCCIDTYPE_STRING | 20232)
#define SCCID_MAIL_INTERNETFREEBUSYADDR                         (SCCIDTYPE_STRING | 20233)
#define SCCID_MAIL_MANAGERSNAME                                 (SCCIDTYPE_STRING | 20234)
#define SCCID_MAIL_ASSISTANTSNAME                               (SCCIDTYPE_STRING | 20235)
#define SCCID_MAIL_OFFICE                                       (SCCIDTYPE_STRING | 20236)
#define SCCID_MAIL_PROFESSION                                   (SCCIDTYPE_STRING | 20237)
#define SCCID_MAIL_SPOUSESNAME                                  (SCCIDTYPE_STRING | 20238)
#define SCCID_MAIL_ANNIVERSARY                                  (SCCIDTYPE_STRING | 20239)
#define SCCID_MAIL_BIRTHDAY                                     (SCCIDTYPE_STRING | 20240)
#define SCCID_MAIL_NORMALIZED_SUBJECT                           (SCCIDTYPE_STRING | 20241)
#define SCCID_MAIL_REQATTENDEE									(SCCIDTYPE_STRING | 20242)
#define SCCID_MAIL_OPTATTENDEE  								(SCCIDTYPE_STRING | 20243)
#define SCCID_MAIL_APPOINTMENT_DURATION							(SCCIDTYPE_STRING | 20244)
#define SCCID_MAIL_TASK_COMPLETE								(SCCIDTYPE_STRING | 20245)



/* Office 2007 default chart text strings */
#define SCCID_CHART_TITLE                                       (SCCIDTYPE_STRING | 20500)
#define SCCID_CHART_AXISTITLE                                   (SCCIDTYPE_STRING | 20501)
#define SCCID_CHART_SERIES                                      (SCCIDTYPE_STRING | 20502)



/*
|  PDF filter text strings.
*/
#define SCCID_PDF_PORTFOLIO_CONTENTDIRECTORY                    (SCCIDTYPE_STRING | 20550)
#define SCCID_PDF_PORTFOLIO_HOMEDIRECTORY                       (SCCIDTYPE_STRING | 20551)



/*
| archive type strings
*/
#define SCCID_HX_ARCTYPECONTAINER                   (SCCIDTYPE_STRING | 21000)
#define SCCID_HX_ARCTYPECOMPFILE                    (SCCIDTYPE_STRING | 21001)
#define SCCID_HX_ARCTYPEMESSAGE                     (SCCIDTYPE_STRING | 21002)
#define SCCID_HX_ARCTYPECONTACT                     (SCCIDTYPE_STRING | 21003)
#define SCCID_HX_ARCTYPECALENDAR                    (SCCIDTYPE_STRING | 21004)
#define SCCID_HX_ARCTYPENOTE                        (SCCIDTYPE_STRING | 21005)
#define SCCID_HX_ARCTYPETASK                        (SCCIDTYPE_STRING | 21006)
#define SCCID_HX_ARCTYPEJOURNAL                     (SCCIDTYPE_STRING | 21007)
#define SCCID_HX_ARCTYPEATTACH                      (SCCIDTYPE_STRING | 21008)
#define SCCID_HX_ARCTYPEFIELDSFILE                  (SCCIDTYPE_STRING | 21009)

/*
| Watermark type stings
*/
#define SCCID_ENABLEWATERMARK						(SCCIDTYPE_STRING | 22000)
#define	SCCID_WATERMARKPOSITION						(SCCIDTYPE_STRING | 22001)
#define SCCID_WATERMARKIO							(SCCIDTYPE_STRING | 22002)
#define SCCID_DEFAULTPAGESIZE						(SCCIDTYPE_STRING | 22003)
#define SCCID_FONTDIRECTORY							(SCCIDTYPE_STRING | 22004)
#define SCCID_APPLYFILTER							(SCCIDTYPE_STRING | 22005)
#define SCCID_EMBEDFONTS                            (SCCIDTYPE_STRING | 22006)
#define SCCID_DOLINEARIZATION                       (SCCIDTYPE_STRING | 22007)

#define SCCID_DEFAULTDISPLAYFONTALIASMAP_COUNT			(SCCIDTYPE_STRING | 23000)
#define SCCID_DEFAULTDISPLAYFONTALIASMAP_ORIGINALBASE	(SCCIDTYPE_STRING | 23100)
#define SCCID_DEFAULTDISPLAYFONTALIASMAP_ALIASBASE		(SCCIDTYPE_STRING | 23200)

#define SCCID_DEFAULTPRINTFONTALIASMAP_COUNT			(SCCIDTYPE_STRING | 23300)
#define SCCID_DEFAULTPRINTFONTALIASMAP_ORIGINALBASE		(SCCIDTYPE_STRING | 23400)
#define SCCID_DEFAULTPRINTFONTALIASMAP_ALIASBASE		(SCCIDTYPE_STRING | 23500)

/* xmp metadata */
#define SCCID_XMP_NAMESPACE                             (SCCIDTYPE_STRING | 23600)

#ifdef __cplusplus
}
#endif

#ifdef SCC_PACKED_BY_SCCID_H
#pragma pack(pop)
#undef SCC_PACKED_BY_SCCID_H
#undef SCC_PACK_SET
#endif /* SCC_PACKED_BY_SCCID_H */

#endif /*SCCID_H*/
