package edu.georgetown.gucs.dictionary;

import edu.georgetown.gucs.utility.ExceptionHandler;
import edu.georgetown.gucs.utility.Global;

/**
 * Prints all the tokens and their frequencies, IDFs, and normalized IDFs for a {@linkplain Dictionary}
 * 
 * @author Clay Shields
 */
public class ShowDictionaryTokens {

    /**
   * Prints each token and its information in the specified dictionary
   * 
   * @param dictionary_file
   *          the string filename containing the serialized dictionary
   */
  public static void print(String dictionary_file) {
      Dictionary dictionary = new Dictionary(dictionary_file);
    dictionary.showTokens();
  }

  /**
   * Prints a dictionary's tokens and their frequencies, IDFs, and normalized IDFs
   * 
   * @param args
   *          array of string command line arguments<br>
   *          <code>args[0]</code> the filename containing the dictionary to show
   */
  public static void main(String args[]) {
    try {
      ShowDictionaryTokens.print(args[0]);
    } catch (ArrayIndexOutOfBoundsException e) {
      System.err.println("Usage: java ShowDictionaryTokens <dictionary file name>");
      System.err.println("Prints a dictionary's tokens and their frequencies, IDFs, and normalized IDFs");
      System.exit(-1);
    } catch (RuntimeException exception) {
      ExceptionHandler.handleExceptionExit(exception);
    }
  }
}
