package edu.georgetown.gucs.experiment;

import edu.georgetown.gucs.utility.Global;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.BlockingQueue;

/**
 * @author Evan B.
 * @since 10/6/14.
 *
 * This class prints results stored in a queue
 *
 */
public class ResultTracker extends Thread {

    private static final ResultTracker instance = new ResultTracker();

    private static final ExperimentResults SHUTDOWN_REQ = new ExperimentResults();

    private volatile boolean shuttingDown, experimentTerminated;

    private static String fileName = null;

    private BlockingQueue<ExperimentResults> finishedResults =
            new ArrayBlockingQueue<>(100);

    private ResultTracker() {

        start();
    }

    public static ResultTracker getResult() {

        return instance;
    }

    //add a way to set the fileName

    @Override
    public void run() {
        try {
            while (finishedResults.peek() != SHUTDOWN_REQ) {

                if(finishedResults.size() >= 100) {

                    writeOutputFile();

                } else {
                    Thread.sleep(1000);
                }

            }

        } catch (InterruptedException e) {
            e.printStackTrace();
        } finally {
            experimentTerminated = true;
        }
    }

    public void log(ExperimentResults results) {
        if (shuttingDown || experimentTerminated) {
            return;
        }

        try {
           finishedResults.put(results);
        } catch (InterruptedException iex) {
            Thread.currentThread().interrupt();
            throw new RuntimeException("Unexpected interruption");
        }

    }


    private void writeOutputFile() {
        //change this
        File file = new File(Global.fileNameExperimentTracker);
        try (BufferedWriter output = new BufferedWriter(new FileWriter(file, true))) {

            System.out.println("writing output file");
           while(!finishedResults.isEmpty())
               try {
                   ExperimentResults result = finishedResults.take();

            output.write(String.format("%n%n%s%n%s%n%s%n%s%n%s%n%s%n",
                        "[Mangler] " + result.getMangler(),
                        "[Matcher Name] " + result.getMatcherName(),
                        "[Average Matcher Score] " + result.getAverageMatcherScore(),
                        "[Exact Matcher Score] " + result.getAverageExactScore(),
                        "[IDF Range] " + result.getIdfRange().getA()
                                + "-" + result.getIdfRange().getB(),
                        "[File Tokenizers]" + result.getTokenizers()));

               } catch (InterruptedException e) {
                   e.printStackTrace();
               }

            } catch (IOException e1) {
            e1.printStackTrace();
        }

    }




    public void shutDown() throws InterruptedException {
        shuttingDown = true;
        finishedResults.put(SHUTDOWN_REQ);
    }

}


