package edu.georgetown.gucs.matcher;

import java.util.concurrent.LinkedBlockingQueue;
import java.util.List;
import java.util.ArrayList;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.logging.Level;
import java.util.logging.Logger;

import edu.georgetown.gucs.fingerprinter.Fingerprint;
import edu.georgetown.gucs.utility.ExceptionHandler;
import edu.georgetown.gucs.utility.Global;
import edu.georgetown.gucs.utility.ObjectBuilder;
import edu.georgetown.gucs.utility.Pair;
import edu.georgetown.gucs.utility.Token;

public class BulkMatcherWorker extends Thread {

    private final String matcherName;
    private final int minScore;
    private final LinkedBlockingQueue<Pair<Integer,Integer>> matchingQueue;
    private final List<Fingerprint> fingerprints;
    private final List<List<Pair<Token,Token>>> parentResults;
    private final List<List<Pair<Token,Token>>> ourResults;
    private final Pair<Integer,Integer> poison;
    private final AtomicInteger finishedThreads;
    private static final Logger logger = Logger.getLogger(BulkMatcher.class.getName());

    //set google all pairs matcher here

    /*
     *
     */
    BulkMatcherWorker(String matcherName, int minScore,
                      LinkedBlockingQueue<Pair<Integer,Integer>> toMatch,List<Fingerprint> fingerprints,
                      List<List<Pair<Token,Token>>> parentResults, Pair<Integer,Integer> poison,
                      AtomicInteger finishedThreads)   {
	
	this.matcherName = matcherName;
	this.minScore = minScore;
	this.matchingQueue = toMatch;
	this.fingerprints = fingerprints;
	this.parentResults = parentResults;
	this.poison = poison;
	this.finishedThreads = finishedThreads;

	ourResults = new ArrayList<>(Global.MAX_SCORE+1);

	for (int i = 0; i <= Global.MAX_SCORE; i++){
	    this.ourResults.add(i, new ArrayList<>());
	}
	

    }
    
		      
    @Override
	public void run(){

    logger.log(Level.INFO, "Thread Starting", Thread.currentThread().getName());
	

	// Make the matcher
        FingerprintMatcher matcher = (FingerprintMatcher) ObjectBuilder.buildObject(matcherName);

	try {
	    while(true) {
		
		int currentScore;
		
		Pair<Integer, Integer> pair = matchingQueue.take();

		if (pair != poison){
		    Integer first = pair.getA();
		    Integer second = pair.getB();
		
		    for (int x = first + 1; x < second; x++) {
			
			//for google all pairs here is where we convert
            //send the fingerprints to google all pairs matcher

            //store FP in blockinqueue
			byte[] firstFP = fingerprints.get(first).getFingerprint();
			byte[] secondFP = fingerprints.get(x).getFingerprint();

			currentScore = matcher.getScore(firstFP, secondFP);
			
			//System.err.println("Thread processing " + first + " " + second + " score: " + currentScore);
			
			if (currentScore >= minScore){
			    
			    // If the score is high enough, create a token and
			    // add it to the slot in the results vector that 
			    // is numbered the same as the score

			    Token firstToken = new Token(fingerprints.get(first).getFileName());
			    Token secondToken = new Token(fingerprints.get(x).getFileName());
			    
			    // Store the results locally in the thread, as the synchronized calls
			    // to pass things to the parent were too slow to do one at a time
			    Pair<Token,Token> matchingFiles = new Pair(firstToken,secondToken);
			    List<Pair<Token,Token>> outerVec = ourResults.get(currentScore);
			    outerVec.add(matchingFiles);
			}
		    }
		}
		else {
		    
		    // When we get the poison, pass all our results back to our parent
		    
		    for (int i = Global.MAX_SCORE; i > 0; i--){
			List<Pair<Token,Token>> ourInnerVec = ourResults.get(i);
			if (ourInnerVec.size() != 0){
			    List<Pair<Token,Token>> parentInnerVec = parentResults.get(i);
			    for (int x = 0; x < ourInnerVec.size(); x++){
				//System.err.println("Thread " + Thread.currentThread().getName() + " adding " + ourInnerVec.get(x).getA() + " " + ourInnerVec.get(x).getB());
				parentInnerVec.add(ourInnerVec.get(x));
			    }

			}
		    }
		    matchingQueue.put(poison);
		    finishedThreads.getAndIncrement();
		    break;
		}
	    }
	}
	catch (InterruptedException e){
	    ExceptionHandler.handleExceptionExit(e);
	}
    logger.log(Level.INFO, "Thread terminating", Thread.currentThread().getName());
    }

}