package edu.georgetown.gucs.matcher;

import edu.georgetown.gucs.fingerprinter.Fingerprint;

import java.io.*;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.channels.FileChannel;
import java.util.*;

/**
 * @author Evan B.
 * @since 9/23/14
 * GFP receives a fingerprint and converts it to bits,
 * Stores bits in a file and runs GAP algorithm
 */
public class GoogleFingerprintMatcher extends FingerprintMatcher {

    Map<Integer, String> matcherMap = new HashMap<>();
    private final String fileName;

    /**
     * Constructor that sets the minimum score to use for matching two fingerprints to zero
     */
    public GoogleFingerprintMatcher() {
        super();

        Random rand = new Random();
        fileName = "gapFpMatch" + rand.nextInt() + ".bin";

    }


    /**
     * save file in record id
     * get the results from GAP
     * lookup record IDS and match them back with score
     */


    /**
     * this is where we get two fingerprints,
     * store them,
     * return the result of GAP results
     */
    @Override
    public boolean match(String base64fp1, String base64fp2) {

        return super.match(base64fp1, base64fp2);
    }


    @Override
    public boolean match(List<Fingerprint> fp) {

        //initialize a temp file
        //iterate through results and store
        Integer fid = 0;
        for (Fingerprint fing : fp) {

            matcherMap.put(fid, fing.getFileName());
            System.out.println("fileName " + fileName);
            printBytes(fileName, true, fid, fing.getFingerprint());

            fid++;
        }

        return true;

    }

    @Override
    public void getScore() {
        //run google all pairs
        //match scores to their appropriate results
        try {
           Process process = new ProcessBuilder(
                    "ap", ".9", fileName).start();

            InputStream is = process.getInputStream();

            InputStreamReader isr = new InputStreamReader(is);
            BufferedReader br = new BufferedReader(isr);

            String line;
            while ((line = br.readLine()) != null) {
                System.out.println(line);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private void printBytes(String path, boolean append, int fid, byte[] set) {

        copy(path, append, fid);
        copy(path, append, set.length * 8);
        for (int i = 0; i < set.length * 8; i++) {
            if ((set[i / 8] & (1 << (7 - (i % 8)))) > 0) {
                copy(path, append, 1);
            } else {
                copy(path, append, 0);
            }
        }

    }

    //override getScore
    //call GAP
    //parse results
    private void copy(String fileOutName, boolean append, int bitset) {
        File fileOut = new File(fileOutName);

        try (FileChannel wChannel = new FileOutputStream(fileOut, append).getChannel()) {

            ByteBuffer bb = ByteBuffer.allocate(32);
            bb.order(ByteOrder.LITTLE_ENDIAN);
            bb.putInt(bitset);

            bb.flip();

            wChannel.write(bb);

        } catch (IOException e) {

            e.printStackTrace();
        }
    }

}
