package edu.georgetown.gucs.matcher;

import edu.georgetown.gucs.fingerprinter.Fingerprint;
import edu.georgetown.gucs.utility.Global;
import edu.georgetown.gucs.utility.Pair;
import edu.georgetown.gucs.utility.Token;

import java.io.*;
import java.util.List;
import java.util.Random;

/**
 * @author Evan Bloomberg
 *         created on 5/5/14.
 */
public class SdHashFingerprintMatcher extends FingerprintMatcher {


    private final String threadName = Thread.currentThread().getName().replaceAll("\\s", "");
    private final Random generator = new Random(System.currentTimeMillis());
    private String sdHashCmpScore;

    /**
     * Returns a random number
     *
     * @return a random double based on @value generators value
     */
    private String randomGenerator() {
        return String.valueOf(generator.nextDouble() * 0.5);
    }


    /**
     * The constructor that is called to inherit the Matcher parent class
     */
    public SdHashFingerprintMatcher() {
        super();
    }

    /**
     * Takes two Lists that are of type Pair where the fingerprint is stored in byte form
     *
     * @param fingerprint1 the list that contains the first fingerprint to compare
     * @param fingerprint2 list that contains the second fingerprint to compare
     * @return the score of two files compared by SdHash
     */
    public int getMatch(List<Fingerprint> fingerprint1, List<Fingerprint> fingerprint2) {
        // There is only one fingerprint per list {located at the 0 element}

        String fp1 = fingerprint1.get(0).getFileName();
        String fp2 = fingerprint2.get(0).getFileName();


        String fileName = threadName + randomGenerator();
        try {
            //create
            File tempFile = File.createTempFile(fileName, ".sdbf");

            try ( BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(tempFile)) ) {
                bufferedWriter.write(fp1);

                bufferedWriter.newLine();

                bufferedWriter.write(fp2);
            }

        } catch (IOException e) {
            e.printStackTrace();
        }

        Integer score = 0;
        String minScore = String.valueOf(getMinimumScore());


        try (InputStream inStream = new ProcessBuilder(Global.sdHashFilePath, "-c", fileName + ".sdbf", "-t", minScore)
                .start().getInputStream();
             BufferedReader buffer = new BufferedReader(new InputStreamReader(inStream, Global.fileEncoding));) {

            String line;
            StringBuilder sdHashComparisonScore = new StringBuilder();
            while ((line = buffer.readLine()) != null) {
                sdHashComparisonScore.append(line);
            }
            sdHashCmpScore = sdHashComparisonScore.toString();

            score = Integer.parseInt(sdHashComparisonScore.substring(sdHashComparisonScore.lastIndexOf("|"),
                    sdHashComparisonScore.length()));

        } catch (IOException e) {
            e.printStackTrace();
        }

        return score;
    }

    public void printScore(){

        System.out.println("********Fingerprint Score*********");
        System.out.println(sdHashCmpScore);

    }


    @Override
    public String toString() {
        return "SdHashFingerprintMatcher";
    }


}
