package edu.georgetown.gucs.testScript;


import java.io.*;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.*;
import java.util.logging.Logger;

/**
 * @author evan
 * @since 5/14/14.
 */
public class SdTest {

    protected static String sdTextpath;
    protected static String basePathInput;
    protected static String basePathOutput;
    protected static String verifiedFilePath;
    protected static Map<String, String> testedFiles = new HashMap<>();
    protected static ArrayList<String> error = new ArrayList<>();

    private static final Logger logger = Logger.getLogger(SdTest.class.getName());

    public static void main(String args[]) {


        for (int i = 0; i < args.length; i += 2) {

            if ("-basePathIn".equalsIgnoreCase(args[i].trim()) || "-bpi".equalsIgnoreCase(args[i].trim())) {

                basePathInput = args[i + 1];

            } else if ("-path".equalsIgnoreCase(args[i].trim()) || "-p".equalsIgnoreCase(args[i].trim())) {

                sdTextpath = args[i + 1];

            } else if ("-basePathOut".equalsIgnoreCase(args[i].trim()) || "-bpo".equalsIgnoreCase(args[i].trim())) {

                basePathOutput = args[i + 1];

            } else if ("-verifiedPath".equalsIgnoreCase(args[i].trim()) || "-vp".equalsIgnoreCase(args[i].trim())) {

                verifiedFilePath = args[i + 1];

            }
        }

        if ("".equals(basePathInput) || "".equals(sdTextpath) || "".equals(basePathOutput)) {

            System.err.println("Please specify a path for sdText [-p or -path]");
            System.exit(1);

        } else {
            ArrayList<String> trialSets = new ArrayList<String>();

            trialSets.add("TokenizeFile|setInput:federalist/15,setOutputFile:false");

         /*   trialSets.add("ArabicFileTokenizer|setInput:arabic-AlJezeera-ChangingInternationalSecurityAndAsian.txt,setOutputFile:false");

            trialSets.add("ChineseFileTokenizer|setInput:chinese-Xinhuanet-ChinaAndUnitedStatesWhoCanWinEnergyBattle.txt,setOutputFile:false");

            trialSets.add("CreateDictionary|setDirectory:federalist/,setOutputFile:true");

            trialSets.add("ShowDictionaryStatistics|setDictionary:createDictionary,setOutputFile:false");

            trialSets.add("ShowDictionaryTokens|setDictionary:createDictionary,setOutputFile:false");

            trialSets.add("TrimDictionary|setDictionary:createDictionary,setOutputFile:true");

            trialSets.add("BitVectorFingerprinter|setInput:federalist/15,setDictionary:CreateDictionary,setOutputFile:true");

            trialSets.add("ScoreFingerprints|setInput:federalist/15,setTargetFingerprint:BitVectorFingerprinter," +
                    "setSourceFingerprint:BitVectorFingerprinter,setOutputFile:false");

            trialSets.add("ExtractFingerprintDictionary|setFingerprint:BitVectorFingerprinter,setOutputFile:false");

            trialSets.add("CompareFingerprint|setDirectory:federalist/,setFingerprint:BitVectorFingerprinter,setOutputFile:true");

            trialSets.add("CompareDirectory|setDirectory:federalist/,setDictionary:CreateDictionary,setOutputFile:true");

            // trialSets.add("Experiment|setConfig:experiment_config.xml,setOutputFile:true");

            //  trialSets.add("sdHashFingerprinter|setInput:/federalist/test,setOutputFile:false")


            /*
            trials = new Trials("BitVectorFingerprinter");
            trials.setInput("federalist/18");
            trials.setDictionary("dictionary.txt");
            trials.setOutputFile("BitVectorFingerprinter");
            trialSets.add(trials);
            */

            SdTest sd = new SdTest();

            ArrayList<Trials> trialArgs = sd.setTrialArguments(trialSets);


            //Create the trial files
            for (Trials trialTemp : trialArgs) {

                sd.runSdText(trialTemp);

            }

            sd.listFiles(verifiedFilePath);
            TestMatch compareFiles;
            for (Map.Entry<String, String> filePaths : testedFiles.entrySet()) {

                compareFiles = new TestMatch(filePaths.getValue());
                compareFiles.compare();

            }

        }
    }


    private ArrayList<String> parseCommand(String str) {

        ArrayList<String> results = new ArrayList<String>();

        String[] createCall = str.split("\\|");

        results.add(createCall[0]);

        String[] trial;
        String[] result;

        if (createCall[1].contains(",")) {
            trial = createCall[1].split(",");
            for (String trialString : trial) {
                result = trialString.split(":");
                results.add(result[0]);
                results.add(result[1]);
            }

        } else {
            result = createCall[1].split(":");
            results.add(result[0]);
            results.add(result[1]);
        }


        return results;
    }


    public ArrayList<Trials> setTrialArguments(ArrayList<String> trialArgs) {

        ArrayList<Trials> trialsArrayList = new ArrayList<>();

        for (String trial : trialArgs) {

            ArrayList<String> temp = parseCommand(trial);

            Trials obj = new Trials(temp.get(0));

            temp.remove(0);

            while (!temp.isEmpty()) {

                Method method;
                try {
                    method = Class.forName("edu.georgetown.gucs.testScript.Trials")
                            .getMethod(temp.get(0), new Class[]{String.class});

                    method.invoke(obj, temp.get(1)); // 4 is the argument to pass to the method

                } catch (NoSuchMethodException | ClassNotFoundException
                        | IllegalAccessException | InvocationTargetException e) {
                    e.printStackTrace();
                }
                temp.remove(0);
                temp.remove(0);
            }

            trialsArrayList.add(obj);

        }

        return trialsArrayList;
    }

    /**
     * @param trials arguments to execute as a process
     */
    public void runSdText(Trials trials) {
        //turn the trials into an array and execute processbuilder
        String[] sdTextParamsArray = trials.getTrialCommand();
        String fileName = basePathOutput + trials.getFileName();

        //Check if temp directory exist &&
        //if !exists create else move on
        File f = new File(basePathOutput);
        if (!f.exists() && !f.isDirectory()) {
            if (f.mkdir()) {
                logger.info("directory successfully created");
            } else {
                logger.severe("unable to create directory");
            }
        }

        ProcessBuilder ps = new ProcessBuilder(sdTextParamsArray);
        ps.redirectErrorStream(true);


        StringBuilder output = new StringBuilder();
        try (InputStream inStream = ps.start().getInputStream();
             BufferedReader buffer = new BufferedReader(
                     new InputStreamReader(inStream, "UTF-8"))) {

            String line;
            while ((line = buffer.readLine()) != null) {
                output.append(line).append(" ").append("\n");
            }

            if (trials.getSave()) {

                try (BufferedWriter writer = new BufferedWriter(new FileWriter(fileName))) {
                    writer.write(output.toString());
                }

                System.out.println("Writing: " + trials.getFileName() + ", success");

            } else {

                System.out.println(trials.getFileName() + ": " + output.toString() + "\n");
            }

        } catch (IOException e) {
            e.printStackTrace();
        }
        //store the fileName & filePath
        testedFiles.put(trials.getFileName().toLowerCase(), fileName + "|");
    }

    public void listFiles(String verifiedFilePath) {

        try {
            Files.walk(Paths.get(verifiedFilePath)).forEach(filePath -> {
                if (Files.isRegularFile(filePath)) {

                    String fileName = filePath.getFileName().toString().toLowerCase();
                    if (testedFiles.containsKey(fileName)) {

                        String temp = testedFiles.get(fileName);
                        testedFiles.replace(fileName, testedFiles.get(fileName),
                                temp + filePath.toString());

                    } else {

                        if (!fileName.equalsIgnoreCase(".DS_STORE")) {
                            error.add("Verified file does not exist in testedFile: " + fileName);
                        }

                    }

                }
            });
        } catch (IOException e) {
            e.printStackTrace();
        }

    }

    public void printParams(List<Trials> trialList) {

        for (Trials trialSet : trialList) {

            for (String trial : trialSet.getTrialCommand()) {
                System.out.println(trial);
            }

            System.out.println("---------New Trial--------");
        }

    }
}
