package edu.georgetown.gucs.tokenizers;

import java.util.Collections;
import java.util.List;
import java.util.StringTokenizer;
import java.util.Vector;

import edu.georgetown.gucs.utility.Token;

/**
 * Eliminates tokens related to attachments in the Enron data set
 * 
 * @author Clay Shields
 * @author Lindsay Neubauer
 * 
 */
public class EnronEmailTokenizer extends Tokenizer {

  private static final long serialVersionUID = -6511497447095629957L;

  /**
   * Eliminates tokens related to attachments in the Enron data set
   */
  @Override
  public List<Token> tokenize(List<Token> tokens) {
    List<Token> tokenVector = Collections.synchronizedList(new Vector<Token>());
    synchronized (tokenVector) {
      for (Token token : tokens) {
        if (token.name().contains("Content-Disposition: attachment;")) {
          break;
        }
        StringTokenizer stringTokenizer = new StringTokenizer(token.name());
        while (stringTokenizer.hasMoreTokens()) {
          tokenVector.add(new Token(stringTokenizer.nextToken().trim(), token.start_byte(), token.end_byte()));
        }
      }
      return tokenVector;
    }
  }
}
