package edu.georgetown.gucs.tokenizers;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Ensures that {@linkplain TokenizerList} objects are only created once. This manager should only be instantiated once
 * and all objects should request TokenizerList objects from it.
 * 
 * @author Chris Wacek
 */
public class TokenizerListManager { 

  private final Map<Integer, TokenizerList> tokenizerLists;

  /**
   * Constructor that initializes a hashMap holding all tokenizerList objects
   */
  public TokenizerListManager() {
    this.tokenizerLists = new HashMap<Integer, TokenizerList>();
  }

  /**
   * Finds the tokenizerList that contains the provided list of tokenizers; if no such tokenizerList exists then it
   * creates a new list with these tokenizers
   * 
   * @param tokenizerNames
   *          the list of tokenizer names to return in the form of a tokenizerList
   * 
   * @return the tokenizerList containing the provided tokenizer names
   */
  public TokenizerList retrieveTokenizerList(List<String> tokenizerNames) {
    if (this.tokenizerLists.containsKey(tokenizerNames.hashCode())) {
      return this.tokenizerLists.get(tokenizerNames.hashCode());
    }

    TokenizerList tempTokenizerList = new TokenizerList(tokenizerNames);

    this.tokenizerLists.put(tokenizerNames.hashCode(), tempTokenizerList);
    return this.tokenizerLists.get(tokenizerNames.hashCode());
  }
}
