package edu.georgetown.gucs.utility;

import java.io.File;
import java.util.Arrays;
import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Thread for processing a file to add to a {@linkplain FileLister}
 *
 * @author Lindsay Neubauer
 * @author Clay Shields
 */
class FileListerWorker extends Thread {

    private final FileLister fileLister;
    private final File poison;
    private static final Logger logger = Logger.getLogger(FileLister.class.getName());

    /**
     * Constructor that specifies a file to add to the existing fileLister
     *
     * @param poison        the file to add to the tail of the file queue
     * @param theFileLister the fileLister to add the currentFile to
     */
    FileListerWorker(FileLister theFileLister, File poison) {
        this.fileLister = theFileLister;
        this.poison = poison;
       // System.out.println("[poison] " + poison);
    }

    /**
     * Adds the file to the existing fileLister
     */
    @Override
    public void run() {

        Boolean done = false;
        ArrayList<File> localList = new ArrayList<>();

        // Get a directory to traverse from the shared queue

        while (!done) {

            File currentDir = fileLister.getNextDirectory();
          //  System.out.println("[CurrentDir] " + currentDir.getAbsolutePath());

            if (currentDir == poison) {
                fileLister.addDirectory(poison);
                logger.log(Level.INFO, "run", "Finished");
                // The next line doens't matter, but it makes FindBugs happy
                done = true;
                return;
            }

            logger.log(Level.INFO, "run", "Dir to process: " + currentDir.getAbsolutePath()
                    + " thread_id = " + Thread.currentThread().getName());


            try {
                for (File file : Arrays.asList(currentDir.listFiles())) {

                    if (file.isFile() && file.canRead()) {
                        // ignore .DS_Store files
                        if (file.toString().indexOf(".DS_Store") < 0) {
                            logger.log(Level.INFO, "run", "Processed file: " + file);
                            localList.add(file);
                        }
                    } else if (file.isDirectory() && file.canRead()) {
                        // Ignore .svn directories
                        if (file.toString().indexOf(".svn") < 0) {
                            fileLister.addDirectory(file);
                            logger.log(Level.INFO, "run", "Added directory: " + file);
                        }
                    } else {
                        logger.log(Level.INFO, "run", "Found odd file: " + file);
                    }
                }
            } catch (NullPointerException e) {
                System.err.println("FileListerWorker: Bad or non-existant directory name: " + currentDir);
                logger.log(Level.INFO, "run", "Bad or non-existant directory name: " + currentDir);
                ExceptionHandler.handleExceptionExit(e);
            }

            for (File current : localList) {

                fileLister.addFile(current);
                fileLister.putFile(current);

            }
            logger.log(Level.INFO,"run", "Finished directory: " + currentDir.getAbsolutePath()
                    + " thread_id = " + Thread.currentThread().getName());

        }
    }

}