package edu.georgetown.gucs.utility;

import java.awt.Font;
import java.io.InputStream;
import java.util.Properties;

/**
 * Global information
 *
 * @author Clay Shields
 * @author Lindsay Neubauer
 */
public final class Global {
    /**
     * Monitor that writes its buffer to a GZIP log file
     */
    public final static Monitor monitor = new Monitor();

    /**
     * Returns the default file system encoding
     */
    public final static String fileEncoding = "UTF-8";

    /**
     * Returns the default file system encoding
     */
    public final static String fileNameExperimentTracker = "current.results";


    /**
     * Location of file path to SdHash
     */
    public final static String sdHashFilePath = "sdhash";

    /**
     * Set the Bloom Filters False Positive probability
     */
    public final static double FALSEPOSPROB = .00001;

    /**
     * Location of precision score in array of experiment/trial results
     */
    public final static int PRECISION = 0;
    /**
     * Location of recall score in array of experiment/trial results
     */
    public final static int RECALL = 1;
    /**
     * Location of f-score in array of experiment/trial results
     */
    public final static int FSCORE = 2;
    /**
     * Location of true-positive count in array of experiment/trial results
     */
    public final static int TRUE_POSITIVE = 3;
    /**
     * Location of false-positive count in array of experiment/trial results
     */
    public final static int FALSE_POSITIVE = 4;
    /**
     * Location of true-negative count in array of experiment/trial results
     */
    public final static int TRUE_NEGATIVE = 5;
    /**
     * Location of false-negative count in array of experiment/trial results
     */
    public final static int FALSE_NEGATIVE = 6;
    /**
     * Location of dictionary size in array of experiment/trial results
     */
    public final static int DICTIONARY_SIZE = 7;

    /**
     * Location of mangler count in array of experiment/trial results
     */
    public final static int COUNT = 3;

    /**
     * GNU Unifont, PLAIN, size 12
     */
    public final static Font unifontFont12 = new Font("GNU Unifont", Font.PLAIN, 12);

    /**
     * GNU Unifont, PLAIN, size 14
     */
    public final static Font unifontFont14 = new Font("GNU Unifont", Font.PLAIN, 14);

    /**
     * GNU Unifont, BOLD, size 12
     */
    public final static Font boldUnifontFont = new Font("GNU Unifont", Font.BOLD, 12);

    /**
     * GNU Unifont, BOLD, size 14
     */
    public final static Font boldUnifontFont14 = new Font("GNU Unifont", Font.BOLD, 14);

    /**
     * Value indicating to display all files in GUI
     */
    public final static boolean ALL_FILES = true;

    /**
     * Value indicating to display only XML files in GUI
     */
    public final static boolean XML_ONLY = false;

    /**
     * Value indicating the lowest similarity score
     */
    public final static int MIN_SCORE = 0;

    /**
     * Value indicating the maximum similarity score
     */
    public final static int MAX_SCORE = 100;

    /**
     * Value indicating the properties
     */
    private static final Properties defaultProps = new Properties();

    static {
        try {
            InputStream stream = Global.class.getResourceAsStream("/sdtext.properties");
            defaultProps.load(stream);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * returns the property specified by ANT build
     */
    public static String getProperty(String key) {
        return defaultProps.getProperty(key);
    }


    /**
     *  Prints a string/object with the
     *  Calling class/Method
     */
    public static void debug(String str, Object o ) {

        StackTraceElement[] stackTraceElements = Thread.currentThread().getStackTrace();

        String currentClass = stackTraceElements[2].getFileName().
                substring(0,stackTraceElements[2].getFileName().lastIndexOf("."));

        String currentMethod = stackTraceElements[2].getMethodName();
        String lineNum = Integer.toString(stackTraceElements[2].getLineNumber());

        System.out.println(currentClass +"." + currentMethod + "." + lineNum
                + " " + str +  " " + o);


    }

}
