package edu.georgetown.gucs.utility;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

/**
 * Makes a deep copy of an Object using serialization
 * 
 * @author Dave Miller
 * 
 * @see <a href="http://www.javaworld.com/javaworld/javatips/jw-javatip76.html?page=2">Java Tip 76: An alternative to
 *      the deep copy technique</a>
 * 
 */
public class ObjectCloner { 

  /**
   * Default constructor is private
   */
  private ObjectCloner() {
  }

  /**
   * Provides a deep copy of an object
   * 
   * @param oldObj
   *          the object to deep copy
   * 
   * @return the new copy of the object
   */
  static public Object deepCopy(Object oldObj) {
    ObjectInputStream ois = null;
    ObjectOutputStream oos = null;
    try {
      ByteArrayOutputStream bos = new ByteArrayOutputStream();
      oos = new ObjectOutputStream(bos);
      // serialize and pass the object
      oos.writeObject(oldObj);
      ois = new ObjectInputStream(new ByteArrayInputStream(bos.toByteArray()));
      return ois.readObject();
    } catch (ClassNotFoundException e) {
      ExceptionHandler.handleExceptionExit(e);
    } catch (IOException e) {
      ExceptionHandler.handleExceptionExit(e);
    } finally {
      try {
        if (ois != null) {
          ois.close();
        }
        if (oos != null) {
          oos.close();
        }
      } catch (IOException e) {
        ExceptionHandler.handleExceptionExit(e);
      }
    }
    return null;
  }
}
